@@ -159,7 +159,7 @@ static int cfg_alloc_structure(CSOUND* csound,
     ldBytes = (ldBytes + 15) & (~15);
     totBytes = structBytes + nameBytes + sdBytes + ldBytes;
     /* allocate memory */
-    pp = (void*) mmalloc(csound, (size_t) totBytes);
+    pp = (void*) csound->Malloc(csound, (size_t) totBytes);
     if (UNLIKELY(pp == NULL))
       return CSOUNDCFG_MEMORY;
     memset(pp, 0, (size_t) totBytes);
@@ -444,8 +444,8 @@ static csCfgVariable_t **list_db_entries(CSOUND* csound, CS_HASH_TABLE *db)
 
 
     /* allocate memory for list */
-    lst = (csCfgVariable_t**) mmalloc(csound, sizeof(csCfgVariable_t*)
-                                     * (cnt + (size_t) 1));
+    lst = (csCfgVariable_t**) csound->Malloc(csound, sizeof(csCfgVariable_t*)
+                                             * (cnt + (size_t) 1));
     if (UNLIKELY(lst == NULL))
       return (csCfgVariable_t**) NULL;  /* not enough memory */
     /* create list */
@@ -487,7 +487,7 @@ PUBLIC csCfgVariable_t **csoundListConfigurationVariables(CSOUND *csound)
 PUBLIC void csoundDeleteCfgVarList(CSOUND* csound, csCfgVariable_t **lst)
 {
     if (lst != NULL)
-      mfree(csound, lst);
+      csound->Free(csound, lst);
 }
 
 /* remove a configuration variable from 'db' */
@@ -499,7 +499,7 @@ static int remove_entry_from_db(CSOUND* csound, CS_HASH_TABLE *db, const char *n
     if (UNLIKELY(pp == NULL))
         return CSOUNDCFG_INVALID_NAME;
 
-    mfree(csound, pp);
+    csound->Free(csound, pp);
     cs_hash_table_remove(csound, db, (char*)name);
 
     return CSOUNDCFG_SUCCESS;
@@ -528,7 +528,7 @@ static int destroy_entire_db(CSOUND *csound, CS_HASH_TABLE *db)
 
     while (current != NULL) {
         if (current->value != NULL) {
-             mfree(csound, current->value);
+             csound->Free(csound, current->value);
         }
         current = current->next;
     }
