@@ -69,37 +69,72 @@ static INSTR_SEMANTICS *instr_semantics_alloc(CSOUND *csound, char *name)
 //static INSTR_SEMANTICS *curr;
 //static INSTR_SEMANTICS *root;
 
-void csp_orc_sa_cleanup(CSOUND *csound)
+/* void csp_orc_sa_cleanup(CSOUND *csound) */
+/* { */
+/*     INSTR_SEMANTICS *current = csound-> instRoot, *h = NULL; */
+/*     csp_orc_sa_print_list(csound); */
+/*     while (current != NULL) { */
+
+/*       csp_set_dealloc(csound, &(current->read)); */
+/*       csp_set_dealloc(csound, &(current->write)); */
+/*       csp_set_dealloc(csound, &(current->read_write)); */
+
+/*       h = current; */
+/*       current = current->next; */
+/*       csound->Free(csound, h); */
+/*     } */
+/*     current = csound->instCurr; */
+/*     while (current != NULL) { */
+
+/*       csp_set_dealloc(csound, &(current->read)); */
+/*       csp_set_dealloc(csound, &(current->write)); */
+/*       csp_set_dealloc(csound, &(current->read_write)); */
+
+/*       h = current; */
+/*       current = current->next; */
+/*       csound->Free(csound, h); */
+/*     } */
+
+/*     csound->instCurr = NULL; */
+/*     csound->instRoot = NULL; */
+/* } */
+
+
+static void sanitise_set(CSOUND *csound, struct set_t* p)
 {
-    INSTR_SEMANTICS *current = csound->instRoot, *h = NULL;
-    while (current != NULL) {
-
-      csp_set_dealloc(csound, &(current->read));
-      csp_set_dealloc(csound, &(current->write));
-      csp_set_dealloc(csound, &(current->read_write));
-
-      h = current;
-      current = current->next;
-      csound->Free(csound, h);
+    struct set_element_t *ele = p->head;
+    while (ele != NULL) {
+      ele->data = cs_strdup(csound, (char*)ele->data);
+      ele = ele->next;
     }
-
-    csound->instCurr = NULL;
-    csound->instRoot = NULL;
 }
 
+void sanitize(CSOUND*csound)
+{
+    INSTR_SEMANTICS *p = csound->instRoot;
+    while (p) {
+      if (p->sanitized==0) {
+        sanitise_set(csound, p->read);
+        sanitise_set(csound, p->write);
+        sanitise_set(csound, p->read_write);
+        p->sanitized = 1;
+      }
+      p = p->next;
+    }
+}
 void csp_orc_sa_print_list(CSOUND *csound)
 {
     csound->Message(csound, "Semantic Analysis\n");
     INSTR_SEMANTICS *current = csound->instRoot;
     while (current != NULL) {
-      csound->Message(csound, "Instr: %s\n", current->name);
-      csound->Message(csound, "  read: ");
+      csound->Message(csound, "(%p)Instr: %s\n", current, current->name);
+      csound->Message(csound, "  read(%p): ", current->read);
       csp_set_print(csound, current->read);
 
-      csound->Message(csound, "  write: ");
+      csound->Message(csound, "  write:(%p) ", current->write);
       csp_set_print(csound, current->write);
 
-      csound->Message(csound, "  read_write: ");
+      csound->Message(csound, "  read_write(%p): ", current->read_write);
       csp_set_print(csound, current->read_write);
 
       current = current->next;
@@ -123,7 +158,6 @@ void csp_orc_sa_global_read_write_add_list(CSOUND *csound,
     else {
       csp_orc_sa_global_write_add_list(csound, write);
       csp_orc_sa_global_read_add_list(csound, read);
-      /* csp_set_dealloc(csound, &new); */
     }
 }
 
@@ -143,11 +177,14 @@ void csp_orc_sa_global_read_write_add_list1(CSOUND *csound,
     else {
       struct set_t *new = NULL;
       csp_set_union(csound, write, read, &new);
+      //printf("Line: %d of cs_par_orc_semantics(%p)\n", __LINE__, *new);
       if (write->count == 1 && read->count == 1 && new->count == 1) {
         /* this is a read_write list thing */
         struct set_t *new_read_write = NULL;
         csp_set_union(csound, csound->instCurr->read_write,
                       new, &new_read_write);
+        //printf("Line: %d of cs_par_orc_semantics(%p)\n",
+        //       __LINE__, *new_read_write);
         csp_set_dealloc(csound, &csound->instCurr->read_write);
         csound->instCurr->read_write = new_read_write;
       }
@@ -155,7 +192,6 @@ void csp_orc_sa_global_read_write_add_list1(CSOUND *csound,
         csp_orc_sa_global_write_add_list(csound, write);
         csp_orc_sa_global_read_add_list(csound, read);
       }
-
       csp_set_dealloc(csound, &new);
     }
 }
@@ -213,13 +249,13 @@ void csp_orc_sa_interlocksf(CSOUND *csound, int code)
       struct set_t *ww = NULL;
       csp_set_alloc_string(csound, &ww);
       csp_set_alloc_string(csound, &rr);
-      if (code&ZR) csp_set_add(csound, rr, strdup("##zak"));
-      if (code&ZW) csp_set_add(csound, ww, strdup("##zak"));
-      if (code&TR) csp_set_add(csound, rr, strdup("##tab"));
-      if (code&TW) csp_set_add(csound, ww, strdup("##tab"));
-      if (code&CR) csp_set_add(csound, rr, strdup("##chn"));
-      if (code&CW) csp_set_add(csound, ww, strdup("##chn"));
-      if (code&WR) csp_set_add(csound, ww, strdup("##wri"));
+      if (code&ZR) csp_set_add(csound, rr, "##zak");
+      if (code&ZW) csp_set_add(csound, ww, "##zak");
+      if (code&TR) csp_set_add(csound, rr, "##tab");
+      if (code&TW) csp_set_add(csound, ww, "##tab");
+      if (code&CR) csp_set_add(csound, rr, "##chn");
+      if (code&CW) csp_set_add(csound, ww, "##chn");
+      if (code&WR) csp_set_add(csound, ww, "##wri");
       csp_orc_sa_global_read_write_add_list(csound, ww, rr);
       if (code&_QQ) csound->Message(csound, Str("opcode deprecated"));
     }
@@ -236,14 +272,17 @@ void csp_orc_sa_interlocks(CSOUND *csound, ORCTOKEN *opcode)
 
 void csp_orc_sa_instr_add(CSOUND *csound, char *name)
 {
-    name = strdup(name);
+    name = strdup(name); // JPff:  leaks: necessary??
+    //printf("csp_orc_sa_instr_add name=%s\n", name);
     csound->inInstr = 1;
     if (csound->instRoot == NULL) {
+      //printf("instRoot id NULL\n");
       csound->instRoot = instr_semantics_alloc(csound, name);
       csound->instCurr = csound->instRoot;
     }
     else if (csound->instCurr == NULL) {
       INSTR_SEMANTICS *prev = csound->instRoot;
+      //printf("instCurr NULL\n");
       csound->instCurr = prev->next;
       while (csound->instCurr != NULL) {
         prev = csound->instCurr;
@@ -253,6 +292,7 @@ void csp_orc_sa_instr_add(CSOUND *csound, char *name)
       csound->instCurr = prev->next;
     }
     else {
+      printf("othercase\n");
       csound->instCurr->next = instr_semantics_alloc(csound, name);
       csound->instCurr = csound->instCurr->next;
     }
@@ -294,20 +334,20 @@ struct set_t *csp_orc_sa_globals_find(CSOUND *csound, TREE *node)
     left  = csp_orc_sa_globals_find(csound, node->left);
     right = csp_orc_sa_globals_find(csound, node->right);
     csp_set_union(csound, left, right, &current_set);
-
+    //printf("Line: %d of cs_par_orc_semantics(%p)\n", __LINE__, current_set);
     csp_set_dealloc(csound, &left);
     csp_set_dealloc(csound, &right);
 
     if ((node->type == T_IDENT || node->type == LABEL_TOKEN) &&
         node->value->lexeme[0] == 'g') {
-      csp_set_add(csound, current_set, strdup(node->value->lexeme));
+      csp_set_add(csound, current_set, /*strdup*/(node->value->lexeme));
     }
 
     if (node->next != NULL) {
       struct set_t *prev_set = current_set;
       struct set_t *next = csp_orc_sa_globals_find(csound, node->next);
       csp_set_union(csound, prev_set, next, &current_set);
-
+      //printf("Line: %d of cs_par_orc_semantics(%p)\n", __LINE__, current_set);
       csp_set_dealloc(csound, &prev_set);
       csp_set_dealloc(csound, &next);
     }
