@@ -31,7 +31,6 @@ extern "C" {
 
 PUBLIC CONS_CELL* cs_cons(CSOUND* csound, void* val, CONS_CELL* cons) {
     CONS_CELL* cell = csound->Malloc(csound, sizeof(CONS_CELL));
-
     cell->value = val;
     cell->next = cons;
 
@@ -179,7 +178,7 @@ char* cs_hash_table_put_no_key_copy(CSOUND* csound,
                 CS_HASH_TABLE_ITEM* newItem = csound->Malloc(csound,
                                                       sizeof(CS_HASH_TABLE_ITEM));
                 newItem->key = key;
-                newItem->value = value;
+                 newItem->value = value;
                 newItem->next = NULL;
                 item->next = newItem;
                 return newItem->key;
@@ -273,8 +272,16 @@ PUBLIC void cs_hash_table_merge(CSOUND* csound,
         CS_HASH_TABLE_ITEM* item = source->buckets[i];
 
         while (item != NULL) {
-            cs_hash_table_put_no_key_copy(csound, target, item->key, item->value);
-            item = item->next;
+            CS_HASH_TABLE_ITEM* next = item->next;
+            char* new_key =
+              cs_hash_table_put_no_key_copy(csound, target, item->key, item->value);
+
+            if(new_key != item->key) {
+                csound->Free(csound, item->key);
+              }
+
+            csound->Free(csound, item);
+            item = next;
         }
     }
 
@@ -324,9 +331,9 @@ PUBLIC void cs_hash_table_free_complete(CSOUND* csound, CS_HASH_TABLE* hashTable
         while(item != NULL) {
             CS_HASH_TABLE_ITEM* next = item->next;
             csound->Free(csound, item->key);
-            
+
             /* NOTE: This needs to be free, not csound->Free.
-               To use mfree on keys, use cs_hash_table_mfree_complete 
+               To use mfree on keys, use cs_hash_table_mfree_complete
                TODO: Check if this is even necessary anymore... */
             free(item->value);
             csound->Free(csound, item);
