@@ -52,12 +52,11 @@ void debugPrintCsound(CSOUND* csound);
 
 void named_instr_assign_numbers(CSOUND *csound, ENGINE_STATE *engineState);
 int named_instr_alloc(CSOUND *csound, char *s, INSTRTXT *ip, int32 insno,
-                      ENGINE_STATE *engineState);
+                      ENGINE_STATE *engineState, int merge);
 int check_instr_name(char *s);
+extern void free_instr_var_memory(CSOUND*, INSDS*);
 
-/* NOTE: these assume that sizeof(MYFLT) is either 4 or 8 */
-#define Wfloats (((int) sizeof(SPECDAT) + 7) / (int) sizeof(MYFLT))
-#define Pfloats (((int) sizeof(PVSDAT) + 7) / (int) sizeof(MYFLT))
+extern const char* SYNTHESIZED_ARG;
 
 #ifdef FLOAT_COMPARE
 #undef FLOAT_COMPARE
@@ -74,7 +73,8 @@ char* strsav_string(CSOUND* csound, ENGINE_STATE* engineState, char* key) {
                                          csound->engineState.stringPool, key);
 
     if (retVal == NULL) {
-        retVal = cs_hash_table_put_key(csound, engineState->stringPool, key);
+      //printf("strsav_string: %s\n", key);
+      retVal = cs_hash_table_put_key(csound, engineState->stringPool, key);
     }
     return retVal;
 }
@@ -91,6 +91,7 @@ int pnum(char *s)        /* check a char string for pnum format  */
     return(-1);
 }
 
+#if 0
 static int argCount(ARG* arg)
 {
     int retVal = -1;
@@ -103,14 +104,16 @@ static int argCount(ARG* arg)
     }
     return retVal;
 }
+#endif
 
 /* get size of string in MYFLT units */
-static inline int strlen_to_samples(const char *s)
+/*static inline int strlen_to_samples(const char *s)
 {
     int n = (int) strlen(s);
     n = (n + (int) sizeof(MYFLT)) / (int) sizeof(MYFLT);
     return n;
 }
+*/
 
 /* convert string constant */
 static void unquote_string(char *dst, const char *src)
@@ -174,10 +177,12 @@ static OPTXT * last_optxt(OPTXT *optxt)
 /**
  * Append OPTXT op2 to end of OPTXT chain op1
  */
+/*
 static inline void append_optxt(OPTXT *op1, OPTXT *op2)
 {
     last_optxt(op1)->nxtop = op2;
 }
+*/
 
 /** Counts number of args in argString, taking into account array identifiers */
 int argsRequired(char* argString)
@@ -207,6 +212,7 @@ char** splitArgs(CSOUND* csound, char* argString)
 {
     int argCount = argsRequired(argString);
     char** args = csound->Malloc(csound, sizeof(char*) * (argCount + 1));
+    // printf("alloc %p \n", args);
     char* t = argString;
     int i = 0;
 
@@ -235,6 +241,7 @@ char** splitArgs(CSOUND* csound, char* argString)
             dimensions++;
           }
           part = csound->Malloc(csound, sizeof(char) * (dimensions + 3));
+          //printf("alloc %p \n", part);
           part[dimensions + 2] = '\0';
           part[dimensions + 1] = ']';
           part[dimensions] = *start;
@@ -244,6 +251,7 @@ char** splitArgs(CSOUND* csound, char* argString)
 
         } else {
           part = csound->Malloc(csound, sizeof(char) * 2);
+          //printf("alloc %p \n", part);
           part[0] = *t;
           part[1] = '\0';
           t++;
@@ -258,77 +266,6 @@ char** splitArgs(CSOUND* csound, char* argString)
     return args;
 }
 
-void set_xincod(CSOUND *csound, TEXT *tp, OENTRY *ep)
-{
-    int n = tp->inlist->count;
-    char *s;
-    int nreqd = argsRequired(ep->intypes);
-    char **types = splitArgs(csound, ep->intypes);
-    //int lgprevdef = 0;
-    char      tfound = '\0', treqd;
-
-    if (n > nreqd) {
-      if ((treqd = *types[nreqd-1]) == 'n') {  /* indef args: */
-        int incnt = -1;                       /* Should count args */
-        if (!(incnt & 01))                    /* require odd */
-          synterr(csound, Str("missing or extra arg"));
-      }       /* IV - Sep 1 2002: added 'M' */
-      else if (treqd != 'm' && treqd != 'z' && treqd != 'y' &&
-               treqd != 'Z' && treqd != 'M' && treqd != 'N' &&
-               treqd != '*' && treqd != 'I' && treqd != 'W') /* else any no */
-        synterr(csound, Str("too many input args\n"));
-    }
-
-    while (n--) {                     /* inargs:   */
-      s = tp->inlist->arg[n];
-
-      if (n >= nreqd) {               /* det type required */
-        switch (*types[nreqd-1]) {
-        case 'M':
-        case 'W':
-        case 'N':
-        case 'Z':
-        case 'y':
-        case 'I':
-        case 'z':   treqd = *types[nreqd-1]; break;
-        default:    treqd = 'i';    /*   (indef in-type) */
-        }
-      }
-      else treqd = *types[n];          /*       or given)   */
-      if (treqd == 'l') {             /* if arg takes lbl  */
-        csound->DebugMsg(csound, "treqd = l");
-        //        lblrequest(csound, s);        /*      req a search */
-        continue;                     /*      chk it later */
-      }
-      tfound = argtyp2(s);     /* else get arg type */
-      if (tfound == 'a' && n < 31) /* JMC added for FOG */
-                                   /* 4 for FOF, 8 for FOG; expanded to 15  */
-        tp->xincod |= (1 << n);
-      if (tfound == 'S' && n < 31)
-        tp->xincod_str |= (1 << n);
-    }
-    csound->Free(csound, types);
-}
-
-
-void set_xoutcod(CSOUND *csound, TEXT *tp, OENTRY *ep)
-{
-    int n = tp->outlist->count;
-    char *s;
-    char **types = splitArgs(csound, ep->outypes);
-    char      tfound = '\0';
-
-    while (n--) {                                     /* outargs:  */
-      s = tp->outlist->arg[n];
-      tfound = argtyp2(s);                     /*  found    */
-      if (tfound == 'a' && n < 31)
-        tp->xoutcod |= (1 << n);
-      if (tfound == 'S' && n < 31)
-        tp->xoutcod_str |= (1 << n);
-    }
-    csound->Free(csound, types);
-}
-
 
 OENTRY* find_opcode(CSOUND*, char*);
 /**
@@ -381,6 +318,7 @@ OPTXT *create_opcode(CSOUND *csound, TREE *root, INSTRTXT *ip,
       /* INITIAL SETUP */
       tp->oentry = (OENTRY*)root->markup;
       tp->opcod = strsav_string(csound, engineState, tp->oentry->opname);
+      tp->linenum = root->line;
       ip->mdepends |= tp->oentry->flags;
       ip->opdstot += tp->oentry->dsblksiz;
 
@@ -398,6 +336,7 @@ OPTXT *create_opcode(CSOUND *csound, TREE *root, INSTRTXT *ip,
         tp->outlist = (ARGLST*) csound->ReAlloc(csound, tp->outlist, m);
         tp->outlist->count = outcount;
 
+        tp->inArgCount = 0;
 
         for (inargs = root->right; inargs != NULL; inargs = inargs->next) {
           /* INARGS */
@@ -412,6 +351,9 @@ OPTXT *create_opcode(CSOUND *csound, TREE *root, INSTRTXT *ip,
           else {
             lgbuild(csound, ip, arg, 1, engineState);
           }
+          if (inargs->markup != &SYNTHESIZED_ARG) {
+            tp->inArgCount++;
+          }
         }
       }
       /* VERIFY ARG LISTS MATCH OPCODE EXPECTED TYPES */
@@ -423,7 +365,8 @@ OPTXT *create_opcode(CSOUND *csound, TREE *root, INSTRTXT *ip,
           arg = outargs->value->lexeme;
           tp->outlist->arg[argcount++] = strsav_string(csound, engineState, arg);
         }
-        set_xincod(csound, tp, ep);
+
+        tp->outArgCount = 0;
 
         /* OUTARGS */
         for (outargs = root->left; outargs != NULL; outargs = outargs->next) {
@@ -437,9 +380,8 @@ OPTXT *create_opcode(CSOUND *csound, TREE *root, INSTRTXT *ip,
             csound->DebugMsg(csound, "Arg: %s\n", arg);
             lgbuild(csound, ip, arg, 0, engineState);
           }
-
+          tp->outArgCount++;
         }
-        set_xoutcod(csound, tp, ep);
 
         if (root->right != NULL) {
           if (ep->intypes[0] != 'l') {     /* intype defined by 1st inarg */
@@ -481,10 +423,14 @@ void addGlobalVariable(CSOUND *csound,
 {
     CS_VARIABLE *var = csoundCreateVariable(csound, csound->typePool,
                                             type, name, typeArg);
+    size_t memSize = sizeof(CS_VAR_MEM) - sizeof(MYFLT) + var->memBlockSize;
+    CS_VAR_MEM *varMem = csound->Malloc(csound, memSize);
     csoundAddVariable(csound, engineState->varPool, var);
-    var->memBlock = (void *) csound->Malloc(csound, var->memBlockSize);
+
+    varMem->varType = var->varType;
+    var->memBlock = varMem;
     if (var->initializeVariableMemory != NULL) {
-      var->initializeVariableMemory(var, var->memBlock);
+      var->initializeVariableMemory(var, &varMem->value);
     }
 }
 
@@ -495,6 +441,7 @@ void addGlobalVariable(CSOUND *csound,
  * Create an Instrument (INSTRTXT) from the AST node given for use as
  * Instrument0. Called from csound_orc_compile.
  */
+
 INSTRTXT *create_instrument0(CSOUND *csound, TREE *root,
                              ENGINE_STATE *engineState,
                              CS_VAR_POOL* varPool)
@@ -528,7 +475,7 @@ INSTRTXT *create_instrument0(CSOUND *csound, TREE *root,
 
     ip->mdepends = 0;
     ip->opdstot = 0;
-
+    ip->nocheckpcnt = 0;
 
     ip->pmax = 3L;
 
@@ -664,15 +611,30 @@ INSTRTXT *create_instrument0(CSOUND *csound, TREE *root,
                       csound->esr, csound->ekr, csound->ksmps,
                       csound->nchnls, csound->e0dbfs);
 
-    if (O->sr_override) {        /* if command-line overrides, apply now */
+    if (O->sr_override || O->kr_override || O->ksmps_override) {   /* if command-line overrides, apply now */
       MYFLT ensmps;
-      csound->esr = (MYFLT) O->sr_override;
-      csound->ekr = (MYFLT) O->kr_override;
-      csound->ksmps = (int) ((ensmps = ((MYFLT) O->sr_override
-                                        / (MYFLT) O->kr_override)) + FL(0.5));
-      csound->Message(csound, Str("sample rate overrides: "
-                                  "esr = %7.4f, ekr = %7.4f, ksmps = %d\n"),
-                      csound->esr, csound->ekr, csound->ksmps);
+      
+      if(!O->ksmps_override){
+      csound->esr = (MYFLT) (O->sr_override ? O->sr_override : csound->esr);
+      csound->ekr = (MYFLT) (O->kr_override ? O->kr_override : csound->ekr);
+      csound->ksmps = (int) ((ensmps = ((MYFLT) csound->esr
+                                        / (MYFLT) csound->ekr)) + FL(0.5));
+      }
+      else {
+        csound->ksmps = (ensmps = O->ksmps_override);
+        if(O->sr_override) {
+          csound->ekr = O->sr_override / csound->ksmps;
+          csound->esr = O->sr_override;
+        }
+        else if(O->kr_override) {
+          csound->esr = O->kr_override * csound->ksmps;
+          csound->ekr = O->kr_override;
+        }
+        else {
+         csound->ekr = csound->esr / csound->ksmps;
+        }
+      }
+      
       /* chk consistency one more time */
       {
         char  s[256];
@@ -687,6 +649,9 @@ INSTRTXT *create_instrument0(CSOUND *csound, TREE *root,
         if (UNLIKELY(FLOAT_COMPARE(csound->esr, (double) csound->ekr * ensmps)))
           csoundDie(csound, Str("%s inconsistent sr, kr, ksmps"), s);
       }
+      csound->Message(csound, Str("sample rate overrides: "
+                                  "esr = %7.4f, ekr = %7.4f, ksmps = %d\n"),
+                      csound->esr, csound->ekr, csound->ksmps);
     }
 
     csound->tpidsr = TWOPI_F / csound->esr;               /* now set internal  */
@@ -702,6 +667,7 @@ INSTRTXT *create_instrument0(CSOUND *csound, TREE *root,
 
     if (csound->ksmps != DFLT_KSMPS) {
       reallocateVarPoolMemory(csound, engineState->varPool);
+      //csound->Message(csound, "recalculate varpool\n");
     }
     close_instrument(csound, engineState, ip);
 
@@ -773,6 +739,17 @@ INSTRTXT *create_global_instrument(CSOUND *csound, TREE *root,
     return ip;
 }
 
+int tree_contains_fn_p(CSOUND *csound, TREE* t)
+{
+    //print_tree(csound, "\ntree_contains_fn_p", t);
+    while (t!=NULL) {
+      if (t->type == T_OPCODE && strcmp(t->value->lexeme, "p")==0) return 1;
+      if (t->left  && tree_contains_fn_p(csound, t->left)) return 1;
+      if (t->right && tree_contains_fn_p(csound, t->right)) return 1;
+      t = t->next;
+    }
+    return 0;
+}
 
 /**
  * Create an Instrument (INSTRTXT) from the AST node given. Called from
@@ -792,7 +769,7 @@ INSTRTXT *create_instrument(CSOUND *csound, TREE *root,
     statements = root->right;
     ip->mdepends = 0;
     ip->opdstot = 0;
-
+    ip->nocheckpcnt = tree_contains_fn_p(csound, root->right);
     ip->pmax = 3L;
 
     /* Initialize */
@@ -871,7 +848,6 @@ void close_instrument(CSOUND *csound, ENGINE_STATE* engineState, INSTRTXT * ip)
 {
     OPTXT * bp, *current;
     int n;
-
     bp = (OPTXT *) csound->Calloc(csound, (int32)sizeof(OPTXT));
 
     bp->t.oentry = find_opcode(csound, "endin");        /*  send an endin to */
@@ -909,22 +885,48 @@ void free_instrtxt(CSOUND *csound, INSTRTXT *instrtxt)
         fdchclose(csound, active);
       if (active->auxchp != NULL)
         auxchfree(csound, active);
+      free_instr_var_memory(csound, active);
+      if(active->opcod_iobufs != NULL)
+        csound->Free(csound, active->opcod_iobufs);
       csound->Free(csound, active);
       active = nxt;
     }
     OPTXT *t = ip->nxtop;
     while (t) {
           OPTXT *s = t->nxtop;
+          TEXT *ttp = &t->t;
+          //printf("%s \n",  ttp->opcod);
+          ARG* current = ttp->outArgs;
+          while (current != NULL) {
+              ARG *tmp = current;
+              //printf("delete %p \n", tmp);
+              current = current->next;
+              csound->Free(csound, tmp);
+            }
+          csound->Free(csound, t->t.outlist);
+          current = ttp->inArgs;
+            while (current  != NULL) {
+              ARG *tmp = current;
+              //printf("delete %p \n", tmp);
+              current = current->next;
+              csound->Free(csound, tmp);
+           }
+          csound->Free(csound, t->t.inlist);
           csound->Free(csound, t);
           t = s;
         }
-    // myflt_pool_free(csound, ip->varPool);
-    /* VL: 19-12-13
-       an instrument varpool memory is allocated in the instrument block
-       so deallocating the pool is not really right */
-    // deleteVarPoolMemory(csound, ip->varPool);
-     //csound->Free(csound, ip->varPool); /* need to delete the varPool memory */
-     csound->Free(csound, ip);
+
+    csound->Free(csound, ip->t.outlist);
+    csound->Free(csound, ip->t.inlist);
+    CS_VARIABLE *var = ip->varPool->head;
+    while(var != NULL){
+      CS_VARIABLE *tmp = var;
+      var = var->next;
+      csound->Free(csound, tmp->varName);
+    }
+
+    csoundFreeVarPool(csound, ip->varPool);
+    csound->Free(csound, ip);
      if (csound->oparms->odebug)
        csound->Message(csound, Str("-- deleted instr from deadpool \n"));
 }
@@ -988,9 +990,10 @@ void add_to_deadpool(CSOUND *csound, INSTRTXT *instrtxt)
    If named instr exists, it is replaced.
 */
 int named_instr_alloc(CSOUND *csound, char *s, INSTRTXT *ip,
-                      int32 insno, ENGINE_STATE *engineState)
+                      int32 insno, ENGINE_STATE *engineState, int merge)
 {
     INSTRNAME *inm, *inm2, *inm_head;
+    int ret = 1;
 
     if (UNLIKELY(!engineState->instrumentNames))
         engineState->instrumentNames = cs_hash_table_create(csound);
@@ -999,6 +1002,8 @@ int named_instr_alloc(CSOUND *csound, char *s, INSTRTXT *ip,
     inm = cs_hash_table_get(csound, engineState->instrumentNames, s);
     if (inm != NULL) {
       int i;
+      ret = 0;
+      if(!merge) return ret;
        inm->ip->isNew = 1;
       /* redefinition does not raise an error now, just a warning */
        if (csound->oparms->odebug)
@@ -1026,7 +1031,7 @@ int named_instr_alloc(CSOUND *csound, char *s, INSTRTXT *ip,
       /* no active instances */
       if (active == NULL) {
         if (csound->oparms->odebug)
-          csound->Message(csound, "no active instances \n");
+          csound->Message(csound, Str("no active instances \n"));
         free_instrtxt(csound, engineState->instrtxtp[inm->instno]);
         engineState->instrtxtp[inm->instno] = NULL;
       }
@@ -1061,7 +1066,7 @@ int named_instr_alloc(CSOUND *csound, char *s, INSTRTXT *ip,
       csound->Message(csound,
                       "named instr name = \"%s\", txtp = %p,\n",
                       s, (void*) ip);
-    return 1;
+    return ret;
 }
 
 /**
@@ -1122,7 +1127,7 @@ void named_instr_assign_numbers(CSOUND *csound, ENGINE_STATE *engineState)
     allocated and if so expand pool of instruments
 */
 void insert_instrtxt(CSOUND *csound, INSTRTXT *instrtxt,
-                     int32 instrNum, ENGINE_STATE *engineState)
+                     int32 instrNum, ENGINE_STATE *engineState, int merge)
 {
     int i;
 
@@ -1148,7 +1153,9 @@ void insert_instrtxt(CSOUND *csound, INSTRTXT *instrtxt,
     if (UNLIKELY(engineState->instrtxtp[instrNum] != NULL)) {
       instrtxt->isNew = 1;
       /* redefinition does not raise an error now, just a warning */
-      if (instrNum && csound->oparms->odebug)
+      /* unless we are not merging */
+      if(!merge) synterr(csound, "instr %d redefined\n", instrNum);
+       if (instrNum && csound->oparms->odebug)
         csound->Warning(csound,
                         Str("instr %ld redefined, replacing previous definition"),
                         instrNum);
@@ -1170,14 +1177,16 @@ void insert_instrtxt(CSOUND *csound, INSTRTXT *instrtxt,
         }
         active = active->nxtinstance;
       }
-      /* no active instances */
-      if (active == NULL || instrNum == 0) {
 
+      /* no active instances */
+      /* instr0 is freed elsewhere */
+      if (active == NULL  && instrNum != 0) {
        if (csound->oparms->odebug)
        csound->Message(csound,
                        Str("no active instances of instr %d \n"), instrNum);
-        free_instrtxt(csound, engineState->instrtxtp[instrNum]);
+       free_instrtxt(csound, engineState->instrtxtp[instrNum]);
       }
+
       /* err++; continue; */
     }
  end:
@@ -1248,19 +1257,20 @@ int engineState_merge(CSOUND *csound, ENGINE_STATE *engineState)
 {
     int i, end = engineState->maxinsno;
     ENGINE_STATE *current_state = &csound->engineState;
-    INSTRTXT *current;
+    INSTRTXT *current, *old_instr0;
     int count;
 
-    cs_hash_table_merge(csound,
-                        current_state->stringPool, engineState->stringPool);
+    //cs_hash_table_merge(csound,
+    //                current_state->stringPool, engineState->stringPool);
 
     for (count = 0; count < engineState->constantsPool->count; count++) {
-      if (csound->oparms->odebug)
+    if (csound->oparms->odebug)
         csound->Message(csound, Str(" merging constants %d) %f\n"),
-                        count, engineState->constantsPool->values[count]);
-      myflt_pool_find_or_add(csound, current_state->constantsPool,
-                             engineState->constantsPool->values[count]);
+                        count, engineState->constantsPool->values[count].value);
+        myflt_pool_find_or_add(csound, current_state->constantsPool,
+                       engineState->constantsPool->values[count].value);
     }
+
     CS_VARIABLE* gVar = engineState->varPool->head;
     while (gVar != NULL) {
       CS_VARIABLE* var;
@@ -1280,13 +1290,24 @@ int engineState_merge(CSOUND *csound, ENGINE_STATE *engineState)
         /* when disposing of the engineState global vars, we do not
            delete the memBlock */
         var->memBlock = gVar->memBlock;
+        //csound->Message(csound, Str(" adding %d) %s:%s\n"), count,
+        //          gVar->varName, gVar->varType->varTypeName);
+         gVar = gVar->next;
+      } else {
+        // if variable exists
+        // free variable mem block
+        // printf("free %p \n", gVar->memBlock);
+        // the CS_VARIABLE itself will be freed on engine_free()
+        csound->Free(csound, gVar->memBlock);
+        csound->Free(csound, gVar->varName);
+        gVar = gVar->next;
       }
-      gVar = gVar->next;
     }
 
     /* merge opcodinfo */
     insert_opcodes(csound, csound->opcodeInfo, current_state);
-    insert_instrtxt(csound,engineState->instrtxtp[0],0,current_state);
+    old_instr0 = current_state->instrtxtp[0];
+    insert_instrtxt(csound,engineState->instrtxtp[0],0,current_state,1);
     for (i=1; i < end; i++){
       current = engineState->instrtxtp[i];
       if (current != NULL){
@@ -1296,13 +1317,13 @@ int engineState_merge(CSOUND *csound, ENGINE_STATE *engineState)
           /* a first attempt at this merge is to make it use
              insert_instrtxt again */
           /* insert instrument in current engine */
-          insert_instrtxt(csound,current,i,current_state);
+          insert_instrtxt(csound,current,i,current_state,1);
         }
         else {
           if (csound->oparms->odebug)
             csound->Message(csound, Str("merging instr %s \n"), current->insname);
           /* allocate a named_instr string in the current engine */
-          named_instr_alloc(csound,current->insname,current,-1L,current_state);
+          named_instr_alloc(csound,current->insname,current,-1L,current_state,1);
         }
       }
     }
@@ -1338,22 +1359,26 @@ int engineState_merge(CSOUND *csound, ENGINE_STATE *engineState)
       }
     }
     (&(current_state->instxtanchor))->nxtinstxt = csound->instr0;
+    /* now free old instr 0 */
+    free_instrtxt(csound, old_instr0);
     return 0;
 }
 
 int engineState_free(CSOUND *csound, ENGINE_STATE *engineState)
 {
-    /* FIXME: we need functions to deallocate stringPool, constantPool */
+
     csound->Free(csound, engineState->instrumentNames);
     myflt_pool_free(csound, engineState->constantsPool);
-    /* purposely using csound->Free and not cs_hash_table_free as keys will have
-     been merged into csound->engineState */
-    csound->Free(csound, engineState->stringPool);
-    csound->Free(csound, engineState->varPool);
+    csoundFreeVarPool(csound, engineState->varPool);
+    csound->Free(csound, engineState->instrtxtp);
     csound->Free(csound, engineState);
     return 0;
 }
 
+void free_typetable(CSOUND *csound, TYPE_TABLE *typeTable){
+      cs_cons_free_complete(csound, typeTable->labelList);
+      csound->Free(csound, typeTable);
+}
 /**
  * Compile the given TREE node into structs
 
@@ -1397,39 +1422,51 @@ PUBLIC int csoundCompileTree(CSOUND *csound, TREE *root)
                                           typeTable->instr0LocalPool);
       cs_hash_table_put_key(csound, engineState->stringPool, "\"\"");
       prvinstxt = &(engineState->instxtanchor);
-       engineState->instrtxtp =
+      engineState->instrtxtp =
       (INSTRTXT **) csound->Calloc(csound, (1 + engineState->maxinsno)
                             * sizeof(INSTRTXT*));
        prvinstxt = prvinstxt->nxtinstxt = csound->instr0;
-      insert_instrtxt(csound, csound->instr0, 0, engineState);
+       insert_instrtxt(csound, csound->instr0, 0, engineState,0);
     }
     else {
       engineState = (ENGINE_STATE *) csound->Calloc(csound, sizeof(ENGINE_STATE));
-      engineState->stringPool = cs_hash_table_create(csound);
+      engineState->stringPool = csound->engineState.stringPool;
+                                //cs_hash_table_create(csound);
       engineState->constantsPool = myflt_pool_create(csound);
       engineState->varPool = typeTable->globalPool;
       prvinstxt = &(engineState->instxtanchor);
-       engineState->instrtxtp =
+      engineState->instrtxtp =
       (INSTRTXT **) csound->Calloc(csound, (1 + engineState->maxinsno) *
                                     sizeof(INSTRTXT*));
        /* VL: allowing global code to be evaluated in
           subsequent compilations */
-      csound->instr0 = create_global_instrument(csound, current, engineState,
-                                          typeTable->instr0LocalPool);
-      insert_instrtxt(csound, csound->instr0, 0, engineState);
-      prvinstxt = prvinstxt->nxtinstxt = csound->instr0;
+       csound->instr0 = create_global_instrument(csound, current, engineState,
+                                         typeTable->instr0LocalPool);
+
+        insert_instrtxt(csound, csound->instr0, 0, engineState,1);
+
+       prvinstxt = prvinstxt->nxtinstxt = csound->instr0;
       //engineState->maxinsno = 1;
     }
 
+
+    // allocate memory for global vars
+    // if this variable already exists,
+    // memory will be freed on merge.
     var = typeTable->globalPool->head;
     while(var != NULL) {
-      var->memBlock = (void *) csound->Calloc(csound, var->memBlockSize);
+      size_t memSize = sizeof(CS_VAR_MEM) - sizeof(MYFLT) + var->memBlockSize;
+      CS_VAR_MEM* varMem = (CS_VAR_MEM*) csound->Calloc(csound, memSize);
+      //printf("alloc %p -- %s\n", varMem, var->varName);
+      varMem->varType = var->varType;
+      var->memBlock = varMem;
       if (var->initializeVariableMemory != NULL) {
-        var->initializeVariableMemory(var, (MYFLT *)(var->memBlock));
-      } else  memset(var->memBlock , 0, var->memBlockSize);
-      var = var->next;
+        var->initializeVariableMemory(var, &varMem->value);
+      } else  memset(&varMem->value , 0, var->memBlockSize);
+        var = var->next;
     }
 
+
     while (current != NULL) {
 
       switch (current->type) {
@@ -1450,7 +1487,7 @@ PUBLIC int csoundCompileTree(CSOUND *csound, TREE *root)
                                                        instr 1
                                                     */
           int32 instrNum = (int32)current->left->value->value;
-          insert_instrtxt(csound, instrtxt, instrNum, engineState);
+          insert_instrtxt(csound, instrtxt, instrNum, engineState,0);
 
         }
         else if (current->left->type == T_IDENT){ /* named instrument, eg.:
@@ -1466,8 +1503,15 @@ PUBLIC int csoundCompileTree(CSOUND *csound, TREE *root)
                 if (UNLIKELY(!check_instr_name(c))) {
                   synterr(csound, Str("invalid name for instrument"));
                 }
-                named_instr_alloc(csound,c,instrtxt, insno_priority,
-                                  engineState);
+                //named_instr_alloc(csound,c,instrtxt, insno_priority,
+                //                engineState,0);
+                /* VL 10.10.14: check for redefinition */
+                if (UNLIKELY(!named_instr_alloc(csound, c,
+                                                instrtxt, insno_priority,
+                                                engineState, 0))) {
+                  synterr(csound, Str("instr %s redefined\n"), c);
+                }
+
                 instrtxt->insname = csound->Malloc(csound, strlen(c) + 1);
                 strcpy(instrtxt->insname, c);
         }
@@ -1482,7 +1526,7 @@ PUBLIC int csoundCompileTree(CSOUND *csound, TREE *root)
 
               if (p->left->type == INTEGER_TOKEN) {
                 insert_instrtxt(csound, instrtxt, p->left->value->value,
-                                engineState);
+                                engineState,0);
               }
               else if (p->left->type == T_IDENT) {
                 int32  insno_priority = -1L;
@@ -1496,7 +1540,7 @@ PUBLIC int csoundCompileTree(CSOUND *csound, TREE *root)
                 }
                 if (UNLIKELY(!named_instr_alloc(csound, c,
                                                 instrtxt, insno_priority,
-                                                engineState))) {
+                                                engineState,0))) {
                   synterr(csound, Str("instr %s redefined"), c);
                 }
                 instrtxt->insname = csound->Malloc(csound, strlen(c) + 1);
@@ -1505,7 +1549,7 @@ PUBLIC int csoundCompileTree(CSOUND *csound, TREE *root)
             }
             else {
               if (p->type == INTEGER_TOKEN) {
-                insert_instrtxt(csound, instrtxt, p->value->value, engineState);
+                insert_instrtxt(csound, instrtxt, p->value->value, engineState,0);
               }
               else if (p->type == T_IDENT) {
                 int32  insno_priority = -1L;
@@ -1519,7 +1563,7 @@ PUBLIC int csoundCompileTree(CSOUND *csound, TREE *root)
                 }
                 if (UNLIKELY(!named_instr_alloc(csound, c,
                                                 instrtxt, insno_priority,
-                                                engineState))) {
+                                                engineState,0))) {
                   synterr(csound, Str("instr %s redefined"), c);
                 }
                 instrtxt->insname = csound->Malloc(csound, strlen(c) + 1);
@@ -1575,6 +1619,7 @@ PUBLIC int csoundCompileTree(CSOUND *csound, TREE *root)
       csound->Warning(csound, Str("%d syntax errors in orchestra.  "
                               "compilation invalid\n"),
                   csound->synterrcnt);
+      free_typetable(csound, typeTable);
       return CSOUND_ERROR;
     }
 
@@ -1595,7 +1640,7 @@ PUBLIC int csoundCompileTree(CSOUND *csound, TREE *root)
       /* run global i-time code */
       init0(csound);
       csound->ids = ids;
-
+      free_typetable(csound, typeTable);
     }
     else {
       /* first compilation */
@@ -1626,27 +1671,23 @@ PUBLIC int csoundCompileTree(CSOUND *csound, TREE *root)
 
       CS_VARIABLE *var;
       var = csoundFindVariableWithName(csound, engineState->varPool, "sr");
-      *((MYFLT *)(var->memBlock)) = csound->esr;
+      var->memBlock->value = csound->esr;
       var = csoundFindVariableWithName(csound, engineState->varPool, "kr");
-      *((MYFLT *)(var->memBlock)) = csound->ekr;
+      var->memBlock->value = csound->ekr;
       var = csoundFindVariableWithName(csound, engineState->varPool, "ksmps");
-      *((MYFLT *)(var->memBlock)) = csound->ksmps;
+      var->memBlock->value = csound->ksmps;
       var = csoundFindVariableWithName(csound, engineState->varPool, "nchnls");
-      *((MYFLT *)(var->memBlock)) = csound->nchnls;
+      var->memBlock->value = csound->nchnls;
       if (csound->inchnls<0) csound->inchnls = csound->nchnls;
       var = csoundFindVariableWithName(csound, engineState->varPool, "nchnls_i");
-      *((MYFLT *)(var->memBlock)) = csound->inchnls;
+      var->memBlock->value = csound->inchnls;
       var = csoundFindVariableWithName(csound, engineState->varPool, "0dbfs");
-      *((MYFLT *)(var->memBlock)) = csound->e0dbfs;
-
-
+      var->memBlock->value = csound->e0dbfs;
     }
-
     if (csound->init_pass_threadlock)
       csoundUnlockMutex(csound->init_pass_threadlock);
     /* notify API lock  */
     csoundUnlockMutex(csound->API_lock);
-
     return CSOUND_SUCCESS;
 }
 
@@ -1667,7 +1708,7 @@ PUBLIC MYFLT csoundEvalCode(CSOUND *csound, const char *str)
 #endif
 }
 
-
+extern void sanitize(CSOUND *csound);
 /**
     Parse and compile an orchestra given on an string (OPTIONAL)
     if str is NULL the string is taken from the internal corfile
@@ -1676,14 +1717,18 @@ PUBLIC MYFLT csoundEvalCode(CSOUND *csound, const char *str)
 */
 PUBLIC int csoundCompileOrc(CSOUND *csound, const char *str)
 {
-    int retVal;
+    int retVal=1;
     TREE *root = csoundParseOrc(csound, str);
     if (LIKELY(root != NULL)) {
-      retVal = csoundCompileTree(csound, root);
+     retVal = csoundCompileTree(csound, root);
+     // Sanitise semantic sets here
+     sanitize(csound);
+     csoundDeleteTree(csound, root);
+    }
+    else {
+      // csoundDeleteTree(csound, root);
+     return  CSOUND_ERROR;
     }
-    else
-      return  CSOUND_ERROR;
-    csoundDeleteTree(csound, root);
 
     if (UNLIKELY(csound->oparms->odebug))
       debugPrintCsound(csound);
@@ -1737,7 +1782,6 @@ static void insprep(CSOUND *csound, INSTRTXT *tp, ENGINE_STATE *engineState)
             arg->next = NULL;
           }
         }
-        ttp->outArgCount = argCount(ttp->outArgs);
       }
       if ((inlist = ttp->inlist) == NULL || !inlist->count)
         ttp->inArgs = NULL;
@@ -1761,18 +1805,20 @@ static void insprep(CSOUND *csound, INSTRTXT *tp, ENGINE_STATE *engineState)
 
           if (ttp->inArgs == NULL) {
             ttp->inArgs = arg;
+            //printf("yinarg %p -- opcode %s \n", arg, ttp->opcod);
           } else {
             ARG* current = ttp->inArgs;
+            //printf("xinarg %p %p -- opcode %s \n", current, arg, ttp->opcod);
             while(current->next != NULL) {
+              //printf("inarg %p %p -- opcode %s \n", current, arg, ttp->opcod);
               current = current->next;
             }
             current->next = arg;
+
             arg->next = NULL;
           }
         }
 
-        ttp->inArgCount = argCount(ttp->inArgs);
-
         if (ttp->oentry == pset) {
           MYFLT* fp1;
           int n;
@@ -1797,7 +1843,7 @@ static void insprep(CSOUND *csound, INSTRTXT *tp, ENGINE_STATE *engineState)
             switch (inArgs->type) {
               case ARG_CONSTANT:
 
-                *fp1++ = engineState->constantsPool->values[inArgs->index];
+                *fp1++ = engineState->constantsPool->values[inArgs->index].value;
                 break;
 
 //                      case ARG_LOCAL:
@@ -1826,7 +1872,11 @@ static void insprep(CSOUND *csound, INSTRTXT *tp, ENGINE_STATE *engineState)
 
           csound->Message(csound, "\n");
         }
-
+        //printf("delete %p \n", argStringParts);
+        for(n=0; argStringParts[n] != NULL; n++) {
+          //printf("delete %p \n", argStringParts[n]);
+          csound->Free(csound, argStringParts[n]);
+        }
         csound->Free(csound, argStringParts);
       }
 
@@ -1853,6 +1903,7 @@ static void lgbuild(CSOUND *csound, INSTRTXT* ip, char *s,
       temp = csound->Calloc(csound, strlen(s) + 1);
       unquote_string(temp, s);
       cs_hash_table_put_key(csound, engineState->stringPool, temp);
+      csound->Free(csound, temp);
     }
 }
 
@@ -1878,16 +1929,21 @@ static ARG* createArg(CSOUND *csound, INSTRTXT* ip,
     if ((c >= '1' && c <= '9') || c == '.' || c == '-' || c == '+' ||
         (c == '0' && strcmp(s, "0dbfs") != 0)) {
       arg->type = ARG_CONSTANT;
-
+      //printf("create constant %p: %c \n", arg, c);
       arg->index = myflt_pool_find_or_addc(csound, engineState->constantsPool, s);
     } else if (c == '"') {
-      STRINGDAT *str = csound->Calloc(csound, sizeof(STRINGDAT));
+      size_t memSize = sizeof(CS_VAR_MEM) - sizeof(MYFLT) + sizeof(STRINGDAT);
+      CS_VAR_MEM* varMem = csound->Calloc(csound, memSize);
+      STRINGDAT *str = (STRINGDAT*)&varMem->value;
+      //printf("create string %p: %s \n", arg, str->data);
+      varMem->varType = (CS_TYPE*)&CS_VAR_TYPE_S;
       arg->type = ARG_STRING;
       temp = csound->Calloc(csound, strlen(s) + 1);
       unquote_string(temp, s);
       str->data = cs_hash_table_get_key(csound,
                                         csound->engineState.stringPool, temp);
       str->size = strlen(temp) + 1;
+      csound->Free(csound, temp);
       arg->argPtr = str;
       if (str->data == NULL) {
         str->data = cs_hash_table_put_key(csound, engineState->stringPool, temp);
@@ -1912,16 +1968,18 @@ static ARG* createArg(CSOUND *csound, INSTRTXT* ip,
       //|| string_pool_indexof(csound->engineState.stringPool, s) > 0) {
       arg->type = ARG_GLOBAL;
       arg->argPtr = csoundFindVariableWithName(csound, engineState->varPool, s);
-
+      //printf("create global %p: %s \n", arg->argPtr, s);
     }
     else {
       arg->type = ARG_LOCAL;
       arg->argPtr = csoundFindVariableWithName(csound, ip->varPool, s);
+      //printf("create local %p: %s \n", arg, s);
       if (arg->argPtr == NULL) {
         csound->Message(csound, Str("Missing local arg: %s\n"), s);
       }
     }
     /*    csound->Message(csound, " [%s -> %d (%x)]\n", s, indx, indx); */
+
     return arg;
 }
 
@@ -2002,7 +2060,7 @@ void debugPrintCsound(CSOUND* csound)
     count = 0;
     for(count = 0; count < csound->engineState.constantsPool->count; count++) {
       csound->Message(csound, "    %d) %f\n",
-                      count, csound->engineState.constantsPool->values[count]);
+                      count, csound->engineState.constantsPool->values[count].value);
     }
 
     csound->Message(csound, "Global Variables:\n");
