@@ -58,6 +58,8 @@ char* convert_internal_to_external(CSOUND* csound, char* arg);
 char* convert_external_to_internal(CSOUND* csound, char* arg);
 void do_baktrace(CSOUND *csound, uint64_t files);
 
+const char* SYNTHESIZED_ARG = "_synthesized";
+
 char* cs_strdup(CSOUND* csound, char* str) {
     size_t len;
     char* retVal;
@@ -104,7 +106,7 @@ char* get_expression_opcode_type(CSOUND* csound, TREE* tree) {
     case '/':
       return "##div";
     case '^':
-      return "pow";
+      return "##pow";
     case S_UMINUS:
       return "##mul";
     case '|':
@@ -198,6 +200,34 @@ char *check_annotated_type(CSOUND* csound, OENTRIES* entries,
     return NULL;
 }
 
+static int isirate(/*CSOUND *csound,*/ TREE *t)
+{                  /* check that argument is an i-rate constant or variable */
+    //print_tree(csound, "isirate",  t);
+    if (t->type == INTEGER_TOKEN) {
+      //printf("integer case\n");
+      return 1;
+    }
+    else if (t->type == T_IDENT) {
+      //printf("identifier case\n");
+      if (t->value->lexeme[0] != 'p' &&
+          t->value->lexeme[0] != 'i' &&
+          (t->value->lexeme[0] != 'g' ||
+           t->value->lexeme[1] != 'i')) return 0;
+      return 1;
+    }
+    else if (t->type == T_ARRAY) {
+      //printf("array case\n");
+      if (isirate(/*csound, */t->right)==0) return 0;
+      t = t->next;
+      while (t) {
+        //printf("t=%p t->type=%d\n", t, t->type);
+        if (isirate(/*csound,*/ t)==0) return 0;
+        t = t->next;
+      }
+      return 1;
+    }
+    else return 0;
+}
 
 /* This function gets arg type with checking type table */
 char* get_arg_type2(CSOUND* csound, TREE* tree, TYPE_TABLE* typeTable)
@@ -222,11 +252,12 @@ char* get_arg_type2(CSOUND* csound, TREE* tree, TYPE_TABLE* typeTable)
                                                         typeTable);
           char* argString = strcat(leftArgType, rightArgType);
 
+          OENTRIES* opentries = find_opcode2(csound, "##array_get");
           char* outype = resolve_opcode_get_outarg(csound,
-                                                   find_opcode2(csound,
-                                                                "##array_get"),
+                                                   opentries,
                                                    argString);
 
+          csound->Free(csound, opentries);
           if (UNLIKELY(outype == NULL)) {
             synterr(csound,
                     Str("unable to find array operator for "
@@ -235,7 +266,8 @@ char* get_arg_type2(CSOUND* csound, TREE* tree, TYPE_TABLE* typeTable)
             do_baktrace(csound, tree->locn);
             return NULL;
           }
-
+          csound->Free(csound, leftArgType);
+          csound->Free(csound, rightArgType);
           return cs_strdup(csound, outype);
         }
       }
@@ -257,10 +289,12 @@ char* get_arg_type2(CSOUND* csound, TREE* tree, TYPE_TABLE* typeTable)
 
         snprintf(condInTypes, 64, "%s%s%s", ans, arg1, arg2);
 
+        OENTRIES* opentries = find_opcode2(csound, ":cond");
         out = resolve_opcode_get_outarg(csound,
-                                        find_opcode2(csound, ":cond"),
+                                        opentries,
                                         condInTypes);
 
+        csound->Free(csound, opentries);
         if (UNLIKELY(out == NULL)) {
           synterr(csound,
                   Str("unable to find ternary operator for "
@@ -270,6 +304,9 @@ char* get_arg_type2(CSOUND* csound, TREE* tree, TYPE_TABLE* typeTable)
           return NULL;
         }
 
+        csound->Free(csound, arg1);
+        csound->Free(csound, arg2);
+        csound->Free(csound, ans);
         return cs_strdup(csound, out);
 
       }
@@ -279,7 +316,9 @@ char* get_arg_type2(CSOUND* csound, TREE* tree, TYPE_TABLE* typeTable)
         //print_tree(csound, "i()", tree);
         if (tree->right->type == T_ARRAY &&
             tree->right->left->type == T_IDENT &&
-            tree->right->right->type == INTEGER_TOKEN) {}
+            isirate(/*csound,*/ tree->right->right)) {
+          //printf("OK array case\n");
+        }
         else
           if (UNLIKELY(tree->right->type != LABEL_TOKEN))
             synterr(csound,
@@ -306,7 +345,8 @@ char* get_arg_type2(CSOUND* csound, TREE* tree, TYPE_TABLE* typeTable)
           do_baktrace(csound, tree->locn);
           return NULL;
         }
-
+        csound->Free(csound, argTypeRight);
+        csound->Free(csound, entries);
         return cs_strdup(csound, out);
 
       }
@@ -332,7 +372,6 @@ char* get_arg_type2(CSOUND* csound, TREE* tree, TYPE_TABLE* typeTable)
 
         OENTRIES* entries = find_opcode2(csound, opname);
 
-
         argTypeLeft = convert_internal_to_external(csound, argTypeLeft);
         argTypeRight = convert_internal_to_external(csound, argTypeRight);
 
@@ -346,15 +385,21 @@ char* get_arg_type2(CSOUND* csound, TREE* tree, TYPE_TABLE* typeTable)
         inArgTypes[len1 + len2] = '\0';
 
         out = resolve_opcode_get_outarg(csound, entries, inArgTypes);
+        csound->Free(csound, entries);
 
         if (UNLIKELY(out == NULL)) {
           synterr(csound, Str("error: opcode '%s' for expression with arg "
                               "types %s not found, line %d \n"),
                   opname, inArgTypes, tree->line);
           do_baktrace(csound, tree->locn);
+          free(inArgTypes);
           return NULL;
         }
 
+        csound->Free(csound, argTypeLeft);
+        csound->Free(csound, argTypeRight);
+
+        free(inArgTypes);
         return cs_strdup(csound, out);
 
       } else {
@@ -393,6 +438,7 @@ char* get_arg_type2(CSOUND* csound, TREE* tree, TYPE_TABLE* typeTable)
       inArgTypes[len1 + len2] = '\0';
 
       out = resolve_opcode_get_outarg(csound, entries, inArgTypes);
+      csound->Free(csound, entries);
 
       if (UNLIKELY(out == NULL)) {
         synterr(csound, Str("error: boolean expression '%s' with arg "
@@ -402,6 +448,9 @@ char* get_arg_type2(CSOUND* csound, TREE* tree, TYPE_TABLE* typeTable)
         free(inArgTypes);
         return NULL;
       }
+
+      csound->Free(csound, argTypeLeft);
+      csound->Free(csound, argTypeRight);
       free(inArgTypes);
       return cs_strdup(csound, out);
 
@@ -726,8 +775,18 @@ int check_in_args(CSOUND* csound, char* inArgsFound, char* opInArgs) {
         }
 
       }
-
+      //printf("delete %p \n", argsFound);
+       int n;
+        for(n=0; argsFound[n] != NULL; n++) {
+          // printf("delete %p \n", argsFound[n]);
+          csound->Free(csound, argsFound[n]);
+        }
       csound->Free(csound, argsFound);
+      //printf("delete %p \n", argsRequired);
+                for(n=0; argsRequired[n] != NULL; n++) {
+                  //printf("delete %p \n", argsRequired[n]);
+          csound->Free(csound, argsRequired[n]);
+        }
       csound->Free(csound, argsRequired);
 
       return returnVal;
@@ -843,8 +902,18 @@ int check_out_args(CSOUND* csound, char* outArgsFound, char* opOutArgs)
           returnVal = 1;
         }
       }
-
+      //printf("delete %p \n", argsFound);
+       int n;
+        for(n=0; argsFound[n] != NULL; n++) {
+          // printf("delete %p \n", argsFound[n]);
+          csound->Free(csound, argsFound[n]);
+        }
       csound->Free(csound, argsFound);
+      //printf("delete %p \n", argsRequired);
+                for(n=0; argsRequired[n] != NULL; n++) {
+                  //printf("delete %p \n", argsRequired[n]);
+          csound->Free(csound, argsRequired[n]);
+        }
       csound->Free(csound, argsRequired);
 
       return returnVal;
@@ -1009,7 +1078,7 @@ char* get_arg_string_from_tree(CSOUND* csound, TREE* tree,
         //FIXME - fix if argType is NULL and remove the below hack
         if(argType == NULL) {
             argsLen += 1;
-            argTypes[index++] = "@";
+            argTypes[index++] = cs_strdup(csound, "@");
         } else {
             argType = convert_internal_to_external(csound, argType);
             argsLen += strlen(argType);
@@ -1027,10 +1096,13 @@ char* get_arg_string_from_tree(CSOUND* csound, TREE* tree,
         int size = strlen(argTypes[i]);
         memcpy(temp, argTypes[i], size);
         temp += size;
+        csound->Free(csound, argTypes[i]);
     }
 
+
     argString[argsLen] = '\0';
 
+    csound->Free(csound, argTypes);
     return argString;
 
 }
@@ -1097,9 +1169,10 @@ int check_args_exist(CSOUND* csound, TREE* tree, TYPE_TABLE* typeTable) {
 
           //FIXME - this feels like a hack
           if (*argType == 'c' || *argType == 'r' || *argType == 'p') {
+            csound->Free(csound, argType);
             break;
           }
-
+          csound->Free(csound, argType);
           pool = (*varName == 'g') ?
             typeTable->globalPool : typeTable->localPool;
           var = csoundFindVariableWithName(csound, pool, varName);
@@ -1116,6 +1189,7 @@ int check_args_exist(CSOUND* csound, TREE* tree, TYPE_TABLE* typeTable) {
               return 0;
             }
           }
+
           break;
         case T_ARRAY:
           varName = current->left->value->lexeme;
@@ -1321,6 +1395,7 @@ int verify_opcode(CSOUND* csound, TREE* root, TYPE_TABLE* typeTable) {
     add_args(csound, root->left, typeTable);
 
     opcodeName = root->value->lexeme;
+    //printf("%p %p (%s) \n", root, root->value, opcodeName);
     leftArgString = get_arg_string_from_tree(csound, left, typeTable);
     rightArgString = get_arg_string_from_tree(csound, right, typeTable);
 
@@ -1336,6 +1411,9 @@ int verify_opcode(CSOUND* csound, TREE* root, TYPE_TABLE* typeTable) {
     if (UNLIKELY(entries == NULL || entries->count == 0)) {
       synterr(csound, Str("Unable to find opcode with name: %s\n"),
               root->value->lexeme);
+      if (entries != NULL) {
+        csound->Free(csound, entries);
+      }
       return 0;
     }
 
@@ -1357,11 +1435,18 @@ int verify_opcode(CSOUND* csound, TREE* root, TYPE_TABLE* typeTable) {
       csoundMessage(csound, Str("Line: %d\n"),
                     root->line);
       do_baktrace(csound, root->locn);
+
+      csound->Free(csound, leftArgString);
+      csound->Free(csound, rightArgString);
+      csound->Free(csound, entries);
+
       return 0;
     } else {
       root->markup = oentry;
     }
-
+    csound->Free(csound, leftArgString);
+    csound->Free(csound, rightArgString);
+    csound->Free(csound, entries);
     return 1;
 }
 
@@ -1393,6 +1478,7 @@ CONS_CELL* get_label_list(CSOUND* csound, TREE* root) {
 
       case ELSE_TOKEN:
       case UNTIL_TOKEN:
+      case WHILE_TOKEN:
         ret = get_label_list(csound, current->right);
         head = cs_cons_append(head, ret);
         break;
@@ -1465,9 +1551,10 @@ int verify_if_statement(CSOUND* csound, TREE* root, TYPE_TABLE* typeTable) {
         outArg = get_arg_type2(csound, current->left, typeTable);
 
         if (outArg == NULL || (*outArg != 'b' && *outArg != 'B')) {
+          csound->Free(csound, outArg);
           return 0;
         }
-
+        csound->Free(csound, outArg);
         current = (current->right == NULL) ? NULL : current->right->next;
       }
 
@@ -1489,7 +1576,7 @@ int verify_until_statement(CSOUND* csound, TREE* root, TYPE_TABLE* typeTable) {
 
     if (UNLIKELY(outArg == NULL || (*outArg != 'b' && *outArg != 'B'))) {
       synterr(csound,
-              Str("expression for until statement not a boolean "
+              Str("expression for until/while statement not a boolean "
                   "expression, line %d\n"),
               root->line);
       do_baktrace(csound, root->locn);
@@ -1498,6 +1585,84 @@ int verify_until_statement(CSOUND* csound, TREE* root, TYPE_TABLE* typeTable) {
     return 1;
 }
 
+/** Verifies if xin and xout statements are correct for UDO
+   needs to check:
+     xin/xout number of args matches UDO input/output arg specifications
+     xin/xout statements exist if UDO in and out args are not 0 */
+int verify_xin_xout(CSOUND *csound, TREE *udoTree, TYPE_TABLE *typeTable) {
+    if(udoTree->right == NULL) {
+        return 1;
+    }
+    TREE* outArgsTree = udoTree->left->left;
+    TREE* inArgsTree = udoTree->left->right;
+    TREE* current = udoTree->right;
+    TREE* xinArgs = NULL;
+    TREE* xoutArgs = NULL;
+    char* inArgs = inArgsTree->value->lexeme;
+    char* outArgs = outArgsTree->value->lexeme;
+    int i;
+
+    for (i = 0; i < strlen(inArgs);i++) {
+        if (inArgs[i] == 'K') {
+            inArgs[i] = 'k';
+        }
+    }
+
+    for (i = 0; i < strlen(outArgs);i++) {
+        if (outArgs[i] == 'K') {
+            outArgs[i] = 'k';
+        }
+    }
+
+    while(current != NULL) {
+        if (current->value != NULL) {
+            if (strcmp("xin", current->value->lexeme) == 0) {
+                if(xinArgs != NULL) {
+                    synterr(csound,
+                            Str("Multiple xin statements found. "
+                                "Only one is allowed."));
+                    return 0;
+                }
+                xinArgs = current->left;
+            }
+            if (strcmp("xout", current->value->lexeme) == 0) {
+                if(xoutArgs != NULL) {
+                    synterr(csound,
+                            Str("Multiple xout statements found. "
+                                "Only one is allowed."));
+                    return 0;
+                }
+                xoutArgs = current->right;
+            }
+        }
+        current = current->next;
+    }
+
+    char* inArgsFound = get_arg_string_from_tree(csound, xinArgs, typeTable);
+    char* outArgsFound = get_arg_string_from_tree(csound, xoutArgs, typeTable);
+
+
+    if (!check_in_args(csound, inArgsFound, inArgs)) {
+      if (!(strcmp("0", inArgs) == 0 && xinArgs == NULL)) {
+        synterr(csound,
+                Str("invalid xin statement for UDO: defined '%s', found '%s'\n"),
+                inArgs, inArgsFound);
+        return 0;
+      }
+    }
+
+    if (!check_out_args(csound, outArgsFound, outArgs)) {
+      if (!(strcmp("0", outArgs) == 0 && xoutArgs == NULL)) {
+        synterr(csound,
+                Str("invalid xout statement for UDO: defined '%s', found '%s'\n"),
+                outArgs, outArgsFound);
+        return 0;
+      }
+    }
+
+    return 1;
+}
+
 TREE* verify_tree(CSOUND * csound, TREE *root, TYPE_TABLE* typeTable)
 {
     TREE *anchor = NULL;
@@ -1505,9 +1670,13 @@ TREE* verify_tree(CSOUND * csound, TREE *root, TYPE_TABLE* typeTable)
     TREE *previous = NULL;
     TREE* newRight;
 
+
     CONS_CELL* parentLabelList = typeTable->labelList;
     typeTable->labelList = get_label_list(csound, root);
 
+    //if(root->value)
+    //printf("verify %p %p (%s) \n", root, root->value, root->value->lexeme);
+
     if (PARSER_DEBUG) csound->Message(csound, "Verifying AST\n");
 
     while (current != NULL) {
@@ -1551,6 +1720,11 @@ TREE* verify_tree(CSOUND * csound, TREE *root, TYPE_TABLE* typeTable)
             }
 
             current->right = newRight;
+
+            if(!verify_xin_xout(csound, current, typeTable)) {
+              return 0;
+            }
+
             newRight = NULL;
         }
 
@@ -1572,11 +1746,13 @@ TREE* verify_tree(CSOUND * csound, TREE *root, TYPE_TABLE* typeTable)
         continue;
 
       case UNTIL_TOKEN:
+      case WHILE_TOKEN:
         if (!verify_until_statement(csound, current, typeTable)) {
           return 0;
         }
 
-        current = expand_until_statement(csound, current, typeTable);
+        current = expand_until_statement(csound, current,
+                                         typeTable, current->type==WHILE_TOKEN);
 
         if (previous != NULL) {
           previous->next = current;
@@ -1724,6 +1900,8 @@ TREE* make_node(CSOUND *csound, int line, int locn, int type,
     ans->rate = -1;
     ans->line = line;
     ans->locn  = locn;
+    ans->markup = NULL;
+    //printf("make node %p %p %p\n", ans, ans->left, ans->right);
     //csound->DebugMsg(csound, "%s(%d) line = %d\n", __FILE__, __LINE__, line);
     return ans;
 }
@@ -1731,7 +1909,7 @@ TREE* make_node(CSOUND *csound, int line, int locn, int type,
 TREE* make_leaf(CSOUND *csound, int line, int locn, int type, ORCTOKEN *v)
 {
     TREE *ans;
-    ans = (TREE*)csound->Malloc(csound, sizeof(TREE));
+    ans = (TREE*)csound->Calloc(csound, sizeof(TREE));
     if (UNLIKELY(ans==NULL)) {
       /* fprintf(stderr, "Out of memory\n"); */
       exit(1);
@@ -1745,6 +1923,9 @@ TREE* make_leaf(CSOUND *csound, int line, int locn, int type, ORCTOKEN *v)
     ans->value = v;
     ans->line = line;
     ans->locn  = locn;
+    ans->markup = NULL;
+    //if(ans->value)
+    // printf("make leaf %p %p (%s) \n", ans, ans->value, ans->value->lexeme);
     csound->DebugMsg(csound, "%s(%d) line = %d\n", __FILE__, __LINE__, line);
     return ans;
 }
@@ -1753,12 +1934,14 @@ static void delete_tree(CSOUND *csound, TREE *l)
 {
     while (1) {
       TREE *old = l;
+
       if (UNLIKELY(l==NULL)) {
         return;
-      }
+      } //else printf("l = %p\n", l);
+
       if (l->value) {
         if (l->value->lexeme) {
-          //printf("Free %p (%s)\n", l->value->lexeme, l->value->lexeme);
+          //printf("Free %p %p (%s)\n", l, l->value, l->value->lexeme);
           csound->Free(csound, l->value->lexeme);
           //l->value->lexeme = NULL;
         }
@@ -1766,18 +1949,20 @@ static void delete_tree(CSOUND *csound, TREE *l)
         csound->Free(csound, l->value);
         //l->value = NULL;
       }
+      // printf("left %p right %p \n", l->left, l->right);
       delete_tree(csound, l->left);
       //l->left = NULL;
       delete_tree(csound, l->right);
       //l->right = NULL;
       l = l->next;
-      //printf("Free %p\n", old);
+      //printf("Free old %p next: %p\n", old, l);
       csound->Free(csound, old);
     }
 }
 
 PUBLIC void csoundDeleteTree(CSOUND *csound, TREE *tree)
 {
+  //printf("Tree %p\n", tree);
   delete_tree(csound, tree);
 }
 
@@ -1861,6 +2046,9 @@ void print_tree_i(CSOUND *csound, TREE *l, int n)
     case UNTIL_TOKEN:
       csound->Message(csound,"UNTIL_TOKEN:(%d:%s)\n",
                       l->line, csound->filedir[(l->locn)&0xff]); break;
+    case WHILE_TOKEN:
+      csound->Message(csound,"WHILE_TOKEN:(%d:%s)\n",
+                      l->line, csound->filedir[(l->locn)&0xff]); break;
     case DO_TOKEN:
       csound->Message(csound,"DO_TOKEN:(%d:%s)\n",
                       l->line, csound->filedir[(l->locn)&0xff]); break;
@@ -1926,6 +2114,9 @@ void print_tree_i(CSOUND *csound, TREE *l, int n)
     case T_INSTLIST:
       csound->Message(csound,"T_INSTLIST:(%d:%s)\n",
                       l->line, csound->filedir[(l->locn)&0xff]); break;
+    case '[':
+      csound->Message(csound,"[:(%d:%s)\n",
+                      l->line, csound->filedir[(l->locn)&0xff]); break;
     default:
       csound->Message(csound,"unknown:%d(%d:%s)\n",
                       l->type, l->line, csound->filedir[(l->locn)&0xff]);
@@ -1951,7 +2142,9 @@ static void print_tree_xml(CSOUND *csound, TREE *l, int n, int which)
       csound->Message(csound, " ");
     }
 
-    csound->Message(csound, "<tree%s type=\"%d\" ", child[which], l->type);
+    csound->Message(csound,
+                    "<tree%s (%p : %p) type=\"%d\" ",
+                    child[which],l, l->value, l->type);
 
     switch (l->type) {
     case ',':
@@ -2017,6 +2210,8 @@ static void print_tree_xml(CSOUND *csound, TREE *l, int n, int which)
       csound->Message(csound,"name=\"ELSE_TOKEN\""); break;
     case UNTIL_TOKEN:
       csound->Message(csound,"name=\"UNTIL_TOKEN\""); break;
+    case WHILE_TOKEN:
+      csound->Message(csound,"name=\"WHILE_TOKEN\""); break;
     case DO_TOKEN:
       csound->Message(csound,"name=\"DO_TOKEN\""); break;
     case OD_TOKEN:
@@ -2168,6 +2363,7 @@ void handle_optional_args(CSOUND *csound, TREE *l)
           case 'o':
             temp = make_leaf(csound, l->line, l->locn, INTEGER_TOKEN,
                              make_int(csound, "0"));
+            temp->markup = &SYNTHESIZED_ARG;
             if (l->right==NULL) l->right = temp;
             else appendToTree(csound, l->right, temp);
             break;
@@ -2175,12 +2371,14 @@ void handle_optional_args(CSOUND *csound, TREE *l)
           case 'p':
             temp = make_leaf(csound, l->line, l->locn, INTEGER_TOKEN,
                              make_int(csound, "1"));
+            temp->markup = &SYNTHESIZED_ARG;
             if (l->right==NULL) l->right = temp;
             else appendToTree(csound, l->right, temp);
             break;
           case 'q':
             temp = make_leaf(csound, l->line, l->locn, INTEGER_TOKEN,
                              make_int(csound, "10"));
+            temp->markup = &SYNTHESIZED_ARG;
             if (l->right==NULL) l->right = temp;
             else appendToTree(csound, l->right, temp);
             break;
@@ -2189,12 +2387,14 @@ void handle_optional_args(CSOUND *csound, TREE *l)
           case 'v':
             temp = make_leaf(csound, l->line, l->locn, NUMBER_TOKEN,
                              make_num(csound, ".5"));
+            temp->markup = &SYNTHESIZED_ARG;
             if (l->right==NULL) l->right = temp;
             else appendToTree(csound, l->right, temp);
             break;
           case 'h':
             temp = make_leaf(csound, l->line, l->locn, INTEGER_TOKEN,
                              make_int(csound, "127"));
+            temp->markup = &SYNTHESIZED_ARG;
             if (l->right==NULL) l->right = temp;
             else appendToTree(csound, l->right, temp);
             break;
@@ -2202,6 +2402,7 @@ void handle_optional_args(CSOUND *csound, TREE *l)
           case 'j':
             temp = make_leaf(csound, l->line, l->locn, INTEGER_TOKEN,
                              make_int(csound, "-1"));
+            temp->markup = &SYNTHESIZED_ARG;
             if (l->right==NULL) l->right = temp;
             else appendToTree(csound, l->right, temp);
             break;
@@ -2221,6 +2422,15 @@ void handle_optional_args(CSOUND *csound, TREE *l)
           incnt++;
         } while (incnt < nreqd);
       }
+      //      printf("delete %p \n", inArgParts);
+      if (inArgParts != NULL) {
+        int n;
+        for(n=0; inArgParts[n] != NULL; n++) {
+          //printf("delete %p \n", inArgParts[n]);
+          csound->Free(csound, inArgParts[n]);
+        }
+        csound->Free(csound, inArgParts);
+      }
     }
 }
 
