@@ -382,17 +382,17 @@ OENTRY opcodlst_1[] = {
   { "expsegr",S(EXPSEG),0,  3,      "k",    "iin",  xsgrset,kxpsegr,NULL },
   { "expsegr.a",S(EXPSEG),0,  5,      "a",    "iin",  xsgrset,NULL,expsegr },
   { "linen",  S(LINEN),0,   3,      "k",    "kiii", lnnset, klinen, NULL   },
-  { "linen.a",  S(LINEN),0,   5,      "a",    "aiii", lnnset, NULL, linen   },
-  { "linen.x",  S(LINEN),0,   5,      "a",    "kiii", lnnset, NULL, linen   },
+  { "linen.a",  S(LINEN),0,   5,      "a",    "aiii", alnnset, NULL, linen   },
+  { "linen.x",  S(LINEN),0,   5,      "a",    "kiii", alnnset, NULL, linen   },
   { "linenr", S(LINENR),0,  3,      "k",    "kiii", lnrset, klinenr,NULL },
-  { "linenr.a", S(LINENR),0,  5,      "a",    "aiii", lnrset, NULL,linenr  },
-  { "linenr.x", S(LINENR),0,  5,      "a",    "kiii", lnrset, NULL,linenr  },
+  { "linenr.a", S(LINENR),0,  5,      "a",    "aiii", alnrset, NULL,linenr  },
+  { "linenr.x", S(LINENR),0,  5,      "a",    "kiii", alnrset, NULL,linenr  },
   { "envlpx", S(ENVLPX), TR, 3,     "k","kiiiiiio", evxset, knvlpx, NULL },
   { "envlpxr", S(ENVLPR),TR, 3,     "k","kiiiiioo", evrset, knvlpxr, NULL },
-  { "envlpx.a", S(ENVLPX), TR, 5,     "a","kiiiiiio", evxset, NULL,envlpx  },
-  { "envlpxr.a", S(ENVLPR),TR, 5,     "a","aiiiiioo", evrset, NULL,envlpxr },
-  { "envlpx.x", S(ENVLPX), TR, 5,     "a","kiiiiiio", evxset, NULL,envlpx  },
-  { "envlpxr.x", S(ENVLPR),TR, 5,     "a","kiiiiioo", evrset, NULL,envlpxr },
+  { "envlpx.a", S(ENVLPX), TR, 5,     "a","aiiiiiio", aevxset, NULL,envlpx  },
+  { "envlpxr.a", S(ENVLPR),TR, 5,     "a","aiiiiioo", aevrset, NULL,envlpxr },
+  { "envlpx.x", S(ENVLPX), TR, 5,     "a","kiiiiiio", aevxset, NULL,envlpx  },
+  { "envlpxr.x", S(ENVLPR),TR, 5,     "a","kiiiiioo", aevrset, NULL,envlpxr },
   { "phasor", S(PHSOR),0,   5,      "a",    "xo",   phsset, NULL, phsor   },
   { "phasor.k", S(PHSOR),0,   3,     "k",   "ko",   phsset, kphsor, NULL  },
   { "ephasor", S(EPHSOR), 0,  5,   "aa",   "xko",  ephsset, NULL, ephsor  },
@@ -569,6 +569,9 @@ OENTRY opcodlst_1[] = {
   { "pow.i",    S(POW),0,   1,      "i",    "iip",  ipow,    NULL,  NULL    },
   { "pow.k",    S(POW),0,   2,      "k",    "kkp",  NULL,    ipow,  NULL    },
   { "pow.a",    S(POW),0,   4,      "a",    "akp",  NULL,    NULL,  apow    },
+  { "##pow.i",  S(POW),0,   1,      "i",    "iip",  ipow,    NULL,  NULL    },
+  { "##pow.k",  S(POW),0,   2,      "k",    "kkp",  NULL,    ipow,  NULL    },
+  { "##pow.a",  S(POW),0,   4,      "a",    "akp",  NULL,    NULL,  apow    },
   { "oscilx",   S(OSCILN), TR, 5,   "a",    "kiii", oscnset,NULL,   osciln  },
   { "linrand.i",S(PRAND),0, 1,      "i",    "k",    iklinear, NULL, NULL    },
   { "linrand.k",S(PRAND),0, 2,      "k",    "k",    NULL, iklinear, NULL    },
@@ -901,14 +904,19 @@ OENTRY opcodlst_1[] = {
   { "mididefault", S(MIDIDEFAULT),0, 3, "", "xx",   mididefault, mididefault },
   { "invalue",   0xFFFF,   CR,    0,   NULL,   NULL, (SUBR) NULL, (SUBR) NULL },
   { "invalue.k", S(INVAL),0, 3, "k", "i",   (SUBR) invalset,(SUBR)  kinval, NULL },
+  { "invalue.i", S(INVAL),0, 1, "i", "i",   (SUBR) invalsetgo, NULL, NULL },
   { "invalue.kS", S(INVAL),0, 3, "k", "S", (SUBR) invalset_S,(SUBR)  kinval, NULL },
+  { "invalue.iS", S(INVAL),0, 1, "i", "S", (SUBR) invalsetSgo, NULL, NULL },
   { "invalue.S", S(INVAL),0, 3, "S", "i",
                                       (SUBR) invalset_string, (SUBR) kinvalS, NULL },
   { "invalue.SS", S(INVAL),0, 3, "S", "S",
                                     (SUBR) invalset_string_S, (SUBR) kinvalS, NULL },
   { "outvalue", S(OUTVAL), CW, 3, "", "ik", (SUBR) outvalset, (SUBR) koutval, NULL},
+  { "outvalue.i", S(OUTVAL), CW, 1, "", "ii", (SUBR) outvalsetgo, NULL, NULL},
   { "outvalue.k", S(OUTVAL), CW, 3, "", "Sk",
                                           (SUBR) outvalset_S, (SUBR) koutval, NULL},
+  { "outvalue.Si", S(OUTVAL), CW, 1, "", "Si",
+                                          (SUBR) outvalsetSgo, NULL, NULL},
   { "outvalue.S", S(OUTVAL), CW, 3, "", "iS",
                                      (SUBR) outvalset_string, (SUBR) koutvalS, NULL},
   { "outvalue.SS", S(OUTVAL), CW, 3, "", "SS",
@@ -1045,6 +1053,8 @@ OENTRY opcodlst_1[] = {
      (SUBR) strrindex_opcode, (SUBR) NULL, (SUBR) NULL                   },
   {  "strrindexk", S(STRINDEX_OP),0, 3, "k",   "SS",
      (SUBR) strrindex_opcode, (SUBR) strrindex_opcode, (SUBR) NULL       },
+  {  "print_type", S(PRINT_TYPE_OP),0, 1, "",   ".",
+     (SUBR) print_type_opcode, (SUBR) NULL, (SUBR) NULL       },
 #ifdef HAVE_CURL
   {  "strfromurl", S(STRCPY_OP), 0, 1, "S", "S", (SUBR) str_from_url     },
 #endif
