@@ -39,7 +39,7 @@
 # endif
 #endif
 
-//#define LBUFSIZ   32768
+#define LBUFSIZ1 32768
 #define LF        '\n'
 
 /* typedef struct { */
@@ -60,7 +60,7 @@ void RTLineset(CSOUND *csound)      /* set up Linebuf & ready the input files */
     /* csound->lineventGlobals = (LINEVENT_GLOBALS*) */
     /*                            csound->Calloc(csound, */
     /*                            sizeof(LINEVENT_GLOBALS)); */
-    STA(linebufsiz) = LBUFSIZ;
+    STA(linebufsiz) = LBUFSIZ1;
     STA(Linebuf) = (char *) csound->Calloc(csound, STA(linebufsiz));
     STA(prve).opcod = ' ';
     STA(Linebufend) = STA(Linebuf) + STA(linebufsiz);
@@ -117,7 +117,8 @@ void RTclose(CSOUND *csound)
           close(csound->Linefd);
 #if !defined(DOSGCC) && !defined(WIN32)
         else
-          fcntl(csound->Linefd, F_SETFL, STA(stdmode));
+          if (UNLIKELY(fcntl(csound->Linefd, F_SETFL, STA(stdmode))))
+            csoundDie(csound, Str("Failed to set file status\n"));
 #endif
       }
 //csound->Free(csound, csound->lineventGlobals);
@@ -144,9 +145,11 @@ static CS_NOINLINE int linevent_alloc(CSOUND *csound, int reallocsize)
       STA(Linebuf) = (char *) csound->ReAlloc(csound,
                                               (void *) STA(Linebuf), reallocsize);
       STA(linebufsiz) = reallocsize;
+      // csound->Message(csound, "realloc: %d\n", reallocsize);
       STA(Linebufend) = STA(Linebuf) + STA(linebufsiz);
+      STA(Linep) = STA(Linebuf);
     } else if (STA(Linebuf)==NULL) {
-       STA(linebufsiz) = LBUFSIZ;
+       STA(linebufsiz) = LBUFSIZ1;
        STA(Linebuf) = (char *) csound->Calloc(csound, STA(linebufsiz));
     }
     if(STA(Linebuf) == NULL) return 1;
@@ -176,15 +179,30 @@ void csoundInputMessageInternal(CSOUND *csound, const char *message)
     int32  size = (int32) strlen(message);
     int n;
 
+    #ifdef ANDROID
+    struct timespec ts;
+    clock_gettime(CLOCK_MONOTONIC, &ts);
+    csound->Message(csound, Str("input message kcount, %d, %d.%06d\n"),
+                            csound->kcounter, ts.tv_sec, ts.tv_nsec/1000);
+    #endif
+
     if ((n=linevent_alloc(csound, 0)) != 0) return;
     if (!size) return;
     if (UNLIKELY((STA(Linep) + size) >= STA(Linebufend))) {
       int extralloc = STA(Linep) + size - STA(Linebufend);
-      if ((n=linevent_alloc(csound, STA(linebufsiz) + extralloc ), 0) != 0) {
+      // csound->Message(csound, "extralloc: %d %d %d\n",
+      //                 extralloc, size, (int)(STA(Linebufend) - STA(Linep)));
+      // FIXME -- Coverity points out that this test isalways false
+      // and n is never used
+#if 0
+      if ((n=linevent_alloc(csound, (STA(linebufsiz) + extralloc) ), 0) != 0) {
         csoundErrorMsg(csound, Str("LineBuffer Overflow - "
                                    "Input Data has been Lost"));
         return;
       }
+#else
+      n = linevent_alloc(csound, (STA(linebufsiz) + extralloc));
+#endif
     }
     memcpy(STA(Linep), message, size);
     if (STA(Linep)[size - 1] != (char) '\n')
@@ -249,7 +267,8 @@ static void sensLine(CSOUND *csound, void *userData)
           pcnt++;
           if (c == '"') {                       /* if find character string */
             if (e.strarg == NULL)
-              e.strarg = sstrp = csound->Malloc(csound, strsiz=SSTRSIZ);
+              e.strarg = csound->Malloc(csound, strsiz=SSTRSIZ);
+            sstrp = e.strarg;
             n = scnt;
             while (n-->0) sstrp += strlen(sstrp)+1;
             n = 0;
@@ -480,9 +499,6 @@ int instanceOpcode_(CSOUND *csound, LINEVENT2 *p, int insname)
     evt.opcod = 'i';
     evt.pcnt = p->INOCOUNT;
 
-    /* pass in the memory to hold the instance after insertion */
-    evt.pinstance = (void *) p->inst;
-
     /* IV - Oct 31 2002: allow string argument */
     if (evt.pcnt > 0) {
       if (insname) {
