@@ -226,7 +226,7 @@ int musmon(CSOUND *csound)
 
   /* run instr 0 inits */
     if (UNLIKELY(init0(csound) != 0))
-    csoundDie(csound, Str("header init errors"));
+      csoundDie(csound, Str("header init errors"));
 
     /* kperf() will not call csoundYield() more than 250 times per second */
     csound->evt_poll_cnt    = 0;
@@ -349,17 +349,21 @@ int musmon(CSOUND *csound)
     if (csound->csoundScoreOffsetSeconds_ > FL(0.0))
       csoundSetScoreOffsetSeconds(csound, csound->csoundScoreOffsetSeconds_);
 
-
+#ifndef __EMSCRIPTEN__
     if(csound->realtime_audio_flag && csound->init_pass_loop == 0){
       extern void *init_pass_thread(void *);
       pthread_attr_t attr;
-      csound->init_pass_loop = 1;
       csound->init_pass_threadlock = csoundCreateMutex(0);
+      csoundLockMutex(csound->init_pass_threadlock);
+      csound->init_pass_loop = 1;
+      csoundUnlockMutex(csound->init_pass_threadlock);
+      csound->init_pass_loop = 1;
       pthread_attr_init(&attr);
       //pthread_attr_setstacksize(&attr, 1048576);
       pthread_create(&csound->init_pass_thread,&attr,init_pass_thread, csound);
-    }
 
+    }
+#endif
 
     /* since we are running in components, we exit here to playevents later */
     return 0;
@@ -431,6 +435,7 @@ PUBLIC int csoundCleanup(CSOUND *csound)
       xturnoff_now(csound, csound->engineState.instrtxtp[0]->instance);
     delete_pending_rt_events(csound);
 
+#ifndef __EMSCRIPTEN__
     if(csound->init_pass_loop == 1) {
       csoundLockMutex(csound->init_pass_threadlock);
       csound->init_pass_loop = 0;
@@ -439,6 +444,7 @@ PUBLIC int csoundCleanup(CSOUND *csound)
       csoundDestroyMutex(csound->init_pass_threadlock);
       csound->init_pass_threadlock = 0;
     }
+#endif
 
     while (csound->freeEvtNodes != NULL) {
       p = (void*) csound->freeEvtNodes;
@@ -1196,7 +1202,6 @@ int insert_score_event_at_sample(CSOUND *csound, EVTBLK *evt, int64_t time_ofs)
       memcpy(e->evt.strarg, evt->strarg, p-evt->strarg+1 );
       e->evt.scnt = evt->scnt;
     }
-    e->evt.pinstance = evt->pinstance;
     e->evt.opcod = evt->opcod;
     e->evt.pcnt = evt->pcnt;
     p = &(e->evt.p[0]);
