@@ -43,15 +43,16 @@ typedef struct pre_parm_s {
     uint64_t        locn;
     uint64_t        llocn;
     uint16_t        depth;
-    uint8_t         lstack[1024];
+    uint16_t        lstack[1024];
 } PRE_PARM;
 
 typedef struct parse_parm_s {
     void            *yyscanner;
     uint64_t        locn;
-    MACRO           *macros;
     char            *xstrbuff;
     int             xstrptr,xstrmax;
+    uint64_t        iline;      /* Line number for start of instrument */
+    uint64_t        ilocn;      /* and location */
 } PARSE_PARM;
 
 void    cs_init_math_constants_macros(CSOUND*, PRE_PARM*);
@@ -60,4 +61,7 @@ void    cs_init_omacros(CSOUND*, PRE_PARM*, NAMES*);
 uint64_t make_location(PRE_PARM *);
 extern uint8_t file_to_int(CSOUND*, const char*);
 
+extern void csound_orcput_ilocn(void *, uint64_t, uint64_t);
+extern uint64_t csound_orcget_iline(void *);
+extern uint64_t csound_orcget_ilocn(void *);
 #endif
