@@ -98,6 +98,11 @@ typedef struct {
     MYFLT   *ar;
 } INM;
 
+typedef struct {
+    OPDS    h;
+    ARRAYDAT   *tabout;
+} INA;
+
 typedef struct {
     OPDS    h;
     MYFLT   *ar1, *ar2;
@@ -131,34 +136,25 @@ typedef struct {
 
 typedef struct {
     OPDS    h;
-    MYFLT   *asig;
-} OUTM;
-
-typedef struct {
-    OPDS    h;
-    MYFLT   *asig1, *asig2;
-} OUTS;
-
-typedef struct {
-    OPDS    h;
-    MYFLT   *asig1, *asig2, *asig3, *asig4;
-} OUTQ;
-
-typedef struct {
-    OPDS    h;
-    MYFLT   *asig1, *asig2, *asig3, *asig4, *asig5, *asig6;
-} OUTH;
-
-typedef struct {
-    OPDS    h;
-    MYFLT   *asig1, *asig2, *asig3, *asig4, *asig5, *asig6, *asig7, *asig8;
-} OUTO;
+    MYFLT   *ar;
+    MYFLT   *ch;
+} INCH1;
 
 typedef struct {
     OPDS    h;
     MYFLT   *asig[VARGMAX];
 } OUTX;
 
+typedef struct {
+    OPDS    h;
+    ARRAYDAT   *tabin;
+} OUTARRAY;
+
+typedef struct {
+    OPDS    h;
+    MYFLT   *asig;
+} OUTM;
+
 typedef struct {
     OPDS    h;
     MYFLT   *args[VARGMAX];
@@ -182,13 +178,21 @@ typedef struct {
 
 typedef struct {
     OPDS    h;
-    MYFLT   *value, *valID;
-    AUXCH   channelName;
-} INVAL;
+    MYFLT   *res, *arg;
+} ERRFN;
+
+typedef struct MONITOR_OPCODE_ {
+    OPDS    h;
+    MYFLT   *ar[24];
+} MONITOR_OPCODE;
 
 typedef struct {
-    OPDS    h;
-    MYFLT   *valID, *value;
-    AUXCH   channelName;
-} OUTVAL;
+        OPDS    h;
+        MYFLT   *kstartChan, *argums[VARGMAX];
+        int narg;
+} OUTRANGE;
 
+int monitor_opcode_perf(CSOUND *csound, MONITOR_OPCODE *p);
+int monitor_opcode_init(CSOUND *csound, MONITOR_OPCODE *p);
+int outRange_i(CSOUND *csound, OUTRANGE *p);
+int outRange(CSOUND *csound, OUTRANGE *p);
