@@ -186,12 +186,16 @@ int invalset(CSOUND *csound, INVAL *p);
 int invalset_string(CSOUND *csound, INVAL *p);
 int invalset_string_S(CSOUND *csound, INVAL *p);
 int invalset_S(CSOUND *csound, INVAL *p);
+int invalsetgo(CSOUND *csound, INVAL *p);
+int invalsetSgo(CSOUND *csound, INVAL *p);
 int koutval(CSOUND *csound, OUTVAL *p);
 int koutvalS(CSOUND *csound, OUTVAL *p);
 int outvalset(CSOUND *csound, OUTVAL *p);
 int outvalset_string(CSOUND *csound, OUTVAL *p);
 int outvalset_string_S(CSOUND *csound, OUTVAL *p);
 int outvalset_S(CSOUND *csound, OUTVAL *p);
+int outvalsetgo(CSOUND *csound, OUTVAL *p);
+int outvalsetSgo(CSOUND *csound, OUTVAL *p);
 #ifdef __cplusplus
 }
 #endif
