@@ -37,7 +37,8 @@ int is_statement_expansion_required(TREE* root);
 void handle_optional_args(CSOUND *csound, TREE *l);
 
 TREE* expand_if_statement(CSOUND* csound, TREE* current, TYPE_TABLE* typeTable);
-TREE* expand_until_statement(CSOUND* csound, TREE* current, TYPE_TABLE* typeTable);
+TREE* expand_until_statement(CSOUND* csound, TREE* current,
+                             TYPE_TABLE* typeTable, int);
 TREE* expand_statement(CSOUND* csound, TREE* current, TYPE_TABLE* typeTable);
 
-#endif
\ No newline at end of file
+#endif
