@@ -48,17 +48,19 @@ typedef struct {
         uint32  lastframe;
 } FSIGDISP;
 
-#define WINDMAX 4096
+#define WINDMAX 16384
 #define WINDMIN 16
 
 typedef struct {
         OPDS    h;
-        MYFLT   *signal, *iprd, *inpts, *ihann, *idbout, *iwtflg;
-        MYFLT   sampbuf[WINDMAX], *bufp, *endp, overN;
+        MYFLT   *signal, *iprd, *inpts, *ihann, *idbout, *iwtflg, *imin, *imax;
+        MYFLT   *sampbuf, *bufp, *endp, overN;
         int32   windsize, overlap, ncoefs;
         int     hanning, dbout;
+        int     npts, start;
         WINDAT  dwindow;
         AUXCH   auxch;
+        AUXCH  smpbuf;
 } DSPFFT;
 
 typedef struct {
