@@ -464,3 +464,7 @@ int inch_opcode1(CSOUND *csound, INCH1 *p);
 int adset_S(CSOUND *csound, void *p);
 int lprdset_S(CSOUND *csound, void *p);
 int pvsfreadset_S(CSOUND *csound, void *p);
+int alnnset(CSOUND *csound, void *p);
+int alnrset(CSOUND *csound, void *p);
+int aevxset(CSOUND *csound, void *p);
+int aevrset(CSOUND *csound, void *p);
