@@ -51,6 +51,28 @@ static inline void rtJack_Lock(CSOUND *csound, pthread_mutex_t *p)
     pthread_mutex_lock(p);
 }
 
+static inline int rtJack_LockTimeout(CSOUND *csound, pthread_mutex_t *p,
+                                     size_t milliseconds)
+{
+      struct timeval  tv;
+      struct timespec ts;
+      register size_t n, s;
+      register int retval = pthread_mutex_trylock(p);
+      if (!retval)
+        return retval;
+      if (!milliseconds)
+        return retval;
+      gettimeofday(&tv, NULL);
+      s = milliseconds / (size_t) 1000;
+      n = milliseconds - (s * (size_t) 1000);
+      s += (size_t) tv.tv_sec;
+      n = (size_t) (((int) n * 1000 + (int) tv.tv_usec) * 1000);
+      ts.tv_nsec = (long) (n < (size_t) 1000000000 ? n : n - 1000000000);
+      ts.tv_sec = (time_t) (n < (size_t) 1000000000 ? s : s + 1);
+      return pthread_mutex_timedlock(p, &ts);
+
+}
+
 static inline int rtJack_TryLock(CSOUND *csound, pthread_mutex_t *p)
 {
     (void) csound;
@@ -83,6 +105,12 @@ static inline void rtJack_Lock(CSOUND *csound, void **p)
     csound->WaitThreadLockNoTimeout(*p);
 }
 
+static inline int rtJack_LockTimeout(CSOUND *csound, void **p, size_t timeout)
+{
+  return csound->WaitThreadLock(*p, timeout);
+}
+
+
 static inline int rtJack_TryLock(CSOUND *csound, void **p)
 {
     return (csound->WaitThreadLock(*p, (size_t) 0));
@@ -508,12 +536,14 @@ static void openJackStreams(RtJackGlobals *p)
       dev_final = dev;
       sp = strchr(dev_final, '\0');
       if (!isalpha(dev_final[0])) dev_final++;
-
       for (i = 0; i < p->nChannels; i++) {
         snprintf(sp, 128-(dev-sp), "%d", i + 1);
         if (UNLIKELY(jack_connect(p->client, dev_final,
                                   jack_port_name(p->inPorts[i])) != 0)) {
-          rtJack_Error(csound, -1, Str("error connecting input ports"));
+          //rtJack_Error(csound, -1, Str("error connecting input ports"));
+          csound->Warning(csound,
+                          Str("not autoconnecting input channel %d \n"
+                              "(needs manual connection)"), i+1);
         }
       }
       *sp = (char) 0;
@@ -544,7 +574,10 @@ static void openJackStreams(RtJackGlobals *p)
         snprintf(sp, 128-(dev-sp), "%d", i + 1);
         if (jack_connect(p->client, jack_port_name(p->outPorts[i]),
                          dev_final) != 0) {
-          rtJack_Error(csound, -1, Str("error connecting output ports"));
+          //rtJack_Error(csound, -1, Str("error connecting output ports"));
+          csound->Warning(csound, Str("not autoconnecting input channel %d \n"
+                                      "(needs manual connection)"), i+1);
+
         }
       }
       *sp = (char) 0;
@@ -787,8 +820,18 @@ static int rtrecord_(CSOUND *csound, MYFLT *inbuf_, int bytes_)
     for (i = j = 0; i < nframes; i++) {
       if (bufpos == 0) {
         /* wait until there is enough data in ring buffer */
-        /* **** COVERITY: claims this is a double lock **** */
-        rtJack_Lock(csound, &(p->bufs[bufcnt]->csndLock));
+        /* VL 28.03.15 -- timeout after wait for 10 buffer
+           lengths */
+        int ret = rtJack_LockTimeout(csound, &(p->bufs[bufcnt]->csndLock),
+                                     10000*(nframes/csound->GetSr(csound)));
+        if(ret) {
+          memset(inbuf_, 0, bytes_);
+          OPARMS oparms;
+          csound->GetOParms(csound, &oparms);
+          if (oparms.msglevel & 4)
+             csound->Warning(csound, Str("rtjack: input audio timeout"));
+          return bytes_;
+        }
       }
       /* copy audio data */
       for (k = 0; k < p->nChannels; k++)
