@@ -79,13 +79,16 @@ void dispinit(CSOUND *csound)
       csound->csoundKillGraphCallback_ = DummyFn2;
     }
     else {
-      csound->Message(csound, Str("graphics %s, ascii substituted\n"),
-                      ((O.graphsoff || O.postscript) ?
-                       Str("suppressed")
-                       : Str("not supported on this terminal")));
-      csound->csoundMakeGraphCallback_ = MakeAscii;
-      csound->csoundDrawGraphCallback_ = DrawAscii;
-      csound->csoundKillGraphCallback_ = KillAscii;
+      if (csound->csoundDrawGraphCallback_ == NULL){
+        // if callbacks are not set by host
+        csound->Message(csound, Str("graphics %s, ascii substituted\n"),
+                        ((O.graphsoff || O.postscript) ?
+                         Str("suppressed")
+                         : Str("not supported on this terminal")));
+        csound->csoundMakeGraphCallback_ = MakeAscii;
+        csound->csoundDrawGraphCallback_ = DrawAscii;
+        csound->csoundKillGraphCallback_ = KillAscii;
+      }
     }
     csound->csoundExitGraphCallback_ = DummyFn3;
 }
@@ -162,7 +165,7 @@ void display(CSOUND *csound, WINDAT *wdptr)   /* prepare a MYFLT array, then  */
     if (wdptr->absflag  || absmax > wdptr->oabsmax)
      wdptr->oabsmax = absmax;           /* & absmax over life of win */
 
-    
+
 
     pol = wdptr->polarity;     /* adjust polarity flg for life of win */
     if (pol == (int16)NOPOL)  {
@@ -174,7 +177,7 @@ void display(CSOUND *csound, WINDAT *wdptr)   /* prepare a MYFLT array, then  */
     else if (pol == (int16)NEGPOL && max > FL(0.0)) pol = (int16)BIPOL;
     wdptr->polarity = pol;
 
-
+    if(O.odebug) csound->Message(csound, " calling draw callback \n");
     /* now graph the function */
     csound->csoundDrawGraphCallback_(csound, wdptr);
 
