@@ -76,10 +76,11 @@ int apow(CSOUND *csound, POW *p)        /* Power routine for a-rate  */
 int seedrand(CSOUND *csound, PRAND *p)
 {
     uint32_t  seedVal = (uint32_t)0;
+    int32 xx = (int32)((double)*p->out + 0.5);
 
-    if (*p->out > FL(0.0))
-      seedVal = (uint32_t)((double)*p->out + 0.5);
-    else if (!seedVal) {
+    if (xx > FL(0.0))
+      seedVal = (uint32_t)xx;
+    else if (xx==0) {
       seedVal = (uint32_t)csound->GetRandomSeedFromTime();
       csound->Warning(csound, Str("Seeding from current time %u\n"),
                               (unsigned int)seedVal);
@@ -351,8 +352,8 @@ int exprndiset(CSOUND *csound, PRANDI *p)
     p->num2 = exprand(csound, *p->arg1);
     p->dfdmax = (p->num2 - p->num1) / FMAXLEN;
     p->phs = 0;
-    p->ampcod = (XINARG1) ? 1 : 0;      /* (not used by krandi) */
-    p->cpscod = (XINARG2) ? 1 : 0;
+    p->ampcod = IS_ASIG_ARG(p->xamp) ? 1 : 0;      /* (not used by krandi) */
+    p->cpscod = IS_ASIG_ARG(p->xcps) ? 1 : 0;
     return OK;
 }
 
@@ -509,8 +510,8 @@ int gaussiset(CSOUND *csound, PRANDI *p)
     p->num2 = gaussrand(csound, *p->arg1);
     p->dfdmax = (p->num2 - p->num1) / FMAXLEN;
     p->phs = 0;
-    p->ampcod = (XINARG1) ? 1 : 0;      /* (not used by krandi) */
-    p->cpscod = (XINARG2) ? 1 : 0;
+    p->ampcod = IS_ASIG_ARG(p->xamp) ? 1 : 0;      /* (not used by krandi) */
+    p->cpscod = IS_ASIG_ARG(p->xcps) ? 1 : 0;
     return OK;
 }
 
@@ -607,8 +608,8 @@ int cauchyiset(CSOUND *csound, PRANDI *p)
     p->num2 = cauchrand(csound, *p->arg1);
     p->dfdmax = (p->num2 - p->num1) / FMAXLEN;
     p->phs = 0;
-    p->ampcod = (XINARG1) ? 1 : 0;      /* (not used by krandi) */
-    p->cpscod = (XINARG2) ? 1 : 0;
+    p->ampcod = IS_ASIG_ARG(p->xamp) ? 1 : 0;      /* (not used by krandi) */
+    p->cpscod = IS_ASIG_ARG(p->xcps) ? 1 : 0;
     return OK;
 }
 
