@@ -29,7 +29,6 @@
 #include <math.h>
 #include "csoundCore.h"
 #include "pstream.h"
-#include "oload.h"
 
         double  besseli(double x);
 static  void    hamming(MYFLT *win, int winLen, int even);
@@ -74,7 +73,7 @@ static CS_NOINLINE int PVS_CreateWindow(CSOUND *csound, MYFLT *buf,
           return csound->InitError(csound, Str("invalid window type"));
     }
     /* use table created with GEN20 */
-    flen = csound->GetTable(csound, &ftable, -(type));
+    flen = csoundGetTable(csound, &ftable, -(type));
     if (UNLIKELY(flen < 0))
       return csound->InitError(csound, Str("ftable for window not found"));
     inc = (double)flen / (double)(winLen & (~1));
@@ -110,9 +109,9 @@ int pvssanalset(CSOUND *csound, PVSANAL *p)
 
     /* Need space for NB complex numbers for each of ksmps */
     if (p->fsig->frame.auxp==NULL ||
-        csound->ksmps*(N+2)*sizeof(MYFLT) > (unsigned int)p->fsig->frame.size)
-      csound->AuxAlloc(csound, csound->ksmps*(N+2)*sizeof(MYFLT),&p->fsig->frame);
-    else memset(p->fsig->frame.auxp, 0, csound->ksmps*(N+2)*sizeof(MYFLT));
+        CS_KSMPS*(N+2)*sizeof(MYFLT) > (unsigned int)p->fsig->frame.size)
+      csound->AuxAlloc(csound, CS_KSMPS*(N+2)*sizeof(MYFLT),&p->fsig->frame);
+    else memset(p->fsig->frame.auxp, 0, CS_KSMPS*(N+2)*sizeof(MYFLT));
     /* Space for remembering samples */
     if (p->input.auxp==NULL ||
         N*sizeof(MYFLT) > (unsigned int)p->input.size)
@@ -164,28 +163,34 @@ int pvsanalset(CSOUND *csound, PVSANAL *p)
     MYFLT *analwinhalf,*analwinbase;
     MYFLT sum;
     int32 halfwinsize,buflen;
-    int i,nBins,Mf,Lf;
+    int i,nBins,Mf/*,Lf*/;
 
     /* opcode params */
-    int32 N =(int32) *(p->fftsize);
-    int32 overlap = (int32) *(p->overlap);
-    int32 M = (int32) *(p->winsize);
+    uint32_t N =(int32) *(p->fftsize);
+    uint32_t overlap = (uint32_t) *(p->overlap);
+    uint32_t M = (uint32_t) *(p->winsize);
     int wintype = (int) *p->wintype;
     /* deal with iinit and iformat later on! */
 
-    if (overlap<csound->ksmps || overlap<=10) /* 10 is a guess.... */
+    if (overlap<CS_KSMPS || overlap<=10) /* 10 is a guess.... */
       return pvssanalset(csound, p);
     if (UNLIKELY(N <= 32))
-      csound->Die(csound, Str("pvsanal: fftsize of 32 is too small!\n"));
+      return csound->InitError(csound,
+                               Str("pvsanal: fftsize of 32 is too small!\n"));
     /* check N for powof2? CARL fft routines and FFTW are not limited to that */
     N = N  + N%2;       /* Make N even */
-    if (UNLIKELY(M < N))
-      csound->Die(csound, Str("pvsanal: window size too small for fftsize\n"));
+    if (UNLIKELY(M < N)) {
+       csound->Warning(csound,
+                               Str("pvsanal: window size too small for fftsize"));
+       M = N;
+    }
     if (UNLIKELY(overlap > N / 2))
-      csound->Die(csound, Str("pvsanal: overlap too big for fft size\n"));
-#ifdef OPLC
-    if (UNLIKELY(overlap < csound->ksmps))
-      csound->Die(csound, Str("pvsanal: overlap must be >= ksmps\n"));
+      return csound->InitError(csound,
+                               Str("pvsanal: overlap too big for fft size\n"));
+#ifdef OLPC
+    if (UNLIKELY(overlap < CS_KSMPS))
+      return csound->InitError(csound,
+                               Str("pvsanal: overlap must be >= ksmps\n"));
 #endif
     halfwinsize = M/2;
     buflen = M*4;
@@ -196,7 +201,7 @@ int pvsanalset(CSOUND *csound, PVSANAL *p)
     /* we can exclude/simplify all sorts of stuff in CARL
      * as we will never do time-scaling with this opcode
      */
-    Lf = Mf = 1 - M%2;
+    /*Lf =*/ Mf = 1 - M%2;
 
     csound->AuxAlloc(csound, overlap * sizeof(MYFLT), &p->overlapbuf);
     csound->AuxAlloc(csound, (N+2) * sizeof(MYFLT), &p->analbuf);
@@ -363,7 +368,9 @@ static void generate_frame(CSOUND *csound, PVSANAL *p)
     }
 #endif
     /*if (format==PVS_AMP_FREQ) {*/
-    for (i=ii=0/*,i0=anal,i1=anal+1,oi=oldInPhase*/; i <= N2; i++,ii+=2/*i0+=2,i1+=2, oi++*/) {
+    for (i=ii=0    /*,i0=anal,i1=anal+1,oi=oldInPhase*/;
+         i <= N2;
+         i++,ii+=2 /*i0+=2,i1+=2, oi++*/) {
       real = anal[ii] /* *i0 */;
       imag = anal[ii+1] /* *i1 */;
       /**i0*/ anal[ii] = HYPOT(real, imag);
@@ -422,6 +429,7 @@ static void anal_tick(CSOUND *csound, PVSANAL *p,MYFLT samp)
       p->inptr = 0;
 
     }
+    //printf("inptr = %d fsig->overlap=%d\n", p->inptr, p->fsig->overlap);
     inbuf[p->inptr++] = samp;
 
 }
@@ -442,21 +450,25 @@ static inline double mod2Pi(double x)
 int pvssanal(CSOUND *csound, PVSANAL *p)
 {
     MYFLT *ain;
-    int NB = p->Ii, i, loc;
+    int NB = p->Ii, loc;
     int N = p->fsig->N;
     MYFLT *data = (MYFLT*)(p->input.auxp);
     CMPLX *fw = (CMPLX*)(p->analwinbuf.auxp);
     double *c = p->cosine;
     double *s = p->sine;
     double *h = (double*)p->oldInPhase.auxp;
-    int nsmps = csound->ksmps;
+    uint32_t offset = p->h.insdshead->ksmps_offset;
+    uint32_t early  = p->h.insdshead->ksmps_no_end;
+    uint32_t i, nsmps = CS_KSMPS;
     int wintype = p->fsig->wintype;
     if (UNLIKELY(data==NULL)) {
-      csound->Die(csound, Str("pvsanal: Not Initialised.\n"));
+      return csound->PerfError(csound,p->h.insdshead,
+                               Str("pvsanal: Not Initialised.\n"));
     }
     ain = p->ain;               /* The input samples */
     loc = p->inptr;             /* Circular buffer */
-    for (i=0; i < nsmps; i++) {
+    nsmps -= early;
+    for (i=offset; i < nsmps; i++) {
       MYFLT re, im, dx;
       CMPLX* ff;
       int j;
@@ -479,7 +491,7 @@ int pvssanal(CSOUND *csound, PVSANAL *p)
       /* Rectang :Fw_t =     F_t                          */
       /* Hamming :Fw_t = 0.54F_t - 0.23[ F_{t-1}+F_{t+1}] */
       /* Hamming :Fw_t = 0.5 F_t - 0.25[ F_{t-1}+F_{t+1}] */
-      /* Blackman:Fw_t = 0.42F_t - 0.25[ F_{t-1}+F_{t+1}] + 0.04[F_{t-2}+F_{t+2}] */
+      /* Blackman:Fw_t = 0.42F_t - 0.25[ F_{t-1}+F_{t+1}]+0.04[F_{t-2}+F_{t+2}] */
       /* Blackman_exact:Fw_t = 0.42659071367153912296F_t
          - 0.24828030954428202923 [F_{t-1}+F_{t+1}]
          + 0.038424333619948409286 [F_{t-2}+F_{t+2}]      */
@@ -656,19 +668,23 @@ int pvssanal(CSOUND *csound, PVSANAL *p)
 int pvsanal(CSOUND *csound, PVSANAL *p)
 {
     MYFLT *ain;
-    int i;
+    uint32_t offset = p->h.insdshead->ksmps_offset;
+    uint32_t early  = p->h.insdshead->ksmps_no_end;
+    uint32_t i, nsmps = CS_KSMPS;
 
     ain = p->ain;
 
     if (UNLIKELY(p->input.auxp==NULL)) {
-      csound->Die(csound, Str("pvsanal: Not Initialised.\n"));
+      return csound->PerfError(csound,p->h.insdshead,
+                               Str("pvsanal: Not Initialised.\n"));
     }
     {
       int overlap = (int)*p->overlap;
-      if (overlap<csound->ksmps || overlap<10) /* 10 is a guess.... */
+      if (overlap<(int)nsmps || overlap<10) /* 10 is a guess.... */
         return pvssanal(csound, p);
     }
-    for (i=0; i < csound->ksmps; i++)
+    nsmps -= early;
+    for (i=offset; i < nsmps; i++)
       anal_tick(csound,p,ain[i]);
     return OK;
 }
@@ -831,7 +847,7 @@ static void process_frame(CSOUND *csound, PVSYNTH *p)
 {
     int i,j,k,ii,NO,NO2;
     float *anal;                                        /* RWD MUST be 32bit */
-    MYFLT *syn,*bsyn,*output;
+    MYFLT *syn, *output;
     MYFLT *oldOutPhase = (MYFLT *) (p->oldOutPhase.auxp);
     int32 N = p->fsig->N;
     MYFLT *obufptr,*outbuf,*synWindow;
@@ -851,7 +867,6 @@ static void process_frame(CSOUND *csound, PVSYNTH *p)
     outbuf = (MYFLT *) (p->overlapbuf.auxp);
     synWindow = (MYFLT *) (p->synwinbuf.auxp) + synWinLen;
 
-    bsyn = syn+1;
     /* reconversion: The magnitude and angle-difference-per-second in syn
        (assuming an intermediate sampling rate of rOut) are
        converted to real and imaginary values and are returned in syn.
@@ -885,7 +900,7 @@ static void process_frame(CSOUND *csound, PVSYNTH *p)
         /* this is spread across several frame cycles, as the problem does not
            develop for a while */
 
-        angledif = p->TwoPioverR * ( /* *i1 */ syn[ii+1]  - ((MYFLT) i * p->Fexact));
+        angledif = p->TwoPioverR * ( /* *i1 */ syn[ii+1] - ((MYFLT)i * p->Fexact));
         the_phase = /* *(oldOutPhase + i) */ oldOutPhase[i] + angledif;
         if (i== p->bin_index)
           the_phase = (MYFLT) fmod(the_phase,TWOPI);
@@ -915,6 +930,7 @@ static void process_frame(CSOUND *csound, PVSYNTH *p)
        out (to standard output). The subroutines reals and fft
        together perform an efficient inverse FFT.  */
     if (!(NO & (NO - 1))) {
+      /*printf("N %d %d \n", NO, NO & (NO-1));*/
       syn[1] = syn[NO];
       csound->InverseRealFFT(csound, syn, NO);
       syn[NO] = syn[NO + 1] = FL(0.0);
@@ -983,7 +999,7 @@ static void process_frame(CSOUND *csound, PVSYNTH *p)
 int pvssynth(CSOUND *csound, PVSYNTH *p)
 {
     int i, k;
-    int ksmps = csound->ksmps;
+    int ksmps = CS_KSMPS;
     int N = p->fsig->N;
     int NB = p->fsig->NB;
     MYFLT *aout = p->aout;
@@ -1020,14 +1036,22 @@ int pvssynth(CSOUND *csound, PVSYNTH *p)
 
 int pvsynth(CSOUND *csound, PVSYNTH *p)
 {
-    int i;
+    uint32_t offset = p->h.insdshead->ksmps_offset;
+    uint32_t early  = p->h.insdshead->ksmps_no_end;
+    uint32_t i, nsmps = CS_KSMPS;
     MYFLT *aout = p->aout;
 
     if (UNLIKELY(p->output.auxp==NULL)) {
-      csound->Die(csound, Str("pvsynth: Not Initialised.\n"));
+      return csound->PerfError(csound,p->h.insdshead,
+                               Str("pvsynth: Not Initialised.\n"));
     }
     if (p->fsig->sliding) return pvssynth(csound, p);
-    for (i=0;i < csound->ksmps;i++)
+    if (UNLIKELY(offset)) memset(aout, '\0', offset*sizeof(MYFLT));
+    if (UNLIKELY(early)) {
+      nsmps -= early;
+      memset(&aout[nsmps], '\0', early*sizeof(MYFLT));
+    }
+    for (i=offset; i<nsmps; i++)
       aout[i] = synth_tick(csound, p);
     return OK;
 }
