@@ -189,7 +189,7 @@ int samphset(CSOUND *csound, SAMPHOLD *p)
 {
     if (!(*p->istor))
       p->state = *p->ival;
-    p->audiogate = (p->XINCODE & 02) ? 1 : 0;
+    p->audiogate = IS_ASIG_ARG(p->xgate) ? 1 : 0;
     return OK;
 }
 
@@ -271,7 +271,7 @@ int delrset(CSOUND *csound, DELAYR *p)
     uint32_t    npts;
     MYFLT       *auxp;
 
-    if (UNLIKELY(p->XOUTCODE != 1))
+    if (UNLIKELY(!IS_ASIG_ARG(p->ar)))
       return csound->InitError(csound, Str("delayr: invalid outarg type"));
     /* fifo for delayr pointers by Jens Groh: */
     /* append structadr for delayw to fifo: */
@@ -494,7 +494,7 @@ int deltapi(CSOUND *csound, DELTAP *p)
     }
     begp = (MYFLT *) q->auxch.auxp;
     endp = (MYFLT *) q->auxch.endp;
-    if (!p->XINCODE) {
+    if (!IS_ASIG_ARG(p->xdlt)) {
       if(*p->xdlt == INFINITY) goto err2;
       delsmps = *p->xdlt * csound->esr;
       idelsmps = (int32)delsmps;
@@ -556,7 +556,7 @@ int deltapn(CSOUND *csound, DELTAP *p)
     }
     begp = (MYFLT *) q->auxch.auxp;
     endp = (MYFLT *) q->auxch.endp;
-    if (!p->XINCODE) {
+    if (!IS_ASIG_ARG(p->xdlt)) {
       delsmps = *p->xdlt;
       idelsmps = (int32)delsmps;
       tap = q->curp - idelsmps;
@@ -601,14 +601,14 @@ int deltap3(CSOUND *csound, DELTAP *p)
 
     if (UNLIKELY(q->auxch.auxp==NULL)) goto err1;
     ar = p->ar;
-    if (UNLIKELY(offset)) memset(ar, '0', offset*sizeof(MYFLT));
+    if (UNLIKELY(offset)) memset(ar, '\0', offset*sizeof(MYFLT));
     if (UNLIKELY(early)) {
       nsmps -= early;
       memset(&ar[nsmps], '\0', early*sizeof(MYFLT));
     }
     begp = (MYFLT *) q->auxch.auxp;
     endp = (MYFLT *) q->auxch.endp;
-    if (!p->XINCODE) {
+    if (!IS_ASIG_ARG(p->xdlt)) {
       if(*p->xdlt == INFINITY) goto err2;
       delsmps = *p->xdlt * csound->esr;
       idelsmps = (int32)delsmps;
@@ -1030,7 +1030,7 @@ int alpass(CSOUND *csound, COMB *p)
     xp = p->pntr;
     endp = (MYFLT *) p->auxch.endp;
     ar = p->ar;
-    if (UNLIKELY(offset)) memset(ar, '0', offset*sizeof(MYFLT));
+    if (UNLIKELY(offset)) memset(ar, '\0', offset*sizeof(MYFLT));
     if (UNLIKELY(early)) {
       nsmps -= early;
       memset(&ar[nsmps], '\0', early*sizeof(MYFLT));
@@ -1134,7 +1134,7 @@ int reverb(CSOUND *csound, REVERB *p)
     endp = (MYFLT *) p->auxch.endp;
 
     ar = p->ar;
-    if (UNLIKELY(offset)) memset(ar, '0', offset*sizeof(MYFLT));
+    if (UNLIKELY(offset)) memset(ar, '\0', offset*sizeof(MYFLT));
     if (UNLIKELY(early)) {
       nsmps -= early;
       memset(&ar[nsmps], '\0', early*sizeof(MYFLT));
