@@ -122,6 +122,9 @@
 using namespace boost::numeric;
 #include <cmath>
 
+#undef CS_KSMPS
+#define CS_KSMPS     (opds.insdshead->ksmps)
+
 class ChuasOscillatorCubic : public OpcodeBase<ChuasOscillatorCubic>
 {
 public:
@@ -172,7 +175,7 @@ public:
 public:
   int init(CSOUND *csound)
   {
-    if (!csound->reinitflag && !csound->tieflag) {
+    if (!csound->GetReinitFlag(csound) && !csound->GetTieFlag(csound)) {
       csound->RegisterDeinitCallback(csound, this, &noteoff_);
     }
     // h = step_size; %*(G/C2);
@@ -206,7 +209,7 @@ public:
     b = 0.0;
     c = -0.00121;
     d = 0.0;
-    ksmps = csound->GetKsmps(csound);
+    ksmps = opds.insdshead->ksmps;
     warn(csound, "ChuasOscillatorCubic::init: L: %f  R0: %f  C2: %f  G: %f"
          "  C1: %f  V1: %f  V2: %f  I3: %f step: %f\n",
          *L_, *R0_, *C2_, *G_, *C1_, M(1), M(2), M(3), h);
@@ -234,6 +237,19 @@ public:
     // probaby by design. This is very handy and should prevent mistakes.
     // Start with aliases for the Csound inputs, in order
     // to preserve the clarity of the original code.
+    uint32_t offset = opds.insdshead->ksmps_offset;
+    uint32_t early  = opds.insdshead->ksmps_no_end;
+    uint32_t n, nsmps = CS_KSMPS;
+    if (UNLIKELY(offset)) {
+      memset(I3, '\0', offset*sizeof(MYFLT));
+      memset(V1, '\0', offset*sizeof(MYFLT));
+      memset(V2, '\0', offset*sizeof(MYFLT));
+    }
+    if (UNLIKELY(early)) {
+      memset(&I3[nsmps-early], '\0', early*sizeof(MYFLT));
+      memset(&V1[nsmps-early], '\0', early*sizeof(MYFLT));
+      memset(&V2[nsmps-early], '\0', early*sizeof(MYFLT));
+    }
     MYFLT &L = *L_;
     MYFLT &R0 = *R0_;
     MYFLT &C2 = *C2_;
@@ -422,7 +438,7 @@ public:
   size_t ksmps;
   int init(CSOUND *csound)
   {
-    if (!csound->reinitflag && !csound->tieflag) {
+    if (!csound->GetReinitFlag(csound) && !csound->GetTieFlag(csound)) {
       csound->RegisterDeinitCallback(csound, this, &noteoff_);
     }
     // NOTE: The original MATLAB code uses 1-based indexing.
@@ -444,7 +460,7 @@ public:
     M(2) = *V2_ / *E_;
     // M(3) = TimeSeries(1)/(E*G);
     M(3) = *I3_ / (*E_ * *G_);
-    ksmps = csound->GetKsmps(csound);
+    ksmps = opds.insdshead->ksmps;
     warn(csound, "ChuasOscillatorPiecewise::init: L: %f  R0: %f  C2: %f  G: "
          "%f  Ga: %f  Gb: %f  E: %f  C1: %f  M(1): %f  M(2):"
          " %f  M(3): %f step: %f\n",
@@ -472,6 +488,19 @@ public:
     // probaby by design. This is very handy and should prevent mistakes.
     // Start with aliases for the Csound inputs, in order
     // to preserve the clarity of the original code.
+    uint32_t offset = opds.insdshead->ksmps_offset;
+    uint32_t early  = opds.insdshead->ksmps_no_end;
+    if (UNLIKELY(offset)) {
+      memset(I3, '\0', offset*sizeof(MYFLT));
+      memset(V1, '\0', offset*sizeof(MYFLT));
+      memset(V2, '\0', offset*sizeof(MYFLT));
+    }
+    if (UNLIKELY(early)) {
+      ksmps -= early;
+      memset(&I3[ksmps], '\0', early*sizeof(MYFLT));
+      memset(&V1[ksmps], '\0', early*sizeof(MYFLT));
+      memset(&V2[ksmps], '\0', early*sizeof(MYFLT));
+    }
     MYFLT &L = *L_;
     MYFLT &R0 = *R0_;
     MYFLT &C2 = *C2_;
@@ -512,7 +541,7 @@ public:
     // omch2 = 1 - ch2;
     omch2 = 1.0 - ch2;
      // Standard 4th-order Runge-Kutta integration.
-    for (size_t i = 0; i < ksmps; i++) {
+    for (size_t i = offset; i < ksmps; i++) {
       // Stage 1.
       k1(1) = alpha*(M(2) - bnorplus1*M(1) -
                      (.5)*(anor - bnor)*(abs(M(1) + 1) - abs(M(1) - 1)));
@@ -556,6 +585,7 @@ extern "C"
 //       {
 //         (char*)"chuac",
 //         sizeof(ChuasOscillatorCubic),
+//         0,
 //         5,
 //    // kL,       kR0,  kC2,     kG,       kC1,       iI3, iV2,   iV1,  kstep_size
 //    // 0.00945,  7.5,  2e-007,  0.00105,  1.5e-008,  0,   -0.1,  0.1,  5e-6
@@ -568,6 +598,7 @@ extern "C"
       {
         (char*)"chuap",
         sizeof(ChuasOscillatorPiecewise),
+        0,
         5,
         // kL,       kR0,  kC2,     kG,       kGa, kGb,       kE,         kC1,
         //                  iI3, iV2,   iV1,  kstep_size
@@ -588,6 +619,7 @@ extern "C"
         0,
         0,
         0,
+        0,
       }
     };
 
@@ -602,7 +634,8 @@ extern "C"
     for(OENTRY *oentry = &oentries[0]; oentry->opname; oentry++)
       {
         status |= csound->AppendOpcode(csound, oentry->opname,
-                                       oentry->dsblksiz, oentry->thread,
+                                       oentry->dsblksiz, oentry->flags,
+                                       oentry->thread,
                                        oentry->outypes, oentry->intypes,
                                        (int (*)(CSOUND*,void*)) oentry->iopadr,
                                        (int (*)(CSOUND*,void*)) oentry->kopadr,
