@@ -57,20 +57,21 @@ static int datestringset(CSOUND *csound, DATESTRING *p)
     char *time_string;
     /* char *q; */
     int32 tmp;
+
 #if defined(MSVC) || (defined(__GNUC__) && defined(__i386__))
-    tmp = (int32) MYFLT2LRND(*(p->timstmp));
+   tmp = (int32) MYFLT2LRND(*(p->timstmp));
 #else
-    tmp = (int32) (*(p->timstmp) + FL(0.5));
+  tmp = (int32) (*(p->timstmp) + FL(0.5));
 #endif
     if (tmp <= 0) temp_time = time(NULL);
     else         temp_time = (time_t)tmp;
 
     time_string = ctime(&temp_time);
     /*    printf("Timestamp = %f\ntimestring=>%s<\n", *p->timstmp, time_string); */
-    p->Stime_->data[0] = '\0';
+
     /* q = strchr(time_string, '\n'); */
     /* if (q) *q='\0'; */
-    if(p->Stime_->data != NULL) csound->Free(csound, p->Stime_->data);
+    if (p->Stime_->data != NULL) csound->Free(csound, p->Stime_->data);
     p->Stime_->data = csound->Strdup(csound, time_string);
     p->Stime_->size = strlen(time_string)+1;
     return OK;
@@ -83,15 +84,15 @@ typedef struct {
 
 static int getcurdir(CSOUND *csound, GETCWD *p)
 {
-  if(p->Scd->data == NULL){
-    p->Scd->size = 1024;
-    p->Scd->data = csound->Calloc(csound, p->Scd->size);
-  }
+    if (p->Scd->data == NULL) {
+      p->Scd->size = 1024;
+      p->Scd->data = csound->Calloc(csound, p->Scd->size);
+    }
 
 #if defined(__MACH__) || defined(LINUX) || defined(__HAIKU__)
-   if (UNLIKELY(getcwd(p->Scd->data, p->Scd->size-1)==NULL))
+    if (UNLIKELY(getcwd(p->Scd->data, p->Scd->size-1)==NULL))
 #else
-   if (UNLIKELY( _getcwd(p->Scd->data, p->Scd->size-1)==NULL))
+    if (UNLIKELY( _getcwd(p->Scd->data, p->Scd->size-1)==NULL))
 #endif
       return csound->InitError(csound, Str("cannot determine current directory"));
     return OK;
@@ -125,7 +126,7 @@ static int readf_init_(CSOUND *csound, READF *p, int isstring)
     else csound->strarg2name(csound, name, p->Sfile, "input.", 0);
     p->fd = fopen(name, "r");
     p->lineno = 0;
-    if(p->Sline->data == NULL) {
+    if (p->Sline->data == NULL) {
       p->Sline->data = (char *) csound->Calloc(csound, MAXLINE);
     p->Sline->size = MAXLINE;
     }
@@ -135,11 +136,11 @@ static int readf_init_(CSOUND *csound, READF *p, int isstring)
 }
 
 static int readf_init(CSOUND *csound, READF *p){
-  return readf_init_(csound,p,0);
+    return readf_init_(csound,p,0);
 }
 
 static int readf_init_S(CSOUND *csound, READF *p){
-  return readf_init_(csound,p,1);
+    return readf_init_(csound,p,1);
 }
 
 
@@ -156,7 +157,8 @@ static int readf(CSOUND *csound, READF *p)
         return OK;
       }
       else
-        return csound->PerfError(csound, p->h.insdshead, Str("readf: read failure"));
+        return csound->PerfError(csound, p->h.insdshead,
+                                 Str("readf: read failure"));
     }
     *p->line = ++p->lineno;
     return OK;
