@@ -145,7 +145,7 @@ int make_FM4Op(CSOUND *csound, FM4OP *p)
     make_ADSR(&p->adsr[2]);
     make_ADSR(&p->adsr[3]);
     make_TwoZero(&p->twozero);
-    if (UNLIKELY((ftp = csound->FTFind(csound, p->vifn)) == NULL))
+    if (UNLIKELY((ftp = csound->FTnp2Find(csound, p->vifn)) == NULL))
       goto err1;
     p->vibWave = ftp;
     p->baseFreq = FL(440.0);
@@ -162,25 +162,26 @@ int make_FM4Op(CSOUND *csound, FM4OP *p)
     return OK;
  err1:
 /* Expect sine wave */
-    return csound->PerfError(csound, Str("No table for VibWaveato"));
+    return csound->PerfError(csound, p->h.insdshead,
+                             Str("No table for VibWaveato"));
 }
 
 static int FM4Op_loadWaves(CSOUND *csound, FM4OP *p)
 {
     FUNC        *ftp;
 
-    if (UNLIKELY((ftp = csound->FTFind(csound, p->ifn0)) == NULL)) goto err1;
+    if (UNLIKELY((ftp = csound->FTnp2Find(csound, p->ifn0)) == NULL)) goto err1;
     p->waves[0] = ftp;
-    if (UNLIKELY((ftp = csound->FTFind(csound, p->ifn1)) == NULL)) goto err1;
+    if (UNLIKELY((ftp = csound->FTnp2Find(csound, p->ifn1)) == NULL)) goto err1;
     p->waves[1] = ftp;
-    if (UNLIKELY((ftp = csound->FTFind(csound, p->ifn2)) == NULL)) goto err1;
+    if (UNLIKELY((ftp = csound->FTnp2Find(csound, p->ifn2)) == NULL)) goto err1;
     p->waves[2] = ftp;
-    if (UNLIKELY((ftp = csound->FTFind(csound, p->ifn3)) == NULL)) goto err1;
+    if (UNLIKELY((ftp = csound->FTnp2Find(csound, p->ifn3)) == NULL)) goto err1;
     p->waves[3] = ftp;
     p->w_time[0] = p->w_time[1] = p->w_time[2] = p->w_time[3] = FL(0.0);
     return OK;
  err1:
-    return csound->PerfError(csound,
+    return csound->PerfError(csound, p->h.insdshead,
                              Str("No table for FM4Op")); /* Expect sine wave */
 }
 
@@ -261,7 +262,8 @@ int tubebellset(CSOUND *csound, FM4OP *p)
     MYFLT       opt = *p->opt;
 
     if (UNLIKELY(make_FM4Op(csound,p))) return NOTOK;
-    if (UNLIKELY(FM4Op_loadWaves(csound,p))) return NOTOK; /* 4 x "rawwaves/sinewave.raw" */
+    if (UNLIKELY(FM4Op_loadWaves(csound,p)))
+      return NOTOK; /* 4 x "rawwaves/sinewave.raw" */
 
     FM4Op_setRatio(p, 0, FL(1.0)   * FL(0.995));
     FM4Op_setRatio(p, 1, FL(1.414) * FL(0.995));
@@ -299,7 +301,9 @@ int tubebell(CSOUND *csound, FM4OP *p)
 {
     MYFLT       amp = *p->amp * AMP_RSCALE; /* Normalised */
     MYFLT       *ar = p->ar;
-    int         n, nsmps = csound->ksmps;
+    uint32_t offset = p->h.insdshead->ksmps_offset;
+    uint32_t early  = p->h.insdshead->ksmps_no_end;
+    uint32_t n, nsmps = CS_KSMPS;
     MYFLT       c1 = *p->control1;
     MYFLT       c2 = *p->control2;
 
@@ -315,7 +319,12 @@ int tubebell(CSOUND *csound, FM4OP *p)
     p->w_rate[3] = p->baseFreq * p->ratios[3] * p->waves[3]->flen * csound->onedsr;
     p->v_rate = *p->vibFreq * p->vibWave->flen * csound->onedsr;
 
-    for (n=0;n<nsmps;n++) {
+    if (UNLIKELY(offset)) memset(ar, '\0', offset*sizeof(MYFLT));
+    if (UNLIKELY(early)) {
+      nsmps -= early;
+      memset(&ar[nsmps], '\0', early*sizeof(MYFLT));
+    }
+    for (n=offset;n<nsmps;n++) {
       MYFLT   lastOutput = FM4Alg5_tick(p, c1, c2);
       ar[n] = lastOutput*AMP_SCALE*FL(1.8);
     }
@@ -415,7 +424,9 @@ int wurley(CSOUND *csound, FM4OP *p)
 {
     MYFLT       amp = *p->amp * AMP_RSCALE; /* Normalised */
     MYFLT       *ar = p->ar;
-    int         n, nsmps = csound->ksmps;
+    uint32_t offset = p->h.insdshead->ksmps_offset;
+    uint32_t early  = p->h.insdshead->ksmps_no_end;
+    uint32_t n, nsmps = CS_KSMPS;
     MYFLT       c1 = *p->control1;
     MYFLT       c2 = *p->control2;
 
@@ -431,7 +442,12 @@ int wurley(CSOUND *csound, FM4OP *p)
     p->w_rate[3] =               p->ratios[3] * p->waves[3]->flen * csound->onedsr;
     p->v_rate = *p->vibFreq * p->vibWave->flen * csound->onedsr;
 
-    for (n=0;n<nsmps;n++) {
+    if (UNLIKELY(offset)) memset(ar, '\0', offset*sizeof(MYFLT));
+    if (UNLIKELY(early)) {
+      nsmps -= early;
+      memset(&ar[nsmps], '\0', early*sizeof(MYFLT));
+    }
+    for (n=offset;n<nsmps;n++) {
       MYFLT   lastOutput = FM4Alg5_tick(p, c1, c2);
       ar[n] = lastOutput*AMP_SCALE*FL(1.9);
     }
@@ -516,7 +532,9 @@ int heavymetset(CSOUND *csound, FM4OP *p)
 int heavymet(CSOUND *csound, FM4OP *p)
 {
     MYFLT       *ar = p->ar;
-    int         n, nsmps = csound->ksmps;
+    uint32_t offset = p->h.insdshead->ksmps_offset;
+    uint32_t early  = p->h.insdshead->ksmps_no_end;
+    uint32_t n, nsmps = CS_KSMPS;
     MYFLT       amp = *p->amp * AMP_RSCALE; /* Normalised */
     MYFLT       c1 = *p->control1;
     MYFLT       c2 = *p->control2;
@@ -534,7 +552,12 @@ int heavymet(CSOUND *csound, FM4OP *p)
     p->w_rate[2] = temp * p->ratios[2] * p->waves[2]->flen;
     p->w_rate[3] = temp * p->ratios[3] * p->waves[3]->flen;
     p->v_rate = *p->vibFreq * p->vibWave->flen * csound->onedsr;
-    for (n=0;n<nsmps;n++) {
+    if (UNLIKELY(offset)) memset(ar, '\0', offset*sizeof(MYFLT));
+    if (UNLIKELY(early)) {
+      nsmps -= early;
+      memset(&ar[nsmps], '\0', early*sizeof(MYFLT));
+    }
+    for (n=offset;n<nsmps;n++) {
       MYFLT   lastOutput;
       lastOutput = FM4Alg3_tick(p, c1, c2);
       ar[n] = lastOutput*AMP_SCALE*FL(2.0);
@@ -624,7 +647,9 @@ int hammondB3(CSOUND *csound, FM4OP *p)
 {
     MYFLT       amp = *p->amp * AMP_RSCALE; /* Normalised */
     MYFLT       *ar = p->ar;
-    int         n, nsmps = csound->ksmps;
+    uint32_t offset = p->h.insdshead->ksmps_offset;
+    uint32_t early  = p->h.insdshead->ksmps_no_end;
+     uint32_t n, nsmps = CS_KSMPS;
     MYFLT       c1 = *p->control1;
     MYFLT       c2 = *p->control2;
     MYFLT       temp;
@@ -634,7 +659,12 @@ int hammondB3(CSOUND *csound, FM4OP *p)
     p->gains[1] = amp * FM4Op_gains[95];
     p->gains[2] = amp * FM4Op_gains[99];
     p->gains[3] = amp * FM4Op_gains[95];
-    for (n=0;n<nsmps;n++) {
+    if (UNLIKELY(offset)) memset(ar, '\0', offset*sizeof(MYFLT));
+    if (UNLIKELY(early)) {
+      nsmps -= early;
+      memset(&ar[nsmps], '\0', early*sizeof(MYFLT));
+    }
+    for (n=offset;n<nsmps;n++) {
       MYFLT   lastOutput;
       if (*p->modDepth > FL(0.0)) {
         p->v_rate = *p->vibFreq * p->vibWave->flen * csound->onedsr;
@@ -943,13 +973,6 @@ int FMVoiceset(CSOUND *csound, FM4OPV *q)
                      FM4Op_susLevels[15], FL(0.050));
     ADSR_setAllTimes(csound, &p->adsr[3], FL(0.001), FL(0.010),
                      FM4Op_susLevels[15], FL(0.500));
-    /*      ADSR_setAll(&p->adsr[0], FL(0.001), FL(0.001),
-            FM4Op_susLevels[15], FL(0.001)); */
-    /*      ADSR_setAll(&p->adsr[1], FL(0.001), FL(0.001),
-            FM4Op_susLevels[15], FL(0.001)); */
-    /*      ADSR_setAll(&p->adsr[2], FL(0.001), FL(0.001),
-            FM4Op_susLevels[15], FL(0.001)); */
-    /*      ADSR_setAll(&p->adsr[3], 0.05f,  0.05f,  FM4Op_susLevels[15], 0.0001f); */
     p->twozero.gain = FL(0.0);
     /*     modDepth = 0.005; */
     q->tilt[0] = FL(1.0);
@@ -976,7 +999,9 @@ int FMVoice(CSOUND *csound, FM4OPV *q)
     FM4OP       *p = (FM4OP *)q;
     MYFLT       amp = *q->amp * AMP_RSCALE;
     MYFLT       *ar = q->ar;
-    int         n, nsmps = csound->ksmps;
+    uint32_t offset = p->h.insdshead->ksmps_offset;
+    uint32_t early  = p->h.insdshead->ksmps_no_end;
+    uint32_t n, nsmps = CS_KSMPS;
 
     if (p->baseFreq != *q->frequency || *q->control1 != q->last_control) {
       q->last_control = *q->control1;
@@ -988,7 +1013,12 @@ int FMVoice(CSOUND *csound, FM4OPV *q)
     q->tilt[2] = amp * amp * amp;
     p->gains[3] = FM4Op_gains[(int) (*p->control2 * FL(0.78125))];
 
-    for (n=0;n<nsmps;n++) {
+    if (UNLIKELY(offset)) memset(ar, '\0', offset*sizeof(MYFLT));
+    if (UNLIKELY(early)) {
+      nsmps -= early;
+      memset(&ar[nsmps], '\0', early*sizeof(MYFLT));
+    }
+    for (n=offset;n<nsmps;n++) {
       MYFLT   lastOutput;
       lastOutput = FM4Alg6_tick(csound,q);
       ar[n] = lastOutput*AMP_SCALE*FL(0.8);
@@ -1053,7 +1083,8 @@ int percfluteset(CSOUND *csound, FM4OP *p)
     MYFLT       amp = *p->amp * AMP_RSCALE; /* Normalised */
 
     if (UNLIKELY(make_FM4Op(csound,p))) return NOTOK;
-    if (UNLIKELY(FM4Op_loadWaves(csound,p))) return NOTOK;  /* 3 x sines; 1 x fwavblnk */
+    if (UNLIKELY(FM4Op_loadWaves(csound,p)))
+      return NOTOK;  /* 3 x sines; 1 x fwavblnk */
 
     FM4Op_setRatio(p, 0, FL(1.50)            );
     FM4Op_setRatio(p, 1, FL(3.00) * FL(0.995));
@@ -1072,10 +1103,6 @@ int percfluteset(CSOUND *csound, FM4OP *p)
                      FM4Op_susLevels[11], FL(0.05));
     ADSR_setAllTimes(csound, &p->adsr[3], FL(0.02), FL(0.05),
                      FM4Op_susLevels[13], FL(0.01));
-    /*  ADSR_setAll(&p->adsr[0],FL(0.001),FL(0.001),FM4Op_susLevels[14], FL(0.001));*/
-    /*  ADSR_setAll(&p->adsr[1], 0.05f,  0.0001f, FM4Op_susLevels[13], 0.0001f); */
-    /*  ADSR_setAll(&p->adsr[2], 0.05f,  0.0020f, FM4Op_susLevels[11], FL(0.001)); */
-    /*  ADSR_setAll(&p->adsr[3], 0.05f,  0.0010f, FM4Op_susLevels[13], FL(0.005)); */
     p->twozero.gain = FL(0.0);
     /*     modDepth = FL(0.005); */
     ADSR_keyOn(&p->adsr[0]);
@@ -1088,7 +1115,9 @@ int percfluteset(CSOUND *csound, FM4OP *p)
 int percflute(CSOUND *csound, FM4OP *p)
 {
     MYFLT       *ar = p->ar;
-    int         n, nsmps = csound->ksmps;
+    uint32_t offset = p->h.insdshead->ksmps_offset;
+    uint32_t early  = p->h.insdshead->ksmps_no_end;
+    uint32_t n, nsmps = CS_KSMPS;
     MYFLT       amp = *p->amp * AMP_RSCALE; /* Normalised */
     MYFLT       c1 = *p->control1;
     MYFLT       c2 = *p->control2;
@@ -1099,7 +1128,13 @@ int percflute(CSOUND *csound, FM4OP *p)
     p->gains[2] = amp * FM4Op_gains[93] * FL(0.5);
     p->gains[3] = amp * FM4Op_gains[85] * FL(0.5);
     p->v_rate = *p->vibFreq * p->vibWave->flen * csound->onedsr;
-    for (n=0;n<nsmps;n++) {
+
+    if (UNLIKELY(offset)) memset(ar, '\0', offset*sizeof(MYFLT));
+    if (UNLIKELY(early)) {
+      nsmps -= early;
+      memset(&ar[nsmps], '\0', early*sizeof(MYFLT));
+    }
+    for (n=offset;n<nsmps;n++) {
       MYFLT   lastOutput = FM4Alg4_tick(csound, p, c1, c2);
       ar[n] = lastOutput*AMP_SCALE*FL(2.0);
     }
