@@ -21,7 +21,7 @@
     02111-1307 USA
 */
 
-#include "csdl.h"
+#include "stdopcod.h"
 #include <math.h>
 
 #define FTCONV_MAXCHN   8
@@ -64,7 +64,7 @@ static void multiply_fft_buffers(MYFLT *outBuf, MYFLT *ringBuf,
     irPtr = IR_Data;
     outBufPtr = outBuf;
     /* clear output buffer to zero */
-    memset(outBuf, 0, sizeof(MYFLT)*(partSize - 2));
+    memset(outBuf, 0, sizeof(MYFLT)*(partSize));
     /* do { */
     /*   *(outBufPtr++) = FL(0.0); */
     /*   *(outBufPtr++) = FL(0.0); */
@@ -161,7 +161,7 @@ static int ftconv_init(CSOUND *csound, FTCONV *p)
       return csound->InitError(csound, Str("ftconv: invalid impulse response "
                                            "partition length"));
     }
-    ftp = csound->FTFind(csound, p->iFTNum);
+    ftp = csound->FTnp2Find(csound, p->iFTNum);
     if (UNLIKELY(ftp == NULL))
       return NOTOK; /* ftfind should already have printed the error message */
     /* calculate total length / number of partitions */
@@ -242,13 +242,23 @@ static int ftconv_init(CSOUND *csound, FTCONV *p)
 static int ftconv_perf(CSOUND *csound, FTCONV *p)
 {
     MYFLT         *x, *rBuf;
-    int           i, n, nn, nSamples, rBufPos;
-    int           m = csound->ksmps;
+    int           i, n, nSamples, rBufPos;
+    uint32_t offset = p->h.insdshead->ksmps_offset;
+    uint32_t early  = p->h.insdshead->ksmps_no_end;
+    uint32_t nn, nsmps = CS_KSMPS;
 
     if (p->initDone <= 0) goto err1;
     nSamples = p->partSize;
     rBuf = &(p->ringBuf[p->rbCnt * (nSamples << 1)]);
-    for (nn = 0; nn < m; nn++) {
+    if (UNLIKELY(offset))
+      for (n = 0; n < p->nChannels; n++)
+        memset(p->aOut[n], '\0', offset*sizeof(MYFLT));
+    if (UNLIKELY(early)) {
+      nsmps -= early;
+      for (n = 0; n < p->nChannels; n++)
+        memset(&p->aOut[n][nsmps], '\0', early*sizeof(MYFLT));
+    }
+    for (nn = offset; nn < nsmps; nn++) {
       /* store input signal in buffer */
       rBuf[p->cnt] = p->aIn[nn];
       /* copy output signals from buffer */
@@ -286,7 +296,8 @@ static int ftconv_perf(CSOUND *csound, FTCONV *p)
     }
     return OK;
  err1:
-    return csound->PerfError(csound, Str("ftconv: not initialised"));
+    return csound->PerfError(csound, p->h.insdshead,
+                             Str("ftconv: not initialised"));
 }
 
 /* module interface functions */
@@ -294,7 +305,7 @@ static int ftconv_perf(CSOUND *csound, FTCONV *p)
 int ftconv_init_(CSOUND *csound)
 {
     return csound->AppendOpcode(csound, "ftconv",
-                                (int) sizeof(FTCONV), TR|5, "mmmmmmmm", "aiiooo",
+                                (int) sizeof(FTCONV), TR, 5, "mmmmmmmm", "aiiooo",
                                 (int (*)(CSOUND *, void *)) ftconv_init,
                                 (int (*)(CSOUND *, void *)) NULL,
                                 (int (*)(CSOUND *, void *)) ftconv_perf);
