@@ -47,12 +47,12 @@ static int grainsetv4(CSOUND *csound, GRAINV4 *p)
 {
     FUNC        *ftp, *ftp_env;
     int         nvoice, cnt;
-    int32       tmplong1, tmplong2;
+    int32_t    tmplong1, tmplong2;
     MYFLT       tmpfloat1;
     MYFLT       pitch[4];
 
     /* call ftfind() to get the function table...*/
-    if (LIKELY((ftp = csound->FTFind(csound, p->ifn)) != NULL)) {
+    if (LIKELY((ftp = csound->FTnp2Find(csound, p->ifn)) != NULL)) {
       p->ftp = ftp;
     }
     else {
@@ -62,7 +62,7 @@ static int grainsetv4(CSOUND *csound, GRAINV4 *p)
 
     /* call ftfind() to get the function table for the envelop...*/
     if (*p->ifnenv > 0) {
-      if (LIKELY((ftp_env = csound->FTFind(csound, p->ifnenv)) != NULL)) {
+      if (LIKELY((ftp_env = csound->FTnp2Find(csound, p->ifnenv)) != NULL)) {
         p->ftp_env = ftp_env;
       }
       else {
@@ -119,7 +119,7 @@ static int grainsetv4(CSOUND *csound, GRAINV4 *p)
       }
     }
 
-    if (UNLIKELY((*p->igskip < 0) || (*p->igskip * csound->esr > ftp->flen) )) {
+    if (UNLIKELY((*p->igskip < 0) || (*p->igskip * CS_ESR > ftp->flen) )) {
       return csound->InitError(csound, Str("granule_set: must be positive and "
                                            "less than function table length"));
     }
@@ -128,8 +128,8 @@ static int grainsetv4(CSOUND *csound, GRAINV4 *p)
                                            "igskip_os must be greater then 0"));
     }
 
-    p->gstart = (int32)(*p->igskip * csound->esr);
-    p->glength = (int32)(*p->ilength * csound->esr);
+    p->gstart = (int32)(*p->igskip * CS_ESR);
+    p->glength = (int32)(*p->ilength * CS_ESR);
     p->gend = p->gstart + p->glength;
 
     if (UNLIKELY(*p->kgap < 0)) {
@@ -160,7 +160,7 @@ static int grainsetv4(CSOUND *csound, GRAINV4 *p)
     }
 
                                 /* Initialize variables....*/
-    p->gskip_os = (int32)(*p->igskip_os * csound->esr);/* in number of samples */
+    p->gskip_os = (int32)(*p->igskip_os * CS_ESR);/* in number of samples */
     p->gap_os = *p->igap_os / FL(100.0);
     p->gsize_os = *p->igsize_os / FL(100.0);
 
@@ -168,8 +168,8 @@ static int grainsetv4(CSOUND *csound, GRAINV4 *p)
       p->fpnt[nvoice] = 0;
       p->cnt[nvoice]  = 0;
       p->phs[nvoice]  = FL(0.0);
-      p->gskip[nvoice] = (int32)(*p->igskip * csound->esr);
-      p->gap[nvoice] = (int32)(*p->kgap * csound->esr);
+      p->gskip[nvoice] = (int32)(*p->igskip * CS_ESR);
+      p->gap[nvoice] = (int32)(*p->kgap * CS_ESR);
     }
 
     if (*p->igap_os != 0) {
@@ -206,7 +206,7 @@ static int grainsetv4(CSOUND *csound, GRAINV4 *p)
     }
 
     for (nvoice = 0; nvoice < *p->ivoice; nvoice++)
-      p->gsize[nvoice] = (int32)(*p->kgsize * csound->esr * p->pshift[nvoice]);
+      p->gsize[nvoice] = (int32)(*p->kgsize * CS_ESR * p->pshift[nvoice]);
 
     if (*p->igsize_os != 0) {
       for (nvoice = 0; nvoice < *p->ivoice; nvoice++)
@@ -218,23 +218,24 @@ static int grainsetv4(CSOUND *csound, GRAINV4 *p)
 
     if (*p->igskip_os != 0)
       for (nvoice = 0; nvoice < *p->ivoice; nvoice++) {
-        tmplong1 = (int32)((p->gskip_os * grand(p)) + (MYFLT)p->gskip[nvoice]);
-        p->gskip[nvoice] = (tmplong1 < p->gstart) ? p->gstart : tmplong1;
+        tmplong1 = ((p->gskip_os * grand(p)) + (MYFLT)p->gskip[nvoice]);
+        p->gskip[nvoice] =
+          (tmplong1 < p->gstart) ? p->gstart : tmplong1;
         p->gskip[nvoice]=
-          ((p->gskip[nvoice]+p->stretch[nvoice])>p->gend) ?
-          p->gstart :
+          ((p->gskip[nvoice]+p->stretch[nvoice])>(int32)p->gend) ?
+          (int32)p->gstart :
           p->gskip[nvoice];
       }
 
     if (*p->ithd != 0) {        /* Do thresholding.... */
       tmplong2 = 0;
-      for (tmplong1=0; tmplong1<ftp->flen; tmplong1++)
-        if (fabs(*(ftp->ftable + tmplong1)) >= *p->ithd )
-          *(ftp->ftable + tmplong2++) = *(ftp->ftable + tmplong1);
+      for (tmplong1=0; tmplong1< (int) ftp->flen; tmplong1++)
+        if (fabs(ftp->ftable[tmplong1]) >= *p->ithd )
+          ftp->ftable[tmplong2++] = ftp->ftable[tmplong1];
       ftp->flen = tmplong2;
     }
 
-    if (p->gend > ftp->flen) {
+    if (p->gend > (int) ftp->flen) {
       return csound->InitError(csound, Str("granule_set: Illegal combination "
                                            "of igskip and ilength"));
     }
@@ -261,7 +262,9 @@ static int graingenv4(CSOUND *csound, GRAINV4 *p)
 {
     FUNC        *ftp, *ftp_env;
     MYFLT       *ar, *ftbl, *ftbl_env=NULL;
-    int         n, nsmps = csound->ksmps;
+    uint32_t offset = p->h.insdshead->ksmps_offset;
+    uint32_t early  = p->h.insdshead->ksmps_no_end;
+    uint32_t n, nsmps = CS_KSMPS;
     int         nvoice;
     int32       tmplong1, tmplong2, tmplong3, tmpfpnt, flen_env=0;
     MYFLT       fract, v1, tmpfloat1;
@@ -287,9 +290,13 @@ static int graingenv4(CSOUND *csound, GRAINV4 *p)
 
    /* Recover audio output pointer... */
    ar   = p->ar;
-
+   if (UNLIKELY(offset)) memset(ar, '\0', offset*sizeof(MYFLT));
+    if (UNLIKELY(early)) {
+      nsmps -= early;
+      memset(&ar[nsmps], '\0', early*sizeof(MYFLT));
+    }
    /* *** Start the loop .... *** */
-   for (n=0; n<nsmps; n++) {                         /* while (--nsmps) */
+   for (n=offset; n<nsmps; n++) {                         /* while (--nsmps) */
                                 /* Optimisations */
      int32      *fpnt = p->fpnt, *cnt = p->cnt, *gskip = p->gskip;
      int32      *gap = p->gap, *gsize = p->gsize;
@@ -297,7 +304,7 @@ static int graingenv4(CSOUND *csound, GRAINV4 *p)
      MYFLT      *pshift = p->pshift, *phs = p->phs;
      ar[n] = FL(0.0);
 
-     for (nvoice = 0; nvoice < *p->ivoice; nvoice++) {
+     for (nvoice = 0; nvoice <  *p->ivoice ; nvoice++) {
        if (*fpnt >= (*gsize -1)) {
          ar[n] += 0;            /* Is this necessary?? */
          *cnt +=1L;
@@ -396,12 +403,12 @@ static int graingenv4(CSOUND *csound, GRAINV4 *p)
                (tmpfloat1*FL(0.5))+FL(1.0) : tmpfloat1+FL(1.0);
            }
 
-           *gap = (int32)(*p->kgap * csound->esr);
+           *gap = (int32)(*p->kgap * CS_ESR);
            if (*p->igap_os != 0) {
              *gap += (int32)((*gap * p->gap_os) * grand(p));
            }
 
-           *gsize = (int32)(*p->kgsize * csound->esr * *pshift);
+           *gsize = (int32)(*p->kgsize * CS_ESR * *pshift);
            if (*p->igsize_os != 0)
              *gsize += (int32)((*gsize * p->gsize_os) * grand(p));
 
@@ -416,7 +423,8 @@ static int graingenv4(CSOUND *csound, GRAINV4 *p)
    }
    return OK;
  err1:
-   return csound->PerfError(csound, Str("grain4: not initialised"));
+   return csound->PerfError(csound, p->h.insdshead,
+                            Str("grain4: not initialised"));
 
 } /* end graingenv4(p) */
 
@@ -430,9 +438,14 @@ static MYFLT grand( GRAINV4 *p)
 
 #define S(x)    sizeof(x)
 
+
+
+
+
+
 static OENTRY grain4_localops[] = {
-  { "granule", S(GRAINV4), TR|5, "a", "xiiiiiiiiikikiiivppppo",
+  { "granule", S(GRAINV4), TR, 5, "a", "xiiiiiiiiikikiiivppppo",
              (SUBR)grainsetv4, NULL, (SUBR)graingenv4},
 };
 
-LINKAGE1(grain4_localops)
+LINKAGE_BUILTIN(grain4_localops)
