@@ -40,7 +40,12 @@ typedef struct {
 #define VOCMAX  4
 
 typedef struct {
-        MYFLT   *ar, *asig, *koct, *icpsmode, *ilowest, *ipolarity;
+        OPDS    h;
+        MYFLT   *ar, *asig, *koct, *kfrq1, *kfrq2;
+        MYFLT   *kfrq3, *kfrq4, *icpsmode, *ilowest, *ipolarity;  //4
+  // or MYFLT   *kfrq3, *icpsmode, *ilowest, *ipolarity, *dummy;  //3
+  // or MYFLT   *icpsmode, *ilowest, *ipolarity, *dummy, *dummy1; //2
+  //Local
         int16   nbufsmps, n2bufsmps, period, cpsmode, polarity, poslead;
         MYFLT   prvoct, minoct, sicvt;
         MYFLT   *bufp, *midp, *inp1, *inp2;
@@ -53,83 +58,92 @@ typedef struct {
         int     hmrngflg;
 } HARM234;
 
-typedef struct {
-        OPDS    h;
-        MYFLT   *ar, *asig, *koct, *kfrq1, *kfrq2,
-                *icpsmode, *ilowest, *ipolarity;
-        HARM234 hrmdat;
-} HARMON2;
-
-typedef struct {
-        OPDS    h;
-        MYFLT   *ar, *asig, *koct, *kfrq1, *kfrq2, *kfrq3,
-                *icpsmode, *ilowest, *ipolarity;
-        HARM234 hrmdat;
-} HARMON3;
-
-typedef struct {
-        OPDS    h;
-        MYFLT   *ar, *asig, *koct, *kfrq1, *kfrq2, *kfrq3, *kfrq4,
-                *icpsmode, *ilowest, *ipolarity;
-        HARM234 hrmdat;
-} HARMON4;
-
+static void print_data(HARM234* p, int x)
+{
+    printf("DATA %d\n=======\n", x);
+    printf("nbufsmps, n2bufsmps, period, cpsmode, polarity, poslead "
+           "= (%d,%d,%d,%d,%d,%d\n",
+           p->nbufsmps, p->n2bufsmps, p->period, p->cpsmode, p->polarity,
+           p->poslead);
+    printf("prvoct, minoct, sicvt = %f, %f, %f\n", p->prvoct, p->minoct, p->sicvt);
+    //MYFLT   *bufp, *midp, *inp1, *inp2;
+    //MYFLT   *pulsbuf[4], *sigmoid, *curpuls;
+    printf("vocamp, vocinc, ampinc = %f, %f, %f\n",
+           p->vocamp, p->vocinc, p->ampinc);
+    //PULDAT  puldat[PULMAX], *endp, *limp;
+    //VOCDAT  vocdat[VOCMAX], *vlim;
+    printf("pbufcnt, maxprd, pulslen, switching = %d, %d, %d, %d, %d\n",
+           p->pbufcnt, p->maxprd, p->pulslen, p->switching, p->hmrngflg);
+    //AUXCH   auxch;
+    //int     hmrngflg;
+    printf("pulse: %p %p %p %p; %d %d %d %d\n",
+           p->puldat[0].srcp, p->puldat[1].srcp,
+           p->puldat[2].srcp, p->puldat[3].srcp,
+           p->puldat[0].cntr, p->puldat[1].cntr,
+           p->puldat[2].cntr, p->puldat[3].cntr);
+    printf("voc: (%p %d %d) (%p %d %d) (%p %d %d) (%p %d %d)\n",
+           p->vocdat[0].kfrq, p->vocdat[0].phase, p->vocdat[0].phsinc,
+           p->vocdat[1].kfrq, p->vocdat[1].phase, p->vocdat[1].phsinc,
+           p->vocdat[2].kfrq, p->vocdat[2].phase, p->vocdat[2].phsinc,
+           p->vocdat[3].kfrq, p->vocdat[3].phase, p->vocdat[3].phsinc);
+    printf("output: %f %f %f %f ...\n", p->ar[0], p->ar[1], p->ar[2], p->ar[3]);
+}
 #define PBUFS   4
 #define PBMSK   0x3
 #define SLEN    256
 #define LCNT    75
 
-static int hm234set(CSOUND *csound, HARM234 *q, HARMON2 *p)
+static int hm234set(CSOUND *csound, HARM234 *p)
 {
-    MYFLT minoct = *q->ilowest;
-    q->hmrngflg = 0;
-    if (q->auxch.auxp == NULL || minoct < q->minoct) {
+    MYFLT minoct = p->minoct;
+    p->hmrngflg = 0;
+    /*if (p->auxch.auxp == NULL || minoct < p->minoct ) */ {
       MYFLT minfrq = POWER(FL(2.0), minoct) * ONEPT;
-      int16 nbufs =
-        (int16)(CS_EKR * 3 / minfrq) + 1;/* recalc max pulse prd */
+      int16 nbufs = (int16)(csound->ekr * 3 / minfrq) + 1;/* recalc max pulse prd */
       int16 nbufsmps = nbufs * CS_KSMPS;
-      int16 maxprd = (int16)(CS_ESR * 2 / minfrq);   /* incl sigmoid ends */
+      int16 maxprd = (int16)(csound->esr * 2 / minfrq);   /* incl sigmoid ends */
       int16 cnt;
       int32  totalsiz = nbufsmps * 2 + maxprd * 4 + (SLEN+1);
       MYFLT *pulsbuf, *sigp;                            /*  & realloc buffers */
 
-      csound->AuxAlloc(csound, totalsiz * sizeof(MYFLT), &q->auxch);
-      q->bufp = (MYFLT *) q->auxch.auxp;
-      q->midp = q->bufp + nbufsmps;                     /* each >= maxprd * 3 */
-      pulsbuf = q->midp + nbufsmps;
-      q->pulsbuf[0] = pulsbuf;  pulsbuf += maxprd;
-      q->pulsbuf[1] = pulsbuf;  pulsbuf += maxprd;
-      q->pulsbuf[2] = pulsbuf;  pulsbuf += maxprd;
-      q->pulsbuf[3] = pulsbuf;  pulsbuf += maxprd;      /* cnt must = PBUFS     */
-      q->sigmoid = sigp = pulsbuf;
+      csound->AuxAlloc(csound, totalsiz * sizeof(MYFLT), &p->auxch);
+      p->bufp = (MYFLT *) p->auxch.auxp;
+      p->midp = p->bufp + nbufsmps;                     /* each >= maxprd * 3 */
+      pulsbuf = p->midp + nbufsmps;
+      p->pulsbuf[0] = pulsbuf;  pulsbuf += maxprd;
+      p->pulsbuf[1] = pulsbuf;  pulsbuf += maxprd;
+      p->pulsbuf[2] = pulsbuf;  pulsbuf += maxprd;
+      p->pulsbuf[3] = pulsbuf;  pulsbuf += maxprd;      /* cnt must = PBUFS     */
+      p->sigmoid = sigp = pulsbuf;
       for (cnt = 0; cnt < SLEN+1; cnt++)                /* make sigmoid inplace */
         *sigp++ = (FL(1.0) - COS(PI_F * cnt / SLEN)) * FL(0.5);
-      q->maxprd = maxprd;
-      q->nbufsmps = nbufsmps;
-      q->n2bufsmps = nbufsmps * 2;
+      p->maxprd = maxprd;
+      p->nbufsmps = nbufsmps;
+      p->n2bufsmps = nbufsmps * 2;
     }
-    q->minoct = minoct;
-    q->sicvt = FL(65536.0) * csound->onedsr;
-    q->cpsmode = ((*q->icpsmode != FL(0.0)));
-    q->polarity = (int16)*q->ipolarity;
-    q->poslead = 0;
-    q->inp1 = q->bufp;
-    q->inp2 = q->midp;
-    q->endp = q->puldat;                        /* nothing in PULDAT array */
-    q->limp = q->puldat + PULMAX;
-    q->prvoct = FL(0.0);
-    q->period = 0;
-    q->curpuls = NULL;
-    q->pbufcnt = 0;
-    q->vocamp = FL(0.0);                        /* begin unvoiced */
-    q->ampinc = FL(10.0) * csound->onedsr;      /* .1 sec lin ramp for uv to v */
-    q->switching = 0;
+    //p->minoct = minoct;
+    p->sicvt = FL(65536.0) * csound->onedsr;
+    //printf("sicvt = %f\n", p->sicvt);
+    //    p->polarity = (int16)*p->ipolarity;
+    p->poslead = 0;
+    p->inp1 = p->bufp;
+    p->inp2 = p->midp;
+    p->endp = p->puldat;                        /* nothing in PULDAT array */
+    p->limp = p->puldat + PULMAX;
+    p->prvoct = FL(0.0);
+    p->period = 0;
+    p->curpuls = NULL;
+    p->pbufcnt = 0;
+    p->vocamp = FL(0.0);                        /* begin unvoiced */
+    p->ampinc = FL(10.0) * csound->onedsr;      /* .1 sec lin ramp for uv to v */
+    //printf("ampinc = %f\n", p->ampinc);
+    p->switching = 0;
     return OK;
 }
 
-static int harmon234(CSOUND *csound, HARM234 *q, HARMON2 *p)
+static int harmon234(CSOUND *csound, HARM234 *p)
 {
-    MYFLT       *outp, *dirp; // *srcp,
+    MYFLT       *outp, *dirp;
     MYFLT       *inp1, *inp2;
     MYFLT       koct, vocamp, diramp;
     PULDAT      *endp;
@@ -137,18 +151,19 @@ static int harmon234(CSOUND *csound, HARM234 *q, HARMON2 *p)
     int16       nsmps = CS_KSMPS, oflow = 0;
     uint32_t offset = p->h.insdshead->ksmps_offset;
     uint32_t early  = p->h.insdshead->ksmps_no_end;
+    //print_data(p, 1);
 
-    if ((koct = *q->koct) != q->prvoct) {               /* if new pitch estimate */
-      if (koct >= q->minoct) {                          /*   above requested low */
+    if ((koct = *p->koct) != p->prvoct) {               /* if new pitch estimate */
+      if (koct >= p->minoct) {                          /*   above requested low */
         MYFLT cps = POWER(FL(2.0), koct) * ONEPT;     /*   recalc pulse period */
-        q->period = (int16) (CS_ESR / cps);
-        if (!q->cpsmode)
-          q->sicvt = cps * FL(65536.0) * csound->onedsr; /* k64dsr;*/
+        p->period = (int16) (CS_ESR / cps);
+        if (!p->cpsmode)
+          p->sicvt = cps * FL(65536.0) * csound->onedsr; /* k64dsr;*/
       }
-      q->prvoct = koct;
+      p->prvoct = koct;
     }
-    inp1 = q->inp1;
-    inp2 = q->inp2;
+    inp1 = p->inp1;
+    inp2 = p->inp2;
     if (UNLIKELY(offset)) {
       memset(inp1, '\0', offset*sizeof(MYFLT));
       memset(inp2, '\0', offset*sizeof(MYFLT));
@@ -158,20 +173,22 @@ static int harmon234(CSOUND *csound, HARM234 *q, HARMON2 *p)
       memset(&inp1[nsmps], '\0', early*sizeof(MYFLT));
       memset(&inp2[nsmps], '\0', early*sizeof(MYFLT));
     }
-    memcpy(&inp1[offset], &q->asig[offset], sizeof(MYFLT)*(nsmps-offset));
-    memcpy(&inp2[offset], &q->asig[offset], sizeof(MYFLT)*(nsmps-offset));
+    memcpy(&inp1[offset], &p->asig[offset], sizeof(MYFLT)*(nsmps-offset));
+    memcpy(&inp2[offset], &p->asig[offset], sizeof(MYFLT)*(nsmps-offset));
+    inp1 += nsmps-offset; inp2 += nsmps-offset;
     //for (srcp = q->asig, nsmps = CS_KSMPS; nsmps--; )
     //  *inp1++ = *inp2++ = *srcp++;              /* dbl store the wavform */
 
-    if (koct >= q->minoct) {                    /* PERIODIC: find the pulse */
+    //print_data(p, 2);
+    if (koct >= p->minoct) {                    /* PERIODIC: find the pulse */
       MYFLT     val0, *buf0, *p0, *plim, *x;
       int16     period, triprd, xdist;
 
-      period = q->period;                       /* set srch range of 2 periods */
+      period = p->period;                       /* set srch range of 2 periods */
       triprd = period * 3;
       p0 = inp2 - triprd;                       /* btwn 3 prds back & 1 prd back */
       plim = inp2 - period;
-      buf0 = q->bufp;
+      buf0 = p->bufp;
       if (UNLIKELY(p0 < buf0))
         p0 = buf0;
 
@@ -183,7 +200,7 @@ static int harmon234(CSOUND *csound, HARM234 *q, HARMON2 *p)
       else while (*x < FL(0.0) && ++x < plim);
       if (x >= plim) goto nonprd;               /*      then non-periodic       */
 
-      if (q->polarity > 0) {
+      if (p->polarity > 0) {
         MYFLT pospk = FL(0.0);                  /* POSITIVE polarity:   */
         MYFLT *posp = NULL;
         for ( ; x < plim; x++) {                /*      find ensuing max val */
@@ -195,8 +212,7 @@ static int harmon234(CSOUND *csound, HARM234 *q, HARMON2 *p)
         for (x = posp;
              x >= buf0 && *x > FL(0.0); x--);   /* & its preceding z-crossing */
         xdist = posp - x;
-      }
-      else if (q->polarity < 0) {
+      } else if (p->polarity < 0) {
         MYFLT negpk = FL(0.0);                  /* NEGATIVE polarity:   */
         MYFLT *negp = NULL;
         for ( ; x < plim; x++) {                /* find ensuing min val */
@@ -234,20 +250,20 @@ static int harmon234(CSOUND *csound, HARM234 *q, HARMON2 *p)
 
         if (pospk / posdist > -negpk / negdist) {
           /* find z-cross with grtst slope to peak */
-          if (UNLIKELY(q->poslead < LCNT)) {   /*      and consistent polarity */
-            if (q->poslead == 1)
+          if (UNLIKELY(p->poslead < LCNT)) {   /*      and consistent polarity */
+            if (p->poslead == 1)
               csound->Warning(csound, Str("harm signal has positive lead\n"));
-            q->poslead += 1;
+            p->poslead += 1;
           }
         }
         else {
-          if (UNLIKELY(q->poslead > -LCNT)) {
-            if (q->poslead == -1)
+          if (UNLIKELY(p->poslead > -LCNT)) {
+            if (p->poslead == -1)
               csound->Warning(csound, Str("harm signal has negative lead\n"));
-            q->poslead -= 1;
+            p->poslead -= 1;
           }
-        }
-        if (q->poslead >= 0) {                  /* use this as pulse beginning  */
+       }
+        if (p->poslead >= 0) {                  /* use this as pulse beginning  */
           x = poscross;
           xdist = posdist;
         }
@@ -257,12 +273,12 @@ static int harmon234(CSOUND *csound, HARM234 *q, HARMON2 *p)
         }
       }
 
-      if (x != q->curpuls) {                    /* if pulse positn is new       */
+      if (x != p->curpuls) {                    /* if pulse positn is new       */
         int16 nn, pulslen, sigdist, ndirect;
         MYFLT *bufp, signdx, siginc;
         MYFLT *z, zval;
 
-        q->curpuls = x;                         /*      record this new positn  */
+        p->curpuls = x;                         /*      record this new positn  */
         z = x + period;                         /*  and from estimated end      */
         if ((zval = *z) != FL(0.0)) {
           int16 n, nlim = inp2 - z;
@@ -283,19 +299,19 @@ static int harmon234(CSOUND *csound, HARM234 *q, HARMON2 *p)
         else if (z > inp2)
           z = inp2;                             /*      by input limits         */
         pulslen = z - x;
-        if (pulslen > q->maxprd)
-          pulslen = q->maxprd;                  /*      & storage limits        */
+        if (pulslen > p->maxprd)
+          pulslen = p->maxprd;                  /*      & storage limits        */
         sigdist = xdist * 2;
         ndirect = pulslen - sigdist*2;
         if (ndirect < 0) goto nostor;
 
-        q->pbufcnt++;                           /* select a new puls buffr      */
-        q->pbufcnt &= PBMSK;
-        bufp = q->pulsbuf[q->pbufcnt];
+        p->pbufcnt++;                           /* select a new puls buffr      */
+        p->pbufcnt &= PBMSK;
+        bufp = p->pulsbuf[p->pbufcnt];
         signdx = FL(0.0);                       /*      & store extended pulse  */
         siginc = (MYFLT)SLEN / sigdist;
         for (nn = sigdist; nn--; signdx += siginc) {
-          MYFLT *sigp = q->sigmoid + (int)signdx;
+          MYFLT *sigp = p->sigmoid + (int)signdx;
           *bufp++ = *x++ * *sigp;               /*      w. sigmoid-envlpd ends  */
         }
         //memcpy(bufp, x, sizeof(MYFLT)*ndirect);
@@ -303,35 +319,37 @@ static int harmon234(CSOUND *csound, HARM234 *q, HARMON2 *p)
           *bufp++ = *x++;
         signdx = (MYFLT)SLEN - siginc;
         for (nn = sigdist; nn--; signdx -= siginc) {
-          MYFLT *sigp = q->sigmoid + (int)signdx;
+          MYFLT *sigp = p->sigmoid + (int)signdx;
           *bufp++ = *x++ * *sigp;
         }
-        q->pulslen = pulslen;
+        p->pulslen = pulslen;
       }
     nostor:
-      if (q->vocamp < FL(1.0)) {                /* if onset             */
-        q->vocinc = q->ampinc;                  /*   set pos voice ramp */
-        q->switching = 1;
+      if (p->vocamp < FL(1.0)) {                /* if onset             */
+        p->vocinc = p->ampinc;                  /*   set pos voice ramp */
+        p->switching = 1;
       }
     } else {                                    /* NON-PERIODIC: */
     nonprd:
-      if (q->vocamp > FL(0.0)) {                /* if onset             */
-        q->vocinc = -q->ampinc;                 /*   set neg voice ramp */
-        q->switching = 1;
+      if (p->vocamp > FL(0.0)) {                /* if onset             */
+        p->vocinc = -p->ampinc;                 /*   set neg voice ramp */
+        p->switching = 1;
       }
-      q->curpuls = NULL;                        /* start no new pulses */
+      p->curpuls = NULL;                        /* start no new pulses */
     }
+    //print_data(p, 3);
     /* HARMONIZER */
-    for (vdp=q->vocdat; vdp<q->vlim; vdp++)     /* get new frequencies  */
-      vdp->phsinc = (int32)(*vdp->kfrq * q->sicvt);
-    outp = q->ar;
-    vocamp = q->vocamp;
+    for (vdp=p->vocdat; vdp<p->vlim; vdp++)     /* get new frequencies  */
+      vdp->phsinc = (int32)(*vdp->kfrq * p->sicvt);
+    outp = p->ar;
+    //nsmps = csound->ksmps;
+    vocamp = p->vocamp;
     diramp = FL(1.0) - vocamp;
-    dirp = q->asig;
-    endp = q->endp;
+    dirp = p->asig;
+    endp = p->endp;
     do {                                        /* insert pulses into output: */
       MYFLT sum = FL(0.0);
-      PULDAT *pdp = q->puldat;
+      PULDAT *pdp = p->puldat;
       while (pdp < endp) {
       addin:
         sum += *pdp->srcp++;                    /* get any ongoing pulsdata */
@@ -344,118 +362,101 @@ static int harmon234(CSOUND *csound, HARM234 *q, HARMON2 *p)
         }
         pdp++;
       }                                         /* if time to start a new one */
-      for (vdp=q->vocdat; vdp<q->vlim; vdp++)
+      for (vdp=p->vocdat; vdp<p->vlim; vdp++)
         if (vdp->phsinc && (vdp->phase += vdp->phsinc) & (~0xFFFF)) {
           vdp->phase &= 0x0000FFFFL;
-          if (q->curpuls != NULL) {             /*      & pulses are current    */
-            if (endp < q->limp) {               /*      set one up              */
-              endp->srcp = q->pulsbuf[q->pbufcnt];
-              endp->cntr = q->pulslen;          /*  w. extended len     */
+        if (p->curpuls != NULL) {               /*      & pulses are current    */
+            if (endp < p->limp) {               /*      set one up              */
+              endp->srcp = p->pulsbuf[p->pbufcnt];
+              endp->cntr = p->pulslen;          /*  w. extended len     */
               endp++;
             } else oflow = 1;
           }
         }
-      if (q->switching) {                       /* if v/uv switching    */
-        vocamp += q->vocinc;                    /*   do linear ramp     */
+      if (p->switching) {                       /* if v/uv switching    */
+        vocamp += p->vocinc;                    /*   do linear ramp     */
         if (vocamp <= FL(0.0)) {
           vocamp = FL(0.0);
-          q->switching = 0;
+          p->switching = 0;
         } else if (vocamp >= FL(1.0)) {
           vocamp = FL(1.0);
-          q->switching = 0;
+          p->switching = 0;
         }
         diramp = FL(1.0) - vocamp;
       }
       *outp++ = sum * vocamp + *dirp++ * diramp;        /* output combined */
     } while (--nsmps);
-    q->endp = endp;
-    q->vocamp = vocamp;
+    p->endp = endp;
+    p->vocamp = vocamp;
 
-    if (UNLIKELY(oflow && ++q->hmrngflg > 10)) {
+    if (UNLIKELY(oflow && ++p->hmrngflg > 10)) {
       csound->Warning(csound, Str("harmon234: out of range\n"));
-      q->hmrngflg = 0;
+      p->hmrngflg = 0;
     }
-    if (inp1 >= q->midp) {                       /* if end of pq bufs */
-      int32 bsmps = q->nbufsmps;
-      q->inp1 = q->bufp;                         /*   reset all ptrs  */
-      q->inp2 = q->midp;
-      if (q->curpuls != NULL)
-        q->curpuls -= bsmps;
+    if (inp1 >= p->midp) {                       /* if end of pq bufs */
+      int32 bsmps = p->nbufsmps;
+      p->inp1 = p->bufp;                         /*   reset all ptrs  */
+      p->inp2 = p->midp;
+      if (p->curpuls != NULL)
+        p->curpuls -= bsmps;
     }
     else {
-      q->inp1 = inp1;
-      q->inp2 = inp2;
+      p->inp1 = inp1;
+      p->inp2 = inp2;
     }
+    //print_data(p, 4);
     return OK;
 }
 
-int harm2set(CSOUND *csound, HARMON2 *p)
+int harm2set(CSOUND *csound, HARM234 *p)
 {
-    HARM234 *q = &p->hrmdat;
-    VOCDAT *vdp = q->vocdat;
-    q->ar = p->ar;
-    q->asig = p->asig;
-    q->koct = p->koct;
+    VOCDAT *vdp = p->vocdat;
     vdp->kfrq = p->kfrq1;       vdp->phase = 0; vdp++;
     vdp->kfrq = p->kfrq2;       vdp->phase = 0; vdp++;
-    q->vlim = vdp;
-    q->icpsmode = p->icpsmode;
-    q->ilowest = p->ilowest;
-    q->ipolarity = p->ipolarity;
-    return hm234set(csound, q, p);
+    p->vlim = vdp;
+    p->polarity = (int16)*p->icpsmode;
+    p->minoct = *p->kfrq4;
+    p->cpsmode = ((*p->kfrq3 != FL(0.0)));
+    return hm234set(csound, p);
 }
 
-int harm3set(CSOUND *csound, HARMON3 *p)
+int harm3set(CSOUND *csound, HARM234 *p)
 {
-    HARM234 *q = &p->hrmdat;
-    VOCDAT *vdp = q->vocdat;
-    q->ar = p->ar;
-    q->asig = p->asig;
-    q->koct = p->koct;
+    VOCDAT *vdp = p->vocdat;
     vdp->kfrq = p->kfrq1;       vdp->phase = 0; vdp++;
     vdp->kfrq = p->kfrq2;       vdp->phase = 0; vdp++;
     vdp->kfrq = p->kfrq3;       vdp->phase = 0; vdp++;
-    q->vlim = vdp;
-    q->icpsmode = p->icpsmode;
-    q->ilowest = p->ilowest;
-    q->ipolarity = p->ipolarity;
-    return hm234set(csound, q, (HARMON2*)p);
+    p->vlim = vdp;
+    //printf("mode, lowest, polar = %p,%p,%p\n",
+    //       p->icpsmode, p->ilowest, p->ipolarity);
+    p->polarity = (int16)*p->ilowest;
+    p->minoct = *p->icpsmode;
+    p->cpsmode = (*p->kfrq4 != FL(0.0));
+    //printf("mode, lowest, polar = (%d,%f,%d)\n",
+    //       p->cpsmode, p->minoct, p->ipolarity);
+    return hm234set(csound, p);
 }
 
-int harm4set(CSOUND *csound, HARMON4 *p)
+int harm4set(CSOUND *csound, HARM234 *p)
 {
-    HARM234 *q = &p->hrmdat;
-    VOCDAT *vdp = q->vocdat;
-    q->ar = p->ar;
-    q->asig = p->asig;
-    q->koct = p->koct;
+    VOCDAT *vdp = p->vocdat;
     vdp->kfrq = p->kfrq1;       vdp->phase = 0; vdp++;
     vdp->kfrq = p->kfrq2;       vdp->phase = 0; vdp++;
     vdp->kfrq = p->kfrq3;       vdp->phase = 0; vdp++;
     vdp->kfrq = p->kfrq4;       vdp->phase = 0; vdp++;
-    q->vlim = vdp;
-    q->icpsmode = p->icpsmode;
-    q->ilowest = p->ilowest;
-    q->ipolarity = p->ipolarity;
-    return hm234set(csound, q, (HARMON2*)p);
+    p->vlim = vdp;
+    p->polarity = (int16)*p->ipolarity;
+    p->minoct = *p->ilowest;
+    p->cpsmode = (*p->icpsmode != FL(0.0));
+    return hm234set(csound, p);
 }
 
-int harmon2(CSOUND *csound, HARMON2 *p)
-{ return harmon234(csound, &p->hrmdat, p);}
-int harmon3(CSOUND *csound, HARMON3 *p)
-{ return harmon234(csound, &p->hrmdat, (HARMON2*)p);}
-int harmon4(CSOUND *csound, HARMON4 *p)
-{ return harmon234(csound, &p->hrmdat, (HARMON2*)p);}
-
 #define S(x)    sizeof(x)
 
 static OENTRY harmon_localops[] = {
-  { "harmon2",S(HARMON2),0, 5, "a",  "akkkiip",
-                                     (SUBR)harm2set,NULL, (SUBR)harmon2 },
-  { "harmon3",S(HARMON3),0, 5, "a",  "akkkkiip",
-                                     (SUBR)harm3set,NULL, (SUBR)harmon3 },
-  { "harmon4",S(HARMON4),0, 5, "a",
-                                   "akkkkkiip",(SUBR)harm4set,NULL, (SUBR)harmon4 },
+  { "harmon2",S(HARM234),0,5,"a","akkkiip",  (SUBR)harm2set,NULL, (SUBR)harmon234 },
+  { "harmon3",S(HARM234),0,5,"a","akkkkiip", (SUBR)harm3set,NULL, (SUBR)harmon234 },
+  { "harmon4",S(HARM234),0,5,"a","akkkkkiip",(SUBR)harm4set,NULL, (SUBR)harmon234 },
 };
 
 LINKAGE_BUILTIN(harmon_localops)
