@@ -21,7 +21,7 @@
     02111-1307 USA
 */
 
-#include "csdl.h"
+#include "stdopcod.h"
 #include <math.h>
 
 typedef struct {
@@ -69,7 +69,7 @@ static int metro(CSOUND *csound, METRO *p)
       *p->sr = FL(1.0);
       p->flag = 0;
     }
-    else if ((phs += *p->xcps * csound->onedkr) >= 1.0) {
+    else if ((phs += *p->xcps * CS_ONEDKR) >= 1.0) {
       *p->sr = FL(1.0);
       phs -= 1.0;
       p->flag = 0;
@@ -101,7 +101,7 @@ static int split_trig_set(CSOUND *csound,   SPLIT_TRIG *p)
     */
 
     FUNC *ftp;
-    if (UNLIKELY((ftp = csound->FTFind(csound, p->ifn)) == NULL)) {
+    if (UNLIKELY((ftp = csound->FTnp2Find(csound, p->ifn)) == NULL)) {
       return csound->InitError(csound, Str("splitrig: incorrect table number"));
     }
     p->table = ftp->ftable;
@@ -147,8 +147,8 @@ static int timeseq_set(CSOUND *csound, TIMEDSEQ *p)
 {
     FUNC *ftp;
     MYFLT *table;
-    int j;
-    if (UNLIKELY((ftp = csound->FTFind(csound, p->ifn)) == NULL))  return NOTOK;
+    unsigned int j;
+    if (UNLIKELY((ftp = csound->FTnp2Find(csound, p->ifn)) == NULL))  return NOTOK;
     table = p->table = ftp->ftable;
     p->numParm = p->INOCOUNT-2; /* ? */
     for (j = 0; j < ftp->flen; j+= p->numParm) {
@@ -164,7 +164,7 @@ static int timeseq_set(CSOUND *csound, TIMEDSEQ *p)
 
 static int timeseq(CSOUND *csound, TIMEDSEQ *p)
 {
-    MYFLT *table = p->table, minDist = csound->onedkr;
+    MYFLT *table = p->table, minDist = CS_ONEDKR;
     MYFLT phs = *p->kphs, endseq = p->endSeq;
     int  j,k, numParm = p->numParm, endIndex = p->endIndex;
     while (phs > endseq)
@@ -251,10 +251,10 @@ static int timeseq(CSOUND *csound, TIMEDSEQ *p)
 #define S(x)    sizeof(x)
 
 static OENTRY localops[] = {
-  { "metro",  S(METRO),   3,      "k", "ko",  (SUBR)metro_set, (SUBR)metro     },
-  { "splitrig", S(SPLIT_TRIG), 3, "",  "kkiiz",
+  { "metro",  S(METRO),  9,  3,      "k", "ko",  (SUBR)metro_set, (SUBR)metro     },
+  { "splitrig", S(SPLIT_TRIG), 0, 3, "",  "kkiiz",
                                         (SUBR)split_trig_set, (SUBR)split_trig },
-  { "timedseq",S(TIMEDSEQ), TR|3, "k", "kiz", (SUBR)timeseq_set, (SUBR)timeseq }
+  { "timedseq",S(TIMEDSEQ), TR, 3, "k", "kiz", (SUBR)timeseq_set, (SUBR)timeseq }
 };
 
 int metro_init_(CSOUND *csound)
