@@ -37,7 +37,7 @@ imaxtracks - max number of tracks (<= number of analysis bins)
 
 */
 
-#include "csdl.h"
+#include "pvs_ops.h"
 #include "pstream.h"
 
 typedef struct _parts {
@@ -469,7 +469,8 @@ static int partials_process(CSOUND * csound, _PARTS * p)
 
 static OENTRY localops[] =
   {
-    { "partials", sizeof(_PARTS), 3, "f", "ffkkki", (SUBR) partials_init, (SUBR) partials_process }
+    { "partials", sizeof(_PARTS), 0, 3, "f", "ffkkki",
+                            (SUBR) partials_init, (SUBR) partials_process }
   };
 
 int partials_init_(CSOUND *csound)
@@ -477,4 +478,3 @@ int partials_init_(CSOUND *csound)
   return csound->AppendOpcodes(csound, &(localops[0]),
                                (int) (sizeof(localops) / sizeof(OENTRY)));
 }
-
