@@ -204,7 +204,7 @@ static int cabasaset(CSOUND *csound, CABASA *p)
     p->coeffs1 = CABA_RESON * CABA_RESON;
     p->coeffs0 = - CABA_RESON * FL(2.0) * COS(CABA_CENTER_FREQ * csound->tpidsr);
                                 /* Note On */
-    p->shakeEnergy = *p->amp * csound->dbfs_to_float * MAX_SHAKE * FL(0.1);
+    p->shakeEnergy = *p->amp * MAX_SHAKE * FL(0.1);
     if (p->shakeEnergy > MAX_SHAKE) p->shakeEnergy = MAX_SHAKE;
     p->last_num = FL(0.0);
     return OK;
@@ -310,7 +310,7 @@ static int sekereset(CSOUND *csound, SEKERE *p)
     p->coeffs0 = - SEKE_RESON * FL(2.0) *
       COS(SEKE_CENTER_FREQ * csound->tpidsr);
                                 /* Note On */
-    p->shakeEnergy = *p->amp * csound->dbfs_to_float * MAX_SHAKE * FL(0.1);
+    p->shakeEnergy = *p->amp * MAX_SHAKE * FL(0.1);
     if (p->shakeEnergy > MAX_SHAKE) p->shakeEnergy = MAX_SHAKE;
     p->last_num = FL(0.0);
     return OK;
@@ -391,7 +391,7 @@ static int sekere(CSOUND *csound, SEKERE *p)
 /*          ar[n] = 0.0f; */
 /*        } */
     }
-    printf("%d/%d:\n", offset, early);
+    //printf("%d/%d:\n", offset, early);
     p->shakeEnergy = shakeEnergy;
     p->sndLevel = sndLevel;
     p->outputs0 = outputs0;
@@ -423,7 +423,7 @@ static int sandset(CSOUND *csound, SEKERE *p)
                                 /* Note On */
     p->shakeEnergy = *p->amp * csound->dbfs_to_float * MAX_SHAKE * FL(0.1);
     if (p->shakeEnergy > MAX_SHAKE) p->shakeEnergy = MAX_SHAKE;
-    p->last_num = FL(0.0);
+    p->last_num = FL(128.0);
     return OK;
 }
 
@@ -450,7 +450,7 @@ static int stixset(CSOUND *csound, SEKERE *p)
                                 /* Note On */
     p->shakeEnergy = *p->amp * csound->dbfs_to_float * MAX_SHAKE * FL(0.1);
     if (p->shakeEnergy > MAX_SHAKE) p->shakeEnergy = MAX_SHAKE;
-    p->last_num = FL(0.0);
+    p->last_num = FL(30.0);
     return OK;
 }
 
@@ -483,6 +483,12 @@ static int guiroset(CSOUND *csound, GUIRO *p)
 {
     MYFLT temp;
 
+    p->res_freqSave = FL(0.0);
+    p->shake_maxSave = FL(0.0);
+    p->res_freq2 = FL(0.0);
+
+    p->baseGain = FL(0.0);
+
     p->sndLevel = FL(0.0);
     p->kloop = (int)(p->h.insdshead->offtim * CS_EKR)
                - (int)(CS_EKR * *p->dettack);
@@ -588,7 +594,7 @@ static int guiro(CSOUND *csound, GUIRO *p)
       MYFLT finalZ2      = p->finalZ2;
       MYFLT gains0       = p->gains0;
       MYFLT gains1       = p->gains1;
-      MYFLT amp          = *p->amp;
+      MYFLT amp          = *p->amp*csound->e0dbfs;
       if (UNLIKELY(offset)) memset(ar, '\0', offset*sizeof(MYFLT));
       if (UNLIKELY(early)) {
         nsmps -= early;
@@ -649,6 +655,7 @@ static int tambourset(CSOUND *csound, TAMBOURINE *p)
 {
     MYFLT temp;
 
+    p->shake_maxSave = FL(0.0);
     p->sndLevel = FL(0.0);
     p->kloop = (int)(p->h.insdshead->offtim * CS_EKR)
                - (int)(CS_EKR * *p->dettack);
@@ -793,6 +800,7 @@ static int tambourine(CSOUND *csound, TAMBOURINE *p)
 static int bambooset(CSOUND *csound, BAMBOO *p)
 {
     MYFLT temp;
+    p->shake_maxSave = FL(0.0);
 
     p->sndLevel = FL(0.0);
     p->kloop = (int)(p->h.insdshead->offtim * CS_EKR)
@@ -971,7 +979,8 @@ static int wuterset(CSOUND *csound, WUTER *p)
     p->shake_damp      = FL(0.0);
     if (p->shakeEnergy > MAX_SHAKE) p->shakeEnergy = MAX_SHAKE;
     p->shake_maxSave = FL(0.0);
-    p->num_objects = p->finalZ0 = p->finalZ1 = p->finalZ2 = FL(0.0);
+    p->num_objects = 10;        /* Bug fix by JPff 2014/08/27 */
+    p->finalZ0 = p->finalZ1 = p->finalZ2 = FL(0.0);
     return OK;
 }
 
@@ -1115,6 +1124,7 @@ static int sleighset(CSOUND *csound, SLEIGHBELLS *p)
 {
     MYFLT temp;
 
+    p->shake_maxSave = FL(0.0);
     p->sndLevel = FL(0.0);
     p->kloop = (int)(p->h.insdshead->offtim * CS_EKR)
                - (int)(CS_EKR * *p->dettack);
