@@ -62,7 +62,7 @@ void FetchInForAdd(float *inp, MYFLT *buf, int32 fsize,
     }
 }
 
-int pvaddset(CSOUND *csound, PVADD *p)
+int pvaddset_(CSOUND *csound, PVADD *p, int stringname)
 {
     int      ibins;
     char     pvfilnam[MAXNAME];
@@ -76,11 +76,17 @@ int pvaddset(CSOUND *csound, PVADD *p)
     p->ftp = ftp;
 
     if (*p->igatefun > FL(0.0))
-      if (UNLIKELY((AmpGateFunc = csound->FTFind(csound, p->igatefun)) == NULL))
+      if (UNLIKELY((AmpGateFunc = csound->FTnp2Find(csound, p->igatefun)) == NULL))
         return NOTOK;
     p->AmpGateFunc = AmpGateFunc;
 
-    csound->strarg2name(csound, pvfilnam, p->ifilno, "pvoc.", p->XSTRCODE);
+    if (stringname==0){
+      if (ISSTRCOD(*p->ifilno))
+        strncpy(pvfilnam,get_arg_string(csound, *p->ifilno), MAXNAME-1);
+      else csound->strarg2name(csound, pvfilnam, p->ifilno, "pvoc.",0);
+    }
+    else strncpy(pvfilnam, ((STRINGDAT *)p->ifilno)->data, MAXNAME-1);
+
     if (UNLIKELY(pvx_loadfile(csound, pvfilnam, p) != OK))
       return NOTOK;
 
@@ -133,7 +139,10 @@ int pvadd(CSOUND *csound, PVADD *p)
     MYFLT   *ar, *ftab;
     MYFLT   frIndx;
     int     size = pvfrsiz(p);
-    int     i, binincr = (int) *p->ibinincr, n, nsmps = csound->ksmps;
+    int     i, binincr = (int) *p->ibinincr;
+    uint32_t offset = p->h.insdshead->ksmps_offset;
+    uint32_t early  = p->h.insdshead->ksmps_no_end;
+    uint32_t n, nsmps = CS_KSMPS;
     MYFLT   amp, frq, v1, fract, *oscphase;
     int32    phase, incr;
     FUNC    *ftp;
@@ -158,12 +167,13 @@ int pvadd(CSOUND *csound, PVADD *p)
 
     ar = p->rslt;
     memset(ar, 0, nsmps*sizeof(MYFLT));
+    if (UNLIKELY(early)) nsmps -= early;
     oscphase = p->oscphase;
     for (i = (int) *p->ibinoffset; i < p->maxbin; i += binincr) {
       lobits = ftp->lobits;
       phase = (int32) *oscphase;
       frq = p->buf[i * 2 + 1] * *p->kfmod;
-      if (p->buf[i * 2 + 1] == FL(0.0) || frq >= csound->esr * FL(0.5)) {
+      if (p->buf[i * 2 + 1] == FL(0.0) || frq >= CS_ESR * FL(0.5)) {
         incr = 0;               /* Hope then does not matter */
         amp = FL(0.0);
       }
@@ -172,7 +182,7 @@ int pvadd(CSOUND *csound, PVADD *p)
         incr = (int32) MYFLT2LONG(tmp);
         amp = p->buf[i * 2];
       }
-      for (n=0;n<nsmps;n++) {
+      for (n=offset;n<nsmps;n++) {
         fract = PFRAC(phase);
         ftab = ftp->ftable + (phase >> lobits);
         v1 = *ftab++;
@@ -185,11 +195,20 @@ int pvadd(CSOUND *csound, PVADD *p)
     }
     return OK;
  err1:
-    return csound->PerfError(csound, Str("pvadd: not initialised"));
+    return csound->PerfError(csound, p->h.insdshead, Str("pvadd: not initialised"));
  err2:
-    return csound->PerfError(csound, Str("PVADD timpnt < 0"));
+    return csound->PerfError(csound, p->h.insdshead, Str("PVADD timpnt < 0"));
 }
 
+int pvaddset(CSOUND *csound, PVADD *p){
+  return pvaddset_(csound, p, 0);
+}
+
+int pvaddset_S(CSOUND *csound, PVADD *p){
+  return pvaddset_(csound, p, 1);
+}
+
+
 static int pvx_loadfile(CSOUND *csound, const char *fname, PVADD *p)
 {
     PVOCEX_MEMFILE  pp;
@@ -217,7 +236,7 @@ static int pvx_loadfile(CSOUND *csound, const char *fname, PVADD *p)
     p->maxFr    = pp.nframes - 1;
     p->asr      = pp.srate;
     /* factor by which to mult expand phase diffs (ratio of samp spacings) */
-    p->frPrtim = csound->esr / (MYFLT) pp.overlap;
+    p->frPrtim = CS_ESR / (MYFLT) pp.overlap;
     return OK;
 }
 
