@@ -9,7 +9,7 @@ static int pyexec_krate(CSOUND *csound, PYEXEC *p)
         *py_initialize_done == 0)
       return NOTOK;
 
-    strncpy(source, (char*) p->string->data,1024);
+    strncpy(source, (char*) p->string->data,1023); source[1023] = '\0';
 
     result = exec_file_in_given_context(csound, source, 0);
     if (result == NULL) {
@@ -30,7 +30,7 @@ static int pyexeci_irate(CSOUND *csound, PYEXEC *p)
        *py_initialize_done == 0)
       return NOTOK;
 
-    strncpy(source, (char*) p->string->data, 1024);
+    strncpy(source, (char*) p->string->data, 1023); source[1023] = '\0';
 
     result = exec_file_in_given_context(csound, source, 0);
     if (result == NULL) {
@@ -62,7 +62,7 @@ static int pylexec_krate(CSOUND *csound, PYEXEC *p)
        *py_initialize_done == 0)
       return NOTOK;
 
-    strncpy(source, (char*) p->string->data, 1024);
+    strncpy(source, (char*) p->string->data, 1023); source[1023]='\0';
 
     result = exec_file_in_given_context(csound, source, GETPYLOCAL(p->h.insdshead));
     if (result == NULL) {
@@ -84,7 +84,7 @@ static int pylexeci_irate(CSOUND *csound, PYEXEC *p)
 
     create_private_namespace_if_needed(&p->h);
 
-    strncpy(source, (char*) p->string->data, 1024);
+    strncpy(source, (char*) p->string->data, 1023); source[1023]='\0';
 
     result = exec_file_in_given_context(csound, source, GETPYLOCAL(p->h.insdshead));
     if (result == NULL) {
@@ -107,7 +107,7 @@ static int pyexect_krate(CSOUND *csound, PYEXECT *p)
     if (!*p->trigger)
       return OK;
 
-    strncpy(source, (char*) p->string->data, 1024);
+    strncpy(source, (char*) p->string->data, 1023);source[1023]='\0';
 
     result = exec_file_in_given_context(csound, source, 0);
     if (result == NULL) {
@@ -141,7 +141,7 @@ static int pylexect_krate(CSOUND *csound, PYEXECT *p)
     if (!*p->trigger)
       return OK;
 
-    strncpy(source, (char*) p->string->data, 1024);
+    strncpy(source, (char*) p->string->data, 1023); source[1023]='\0';
 
     result = exec_file_in_given_context(csound, source, GETPYLOCAL(p->h.insdshead));
     if (result == NULL) {
@@ -161,7 +161,7 @@ static int pyrun_krate(CSOUND *csound, PYRUN *p)
        *py_initialize_done == 0)
       return NOTOK;
 
-    strncpy(source, (char*) p->string->data, 40960);
+    strncpy(source, (char*) p->string->data, 40959);source[40959]='\0';
 
     result = run_statement_in_given_context(source, 0);
     if (result == NULL) {
@@ -181,7 +181,7 @@ static int pyruni_irate(CSOUND *csound, PYRUN *p)
        *py_initialize_done == 0)
       return NOTOK;
 
-    strncpy(source, (char*) p->string->data, 40960);
+    strncpy(source, (char*) p->string->data, 40959);source[40959]='\0';
 
     result = run_statement_in_given_context(source, 0);
     if (result == NULL) {
@@ -212,7 +212,7 @@ static int pylrun_krate(CSOUND *csound, PYRUN *p)
        *py_initialize_done == 0)
       return NOTOK;
 
-    strncpy(source, (char*) p->string->data, 40960);
+    strncpy(source, (char*) p->string->data, 40959); source[40959]='\0';
 
     result = run_statement_in_given_context(source, GETPYLOCAL(p->h.insdshead));
     if (result == NULL) {
@@ -233,7 +233,7 @@ static int pylruni_irate(CSOUND *csound, PYRUN *p)
       return NOTOK;
     create_private_namespace_if_needed(&p->h);
 
-    strncpy(source, (char*) p->string->data, 40960);
+    strncpy(source, (char*) p->string->data, 40959); source[40959]='\0';
 
     result = run_statement_in_given_context(source, GETPYLOCAL(p->h.insdshead));
     if (result == NULL) {
@@ -255,7 +255,7 @@ static int pyrunt_krate(CSOUND *csound, PYRUNT *p)
     if (!*p->trigger)
       return OK;
 
-    strncpy(source, (char*) p->string->data, 40960);
+    strncpy(source, (char*) p->string->data, 40959); source[40959]='\0';
 
     result = run_statement_in_given_context(source, 0);
     if (result == NULL) {
@@ -288,7 +288,7 @@ static int pylrunt_krate(CSOUND *csound, PYRUNT *p)
     if (!*p->trigger)
       return OK;
 
-    strncpy(source, (char*) p->string->data, 40960);
+    strncpy(source, (char*) p->string->data, 40959); source[40959]='\0';
 
     result = run_statement_in_given_context(source, GETPYLOCAL(p->h.insdshead));
     if (result == NULL) {
@@ -307,7 +307,7 @@ static int pyeval_krate(CSOUND *csound, PYEVAL *p)
         csound->QueryGlobalVariable(csound,"PY_INITIALIZE")) == NULL ||
        *py_initialize_done == 0)
       return NOTOK;
-    strncpy(source, (char*) p->string->data, 1024);
+    strncpy(source, (char*) p->string->data, 1023);source[1023]='\0';
 
     result = eval_string_in_given_context(source, 0);
     if (result == NULL) {
@@ -333,7 +333,7 @@ static int pyevali_irate(CSOUND *csound, PYEVAL *p)
         csound->QueryGlobalVariable(csound,"PY_INITIALIZE")) == NULL ||
        *py_initialize_done == 0)
       return NOTOK;
-    strncpy(source, (char*) p->string->data, 1024);
+    strncpy(source, (char*) p->string->data, 1023);source[1023]='\0';
 
     result = eval_string_in_given_context(source, 0);
     if (result == NULL) {
@@ -370,7 +370,7 @@ static int pyleval_krate(CSOUND *csound, PYEVAL *p)
         csound->QueryGlobalVariable(csound,"PY_INITIALIZE")) == NULL ||
        *py_initialize_done == 0)
       return NOTOK;
-    strncpy(source, (char*) p->string->data, 1024);
+    strncpy(source, (char*) p->string->data, 1023);source[1023]='\0';
 
     result = eval_string_in_given_context(source, GETPYLOCAL(p->h.insdshead));
     if (result == NULL) {
@@ -397,7 +397,7 @@ static int pylevali_irate(CSOUND *csound, PYEVAL *p)
       return NOTOK;
     create_private_namespace_if_needed(&p->h);
 
-    strncpy(source, (char*) p->string->data, 1024);
+    strncpy(source, (char*) p->string->data, 1023);source[1023]='\0';
 
     result = eval_string_in_given_context(source, GETPYLOCAL(p->h.insdshead));
     if (result == NULL) {
@@ -427,7 +427,7 @@ static int pyevalt_krate(CSOUND *csound, PYEVALT *p)
       return OK;
     }
 
-    strncpy(source, (char*) p->string->data, 1024);
+    strncpy(source, (char*) p->string->data, 1023);source[1023]='\0';
 
     result = eval_string_in_given_context(source, 0);
     if (result == NULL) {
@@ -469,7 +469,7 @@ static int pylevalt_krate(CSOUND *csound, PYEVALT *p)
       return OK;
     }
 
-    strncpy(source, (char*) p->string->data, 1024);
+    strncpy(source, (char*) p->string->data, 1023);source[1023]='\0';
 
     result = eval_string_in_given_context(source, GETPYLOCAL(p->h.insdshead));
     if (result == NULL) {
