@@ -534,14 +534,14 @@ int spdspset(CSOUND *csound, SPECDISP *p)
       if (downp->lofrq > FL(5.0)) {
         snprintf(strmsg, 256,
                 Str("instr %d %s, dft (%s), %d octaves (%d - %d Hz):"),
-                (int) p->h.insdshead->p1, p->h.optext->t.inlist->arg[0],
+                (int) p->h.insdshead->p1.value, p->h.optext->t.inlist->arg[0],
                 outstring[specp->dbout],
                 downp->nocts, (int)downp->lofrq, (int)downp->hifrq);
       }
       else {                            /* more detail if low frequency  */
         snprintf(strmsg, 256,
                 Str("instr %d %s, dft (%s), %d octaves (%3.1f - %3.1f Hz):"),
-                (int) p->h.insdshead->p1, p->h.optext->t.inlist->arg[0],
+                (int) p->h.insdshead->p1.value, p->h.optext->t.inlist->arg[0],
                 outstring[specp->dbout],
                 downp->nocts, downp->lofrq, downp->hifrq);
       }
