@@ -27,6 +27,7 @@
 #include <ctype.h>
 
 static void list_audio_devices(CSOUND *csound, int output);
+static void list_midi_devices(CSOUND *csound, int output);
 extern void strset_option(CSOUND *csound, char *s);     /* from str_ops.c */
 
 #define FIND(MSG)   if (*s == '\0')  \
@@ -43,6 +44,63 @@ extern void strset_option(CSOUND *csound, char *s);     /* from str_ops.c */
 
 /* IV - Feb 19 2005 */
 
+#ifdef EXPERIMENTAL
+static FILE *logFile = NULL;
+
+void msg_callback(CSOUND *csound,
+                         int attr, const char *format, va_list args)
+{
+    (void) csound;
+    if ((attr & CSOUNDMSG_TYPE_MASK) != CSOUNDMSG_REALTIME) {
+      vfprintf(logFile, format, args);
+      fflush(logFile);
+      return;
+     }
+    #if defined(WIN32) || defined(MAC)
+    switch (attr & CSOUNDMSG_TYPE_MASK) {
+        case CSOUNDMSG_ERROR:
+        case CSOUNDMSG_WARNING:
+        case CSOUNDMSG_REALTIME:
+        break;
+      default:
+        vfprintf(logFile, format, args);
+        return;
+    }
+    #endif
+
+    vfprintf(stderr, format, args);
+}
+
+void nomsg_callback(CSOUND *csound,
+  int attr, const char *format, va_list args){ return; }
+
+void do_logging(char *s)
+{
+    int nomessages = 0;
+    if (logFile) return;
+    if (!strcmp(s, "NULL") || !strcmp(s, "null"))
+      nomessages = 1;
+    else if ((logFile = fopen(s, "w")) == NULL) {
+      fprintf(stderr, "Error opening log file '%s': %s\n",
+              s, strerror(errno));
+      exit(1);
+    }
+    /* if logging to file, set message callback */
+    if (logFile != NULL)
+      csoundSetDefaultMessageCallback(msg_callback);
+    else if (nomessages)
+      csoundSetDefaultMessageCallback(nomsg_callback);
+}
+
+void end_logging(void)
+{
+    if (logFile != NULL)
+      fclose(logFile);
+}
+#else
+#define do_logging(x) {}
+#endif
+
 static inline void set_stdin_assign(CSOUND *csound, int type, int state)
 {
     if (state)
@@ -226,8 +284,10 @@ static const char *longUsageList[] = {
   Str_noop("--port=N\t\t listen to UDP port N for instruments/orchestra "
            "code (implies --daemon)"),
   Str_noop("--vbr-quality=Ft\t set quality of variable bit0rate compression"),
+    Str_noop("--devices[=in|out] \t\t list available MIDI devices and exit"),
   Str_noop("--devices[=in|out] \t\t list available audio devices and exit"),
   Str_noop("--get-system-sr \t\t print system sr and exit"),
+  Str_noop("--ksmps=N \t\t override ksmps"),
   " ",
   Str_noop("--help\t\t\tLong help"),
 
@@ -559,6 +619,12 @@ static int decode_long(CSOUND *csound, char *s, int argc, char **argv)
       O->kr_override = (float)atof(s);
       return 1;
     }
+    else if (!(strncmp(s, "ksmps=", 6))) {
+      s += 6;
+      if (UNLIKELY(*s=='\0')) dieu(csound, Str("no ksmps"));
+      O->ksmps_override = atoi(s);
+      return 1;
+    }
     /* -K */
     else if (!(strcmp (s, "nopeaks"))) {
       csound->peakchunks = 0;           /* Do not write peak information */
@@ -712,6 +778,7 @@ static int decode_long(CSOUND *csound, char *s, int argc, char **argv)
     else if (!(strncmp (s, "logfile=", 8))) {
       s += 8;
       if (UNLIKELY(*s=='\0')) dieu(csound, Str("no log file"));
+      do_logging(s);
       return 1;
     }
     /* -r N */
@@ -933,28 +1000,32 @@ static int decode_long(CSOUND *csound, char *s, int argc, char **argv)
     }
     else if (!(strcmp(s, "new-parser")) ||
              !(strcmp(s, "old-parser"))) {
-        return 1;  /* ignore flag, this is here for backwards compatibility */
+      return 1;  /* ignore flag, this is here for backwards compatibility */
+    }
+    else if (!(strcmp(s, "sco-parser"))) {
+      csound->score_parser = 1;
+      return 1;  /* Try new parser */
     }
     else if (!(strcmp(s, "daemon"))) {
-        O->daemon = 1;
-        return 1;
+      O->daemon = 1;
+      return 1;
     }
     else if (!(strncmp(s, "port=",5))) {
-        s += 5;
-        O->daemon = atoi(s);
-        return 1;
+      s += 5;
+      O->daemon = atoi(s);
+      return 1;
     }
     else if (!(strncmp(s, "vbr-quality=",12))) {
-        s += 12;
-        O->quality = atof(s);
-        return 1;
+      s += 12;
+      O->quality = atof(s);
+      return 1;
       }
     else if (!(strncmp(s, "devices",7))) {
       csoundLoadExternals(csound);
       if (csoundInitModules(csound) != 0)
-              csound->LongJmp(csound, 1);
-      if(*(s+7) == '='){
-        if(!strncmp(s+8,"in", 2)) {
+        csound->LongJmp(csound, 1);
+      if (*(s+7) == '='){
+        if (!strncmp(s+8,"in", 2)) {
           list_audio_devices(csound, 0);
         }
         else if(!strncmp(s+8,"out", 2))
@@ -967,20 +1038,38 @@ static int decode_long(CSOUND *csound, char *s, int argc, char **argv)
       csound->info_message_request = 1;
       return 1;
       }
-    else if (!(strncmp(s, "get-system-sr",13))){
-      if(O->outfilename &&
-        !(strncmp(O->outfilename, "dac",3))) {
-      /* these are default values to get the
-         backend to open successfully */
-      set_output_format(O, 'f');
-      O->inbufsamps = O->outbufsamps = 256;
-      O->oMaxLag = 1024;
+     else if (!(strncmp(s, "midi-devices",12))) {
       csoundLoadExternals(csound);
       if (csoundInitModules(csound) != 0)
-              csound->LongJmp(csound, 1);
-      sfopenout(csound);
-      csound->Message(csound, "system sr: %f\n", csound->system_sr(csound,0));
-      sfcloseout(csound);
+        csound->LongJmp(csound, 1);
+      if (*(s+12) == '='){
+        if (!strncmp(s+13,"in", 2)) {
+          list_midi_devices(csound, 0);
+        }
+        else if(!strncmp(s+13,"out", 2))
+          list_midi_devices(csound,1);
+      }
+      else {
+        list_midi_devices(csound,0);
+        list_midi_devices(csound,1);
+      }
+      csound->info_message_request = 1;
+      return 1;
+      }
+    else if (!(strncmp(s, "get-system-sr",13))){
+      if (O->outfilename &&
+          !(strncmp(O->outfilename, "dac",3))) {
+        /* these are default values to get the
+           backend to open successfully */
+        set_output_format(O, 'f');
+        O->inbufsamps = O->outbufsamps = 256;
+        O->oMaxLag = 1024;
+        csoundLoadExternals(csound);
+        if (csoundInitModules(csound) != 0)
+          csound->LongJmp(csound, 1);
+        sfopenout(csound);
+        csound->Message(csound, "system sr: %f\n", csound->system_sr(csound,0));
+        sfcloseout(csound);
       }
       csound->info_message_request = 1;
       return 1;
@@ -1024,7 +1113,7 @@ PUBLIC int argdecode(CSOUND *csound, int argc, char **argv_)
             FIND(Str("no utility name"));
             {
               int retval = csoundRunUtility(csound, s, argc, argv);
-              if(retval) {
+              if (retval) {
                   csound->info_message_request = 1;
                   csound->orchname = NULL;
                   goto end;
@@ -1262,14 +1351,15 @@ PUBLIC int argdecode(CSOUND *csound, int argc, char **argv_)
                 readOptions(csound, ind, 0);
                 csound->FileClose(csound, fd);
               }
-              while (*s++)
-               ; s--; /* semicolon on separate line to silence warning */
+              while (*s++) {};
+              s--; /* semicolon on separate line to silence warning */
             }
             break;
           case 'O':
             FIND(Str("no log file"));
-            while (*s++)
-              ; s--; /* semicolon on separate line to silence warning */
+            do_logging(s);
+            while (*s++) {};
+            s--; /* semicolon on separate line to silence warning */
             break;
           case '-':
 #if defined(LINUX)
@@ -1398,6 +1488,8 @@ PUBLIC void csoundSetParams(CSOUND *csound, CSOUND_PARAMS *p){
   oparms->nchnls_override = p->nchnls_override;
   oparms->nchnls_i_override = p->nchnls_i_override;
   oparms->e0dbfs_override = p->e0dbfs_override;
+  
+  if(p->ksmps_override > 0) oparms->ksmps_override = p->ksmps_override;
 }
 
 PUBLIC void csoundGetParams(CSOUND *csound, CSOUND_PARAMS *p){
@@ -1436,6 +1528,7 @@ PUBLIC void csoundGetParams(CSOUND *csound, CSOUND_PARAMS *p){
   p->heartbeat = oparms->heartbeat;
   p->ring_bell = oparms->ringbell;
   p->daemon = oparms->daemon;
+  p->ksmps_override = oparms->ksmps_override;
 }
 
 
@@ -1463,7 +1556,7 @@ PUBLIC void csoundSetOutput(CSOUND *csound, char *name, char *type, char *format
     if (type != NULL) {
       int i=0;
       while ((typename = file_type_map[i].format) != NULL) {
-        if(!strcmp(type,typename)) break;
+        if (!strcmp(type,typename)) break;
         i++;
       }
       if (typename != NULL) {
@@ -1579,3 +1672,19 @@ static void list_audio_devices(CSOUND *csound, int output){
                    i, devs[i].device_id, devs[i].device_name);
          free(devs);
 }
+
+static void list_midi_devices(CSOUND *csound, int output){
+
+       int i,n = csoundGetMIDIDevList(csound,NULL, output);
+         CS_MIDIDEVICE *devs = (CS_MIDIDEVICE *)
+             malloc(n*sizeof(CS_MIDIDEVICE));
+         if(output)
+          csound->Message(csound, "%d MIDI output devices \n", n);
+         else
+           csound->Message(csound, "%d MIDI input devices \n", n);
+         csoundGetMIDIDevList(csound,devs,output);
+         for(i=0; i < n; i++)
+             csound->Message(csound, " %d: %s (%s)\n",
+                   i, devs[i].device_id, devs[i].device_name);
+         free(devs);
+}
