@@ -51,7 +51,7 @@ extern void cs_init_math_constants_macros(CSOUND *csound, PRE_PARM *yyscanner);
 extern void cs_init_omacros(CSOUND *csound, PRE_PARM*, NAMES *nn);
 extern void csoundInputMessageInternal(CSOUND *csound, const char *message);
 
-void checkOptions(CSOUND *csound)
+static void checkOptions(CSOUND *csound)
 {
     const char  *csrcname;
     const char  *home_dir;
@@ -346,9 +346,6 @@ PUBLIC int csoundStart(CSOUND *csound) // DEBUG
        return CSOUND_ERROR;
     }
 
-
-
-
    { /* test for dummy module request */
     char *s;
      if((s = csoundQueryGlobalVariable(csound, "_RTAUDIO")) != NULL)
@@ -437,10 +434,12 @@ PUBLIC int csoundStart(CSOUND *csound) // DEBUG
       O->RTevents = 1;
     if (!O->sfheader)
       O->rewrt_hdr = 0;         /* cannot rewrite header of headerless file */
+    /* VL 9 04 15: these not need occur jointly anymore */
+    /* 
     if (O->sr_override || O->kr_override) {
       if (!O->sr_override || !O->kr_override)
         dieu(csound, Str("srate and krate overrides must occur jointly"));
-    }
+    } */
     if (!O->outformat)                      /* if no audioformat yet  */
       O->outformat = AE_SHORT;              /*  default to short_ints */
     O->sfsampsize = sfsampsize(FORMAT2SF(O->outformat));
