@@ -62,10 +62,10 @@ CS_NOINLINE char *csoundTmpFileName(CSOUND *csound, const char *ext)
 {
 #define   nBytes (256)
     char lbuf[256];
-#if defined(LINUX) || defined(__MACH__)
-    struct stat tmp;
-#elif defined(WIN32)
+#if defined(WIN32)
     struct _stat tmp;
+#else
+    struct stat tmp;
 #endif
     do {
 #ifndef WIN32
@@ -114,11 +114,11 @@ CS_NOINLINE char *csoundTmpFileName(CSOUND *csound, const char *ext)
           } while (lbuf[i] != '\0');
       }
 #endif
-#if defined(LINUX) || defined(__MACH__)
+#if defined(WIN32)
+    } while (_stat(lbuf, &tmp) == 0);
+#else
       /* if the file already exists, try again */
     } while (stat(lbuf, &tmp) == 0);
-#elif defined(WIN32)
-    } while (_stat(lbuf, &tmp) == 0);
 #endif
     return strdup(lbuf);
 }
@@ -362,8 +362,14 @@ static int createScore(CSOUND *csound, FILE *unf)
     while (my_fgets(csound, buffer, CSD_MAX_LINE_LEN, unf)!= NULL) {
       p = buffer;
       while (*p == ' ' || *p == '\t') p++;
-      if (strstr(p, "</CsScore>") == p)
+      if (strstr(p, "</CsScore>") == p) {
+#ifdef SCORE_PARSER
+        corfile_puts("\n#exit\n", csound->scorestr);
+        corfile_putc('\0', csound->scorestr);     /* For use in bison/flex */
+        corfile_putc('\0', csound->scorestr);     /* For use in bison/flex */
+#endif
         return TRUE;
+      }
       else
         corfile_puts(buffer, csound->scorestr);
     }
@@ -392,7 +398,7 @@ static int createExScore(CSOUND *csound, char *p, FILE *unf)
       return FALSE;
     }
     *q = '\0';
-    strncpy(prog, p+5, 256); /* after "<CsExScore " */
+    strncpy(prog, p+5, 255); prog[255]='\0';/* after "<CsExScore " */
     /* Generate score name */
     if (STA(sconame)) free(STA(sconame));
     STA(sconame) = csoundTmpFileName(csound, ".sco");
@@ -415,28 +421,32 @@ static int createExScore(CSOUND *csound, char *p, FILE *unf)
         snprintf(sys, 1024, "%s %s %s", prog, extname, STA(sconame));
         if (UNLIKELY(system(sys) != 0)) {
           csoundErrorMsg(csound, Str("External generation failed"));
-          remove(extname);
-          remove(STA(sconame));
+          if (UNLIKELY(remove(extname) || remove(STA(sconame))))
+            csoundErrorMsg(csound, Str("and cannot remove"));
           return FALSE;
         }
-        remove(extname);
+        if (UNLIKELY(remove(extname)))
+          csoundErrorMsg(csound, Str("and cannot remove %s"), extname);
         if (csound->scorestr == NULL)
           csound->scorestr = corfile_create_w();
         fd = csoundFileOpenWithType(csound, &scof, CSFILE_STD, STA(sconame),
                                     "r", NULL, CSFTYPE_SCORE, 0);
         if (UNLIKELY(fd == NULL)) {
-          remove(STA(sconame));
+          if (UNLIKELY(remove(STA(sconame))))
+            csoundErrorMsg(csound, Str("and cannot remove %s"), STA(sconame));
           return FALSE;
         }
         while (my_fgets(csound, buffer, CSD_MAX_LINE_LEN, scof)!= NULL)
           corfile_puts(buffer, csound->scorestr);
         csoundFileClose(csound, fd);
-        remove(STA(sconame));
+          if (UNLIKELY(remove(STA(sconame))))
+            csoundErrorMsg(csound, Str("and cannot remove %s"), STA(sconame));
         return TRUE;
       }
       else fputs(buffer, scof);
     }
     csoundErrorMsg(csound, Str("Missing end tag </CsScore>"));
+    free(extname);
     return FALSE;
 }
 
@@ -584,7 +594,7 @@ static int createFile(CSOUND *csound, char *buffer, FILE *unf)
       q = strchr(p, '>');
     if (q) *q='\0';
     //  printf("p=>>%s<<\n", p);
-    strncpy(filename, p, 256);
+    strncpy(filename, p, 255); filename[255]='\0';
 //sscanf(buffer, "<CsFileB filename=\"%s\">", filename);
 //    if (filename[0] != '\0' &&
 //       filename[strlen(filename) - 1] == '>' &&
@@ -636,7 +646,7 @@ static int createFilea(CSOUND *csound, char *buffer, FILE *unf)
       q = strchr(p, '>');
     if (q) *q='\0';
     //  printf("p=>>%s<<\n", p);
-    strncpy(filename, p, 256);
+    strncpy(filename, p, 255); filename[255]='\0';
     if (UNLIKELY((smpf = fopen(filename, "r")) != NULL)) {
       fclose(smpf);
       csoundDie(csound, Str("File %s already exists"), filename);
@@ -729,6 +739,24 @@ static int checkLicence(CSOUND *csound, FILE *unf)
     return FALSE;
 }
 
+static int checkShortLicence(CSOUND *csound, FILE *unf)
+{
+    int   type = 0;
+    char  buff[CSD_MAX_LINE_LEN];
+
+    csoundMessage(csound, Str("**** Licence Information ****\n"));
+    while (my_fgets(csound, buff, CSD_MAX_LINE_LEN, unf) != NULL) {
+      if (strstr(buff, "</CsShortLicence>") != NULL ||
+          strstr(buff, "</CsShortLicense>") != NULL) {
+        csound->SF_id_scopyright = type;
+        return TRUE;
+      }
+      type = atoi(buff);
+    }
+    csoundErrorMsg(csound, Str("Missing end tag </CsShortLicence>"));
+    return FALSE;
+}
+
 static int blank_buffer(CSOUND *csound, char *buffer)
 {
     const char *s;
@@ -750,6 +778,7 @@ int read_unified_file(CSOUND *csound, char **pname, char **score)
     int   started = FALSE;
     int   r;
     char    buffer[CSD_MAX_LINE_LEN];
+    int endtag_found = 0;
 
     /* Need to open in binary to deal with MIDI and the like. */
     fd = csoundFileOpenWithType(csound, &unf, CSFILE_STD, name, "rb", NULL,
@@ -776,6 +805,7 @@ int read_unified_file(CSOUND *csound, char **pname, char **score)
       }
       else if (strstr(p, "</CsoundSynthesizer>") == p ||
                strstr(p, "</CsoundSynthesiser>") == p) {
+        endtag_found = 1;
         if (csound->scorestr != NULL)
           corfile_flush(csound->scorestr);
         *pname = STA(orcname);
@@ -846,6 +876,11 @@ int read_unified_file(CSOUND *csound, char **pname, char **score)
         r = checkLicence(csound, unf);
         result = r && result;
       }
+      else if (strstr(p, "<CsShortLicence>") == p ||
+               strstr(p, "<CsSortLicense>") == p) {
+        r = checkShortLicence(csound, unf);
+        result = r && result;
+      }
       else if (blank_buffer(csound, buffer)) continue;
       else if (started && strchr(p, '<') == buffer){
         csoundMessage(csound, Str("unknown CSD tag: %s\n"), buffer);
@@ -863,6 +898,11 @@ int read_unified_file(CSOUND *csound, char **pname, char **score)
       csound->oparms->FMidiin = 1;
     }
     csoundFileClose(csound, fd);
+    if(endtag_found == 0) {
+    csoundMessage(csound,
+                  Str("Could not find </CsoundSynthesizer> tag in CSD file.\n"));
+     result = FALSE;
+    }
     return result;
 }
 
