@@ -32,7 +32,6 @@
 #include "Composition.hpp"
 #include "Node.hpp"
 #include "Score.hpp"
-using namespace boost::numeric;
 #endif
 
 namespace csound {
@@ -49,7 +48,7 @@ namespace csound {
  * with the coordinate system of its parent to derive a new local coordinate system,
  * which is applied to all child events.
  */
-class ScoreModel :
+class SILENCE_PUBLIC ScoreModel :
                         public Composition,
                         public Node {
 public:
@@ -60,7 +59,7 @@ public:
          * Generates a score based on a music graph defined
          * by the child nodes of this.
          */
-        virtual void generate();
+        virtual int generate();
         /**
          * Clears the score.
          */
