@@ -116,7 +116,7 @@ const char *getNameForOpcode(int opcode)
         return "No name for this opcode.";
     } else {
         return it->second;
-  }
+    }
 }
 
 double CsoundVST::inputScale = 32767.0;
@@ -124,90 +124,90 @@ double CsoundVST::outputScale = (1.0 / 32767.0);
 void *CsoundVST::fltkWaitThreadId = 0;
 
 CsoundVST::CsoundVST(audioMasterCallback audioMaster) :
-  AudioEffectX(audioMaster, kNumPrograms, 0),
-  isSynth(true),
-  isMultiThreaded(true),
-  csoundFrameI(0),
-  csoundLastFrame(0),
-  channelI(0),
-  channelN(0),
-  hostFrameI(0),
-  vstSr(0),
-  vstCurrentSampleBlockStart(0),
-  vstCurrentSampleBlockEnd(0),
-  vstCurrentSamplePosition(0),
-  vstPriorSamplePosition(0),
+    AudioEffectX(audioMaster, kNumPrograms, 0),
+    isSynth(true),
+    isMultiThreaded(true),
+    csoundFrameI(0),
+    csoundLastFrame(0),
+    channelI(0),
+    channelN(0),
+    hostFrameI(0),
+    vstSr(0),
+    vstCurrentSampleBlockStart(0),
+    vstCurrentSampleBlockEnd(0),
+    vstCurrentSamplePosition(0),
+    vstPriorSamplePosition(0),
     CSOUNDVST_PRINT_OPCODES(0),
-  csoundVstFltk(0)
+    csoundVstFltk(0)
 {
     CSOUNDVST_PRINT_OPCODES = std::getenv("CSOUNDVST_PRINT_OPCODES");
     Message("CSOUNDVST_PRINT_OPCODES: 0x%p\n", CSOUNDVST_PRINT_OPCODES);
     if (fltkWaitThreadId == 0) {
-      Fl::lock();
-      fltkWaitThreadId == csoundGetCurrentThreadId();
+        Fl::lock();
+        fltkWaitThreadId == csoundGetCurrentThreadId();
     }
-  setNumInputs(kNumInputs);
-  setNumOutputs(kNumOutputs);
-  setUniqueID('cVsT');
-  canProcessReplacing();
-  setIsSynth(true);
-  open();
-  csoundVstFltk = new CsoundVstFltk(this);
-  int number = 0;
-  csoundVstFltk->preferences.get("IsSynth", number, 0);
+    setNumInputs(kNumInputs);
+    setNumOutputs(kNumOutputs);
+    setUniqueID('cVsT');
+    canProcessReplacing();
+    setIsSynth(true);
+    open();
+    csoundVstFltk = new CsoundVstFltk(this);
+    int number = 0;
+    csoundVstFltk->preferences.get("IsSynth", number, 0);
     if(audioMaster) {
         if(number) {
-          AudioEffectX::isSynth(true);
+            AudioEffectX::isSynth(true);
         } else {
-          AudioEffectX::isSynth(false);
+            AudioEffectX::isSynth(false);
         }
     }
-  programsAreChunks(true);
-  curProgram = 0;
-  bank.resize(kNumPrograms);
+    programsAreChunks(true);
+    curProgram = 0;
+    bank.resize(kNumPrograms);
     for(size_t i = 0; i < bank.size(); i++) {
-      char buffer[0x24];
-      sprintf(buffer, "Program%d", (int)(i + 1));
-      bank[i].name = buffer;
+        char buffer[0x24];
+        sprintf(buffer, "Program%d", (int)(i + 1));
+        bank[i].name = buffer;
     }
-  setCommand("csound -f -h -+rtmidi=null -M0 -d -n -m7 --midi-key-oct=4 --midi-velocity=5");
+    setCommand("csound -f -h -+rtmidi=null -M0 -d -n -m7 --midi-key-oct=4 --midi-velocity=5");
 }
 
 CsoundVST::CsoundVST() :
-  AudioEffectX(0, kNumPrograms, 0),
-  isSynth(true),
-  isMultiThreaded(true),
-  csoundFrameI(0),
-  csoundLastFrame(0),
-  channelI(0),
-  channelN(0),
-  hostFrameI(0),
-  vstSr(0),
-  vstCurrentSampleBlockStart(0),
-  vstCurrentSampleBlockEnd(0),
-  vstCurrentSamplePosition(0),
-  vstPriorSamplePosition(0),
+    AudioEffectX(0, kNumPrograms, 0),
+    isSynth(true),
+    isMultiThreaded(true),
+    csoundFrameI(0),
+    csoundLastFrame(0),
+    channelI(0),
+    channelN(0),
+    hostFrameI(0),
+    vstSr(0),
+    vstCurrentSampleBlockStart(0),
+    vstCurrentSampleBlockEnd(0),
+    vstCurrentSamplePosition(0),
+    vstPriorSamplePosition(0),
     CSOUNDVST_PRINT_OPCODES(0),
-  csoundVstFltk(0)
+    csoundVstFltk(0)
 {
     CSOUNDVST_PRINT_OPCODES = std::getenv("CSOUNDVST_PRINT_OPCODES");
     Message("CSOUNDVST_PRINT_OPCODES: 0x%p\n", CSOUNDVST_PRINT_OPCODES);
     if (fltkWaitThreadId == 0) {
-      Fl::lock();
-      fltkWaitThreadId == csoundGetCurrentThreadId();
+        Fl::lock();
+        fltkWaitThreadId == csoundGetCurrentThreadId();
     }
-  setNumInputs(2);              // stereo in
-  setNumOutputs(2);             // stereo out
-  setUniqueID('cVsT');  // identify
-  canProcessReplacing();        // supports both accumulating and replacing output
-  //open();
-  csoundVstFltk = new CsoundVstFltk(this);
-  bank.resize(kNumPrograms);
-  curProgram = 0;
+    setNumInputs(2);              // stereo in
+    setNumOutputs(2);             // stereo out
+    setUniqueID('cVsT');  // identify
+    canProcessReplacing();        // supports both accumulating and replacing output
+    //open();
+    csoundVstFltk = new CsoundVstFltk(this);
+    bank.resize(kNumPrograms);
+    curProgram = 0;
     for(size_t i = 0; i < bank.size(); i++) {
-      char buffer[0x24];
-      sprintf(buffer, "Program%d", i + 1);
-      bank[i].name = buffer;
+        char buffer[0x24];
+        sprintf(buffer, "Program%d", i + 1);
+        bank[i].name = buffer;
     }
 }
 
@@ -217,234 +217,234 @@ CsoundVST::~CsoundVST()
 
 bool CsoundVST::getIsSynth() const
 {
-  return isSynth;
+    return isSynth;
 }
 
 void CsoundVST::setIsSynth(bool isSynth)
 {
-  this->isSynth = isSynth;
+    this->isSynth = isSynth;
 }
 
 bool CsoundVST::getIsVst() const
 {
-  if (audioMaster) {
-    return true;
-  } else {
-    return false;
-  }
+    if (audioMaster) {
+        return true;
+    } else {
+        return false;
+    }
 }
 
 void CsoundVST::setProgramName(char *name)
 {
-  bank[curProgram].name = name;
+    bank[curProgram].name = name;
 }
 
 void CsoundVST::getProgramName(char *name)
 {
-  strcpy(name, bank[curProgram].name.c_str());
+    strcpy(name, bank[curProgram].name.c_str());
 }
 
 AEffEditor* CsoundVST::getEditor()
 {
-  return editor;
+    return editor;
 }
 
 void CsoundVST::openView(bool doRun)
 {
-  editor->open(0);
-  if(doRun) {
-    fltkrun();
-  }
+    editor->open(0);
+    if(doRun) {
+        fltkrun();
+    }
 }
 
 void CsoundVST::closeView()
 {
-  editor->close();
+    editor->close();
 }
 
 int CsoundVST::midiDeviceOpen(CSOUND *csound, void **userData,
                               const char *devName)
 {
-  *userData = csoundGetHostData(csound);
-  return 0;
+    *userData = csoundGetHostData(csound);
+    return 0;
 }
 
 int CsoundVST::midiDeviceClose(CSOUND *csound, void *userData)
 {
-  return 0;
+    return 0;
 }
 
 uintptr_t CsoundVST::performanceThreadRoutine()
 {
-  stop();
-  Reset();
-  // Translate csd-style command lines to orc/sco style.
-  std::string command = getCommand();
-  std::string vstcommand;
-  bool updateCommand = false;
-  if (command.find("-") == 0 || command.length() == 0) {
-    updateCommand = true;
-    vstcommand = "csound ";
-  }
-  vstcommand.append(command);
-  if (command.find(".orc") == std::string::npos && command.find(".sco") == std::string::npos) {
-    updateCommand = true;
-    //vstcommand.append(" temp.orc temp.sco");
-  }
-  if (updateCommand) {
-    setCommand(vstcommand);
-    std::string buffer = getCommand();
-    csoundVstFltk->commandInput->value(buffer.c_str());
-  }
-  reset();
-  // FLTK flags is the sum of any of the following values:
-  //   1:  disable widget opcodes by setting up dummy opcodes instead
-  //   2:  disable FLTK graphs
-  //   4:  disable the use of a separate thread for widget opcodes
-  //   8:  disable the use of Fl::lock() and Fl::unlock()
-  //  16:  disable the use of Fl::awake()
-  // 128:  disable widget opcodes by not registering any opcodes
-  // 256:  disable the use of Fl::wait() (implies no widget thread)
-  CreateGlobalVariable("FLTK_Flags", sizeof(int));
-  int *fltkFlags = (int *)QueryGlobalVariable("FLTK_Flags");
-  //*fltkFlags = 274;
-  //*fltkFlags = 286;
-  *fltkFlags = 256 + 16 + 8 + 4 + 2;
-  // It used to be possible to compile with an empty orc and sco without
-  // crashing, but not any longer. So we test for a valid orc (contains
-  // "instr" and "endin").
-  const std::string &testorc = getOrchestra();
-  if ((testorc.find("instr") == std::string::npos) ||
+    stop();
+    Reset();
+    // Translate csd-style command lines to orc/sco style.
+    std::string command = getCommand();
+    std::string vstcommand;
+    bool updateCommand = false;
+    if (command.find("-") == 0 || command.length() == 0) {
+        updateCommand = true;
+        vstcommand = "csound ";
+    }
+    vstcommand.append(command);
+    if (command.find(".orc") == std::string::npos && command.find(".sco") == std::string::npos) {
+        updateCommand = true;
+        //vstcommand.append(" temp.orc temp.sco");
+    }
+    if (updateCommand) {
+        setCommand(vstcommand);
+        std::string buffer = getCommand();
+        csoundVstFltk->commandInput->value(buffer.c_str());
+    }
+    reset();
+    // FLTK flags is the sum of any of the following values:
+    //   1:  disable widget opcodes by setting up dummy opcodes instead
+    //   2:  disable FLTK graphs
+    //   4:  disable the use of a separate thread for widget opcodes
+    //   8:  disable the use of Fl::lock() and Fl::unlock()
+    //  16:  disable the use of Fl::awake()
+    // 128:  disable widget opcodes by not registering any opcodes
+    // 256:  disable the use of Fl::wait() (implies no widget thread)
+    CreateGlobalVariable("FLTK_Flags", sizeof(int));
+    int *fltkFlags = (int *)QueryGlobalVariable("FLTK_Flags");
+    //*fltkFlags = 274;
+    //*fltkFlags = 286;
+    *fltkFlags = 256 + 16 + 8 + 4 + 2;
+    // It used to be possible to compile with an empty orc and sco without
+    // crashing, but not any longer. So we test for a valid orc (contains
+    // "instr" and "endin").
+    const std::string &testorc = getOrchestra();
+    if ((testorc.find("instr") == std::string::npos) ||
             (testorc.find("endin") == std::string::npos)) {
-      Message("Csound orchestra missing or invalid.\n");
-      reset();
-      stop();
-      return 0;
+        Message("Csound orchestra missing or invalid.\n");
+        reset();
+        stop();
+        return 0;
     }
     if(getIsVst()) {
-      Message("Compiling for VST performance.\n");
-      SetHostImplementedAudioIO(1, 0);
-      SetHostImplementedMIDIIO(1);
-      SetExternalMidiInOpenCallback(&CsoundVST::midiDeviceOpen);
-      SetExternalMidiReadCallback(&CsoundVST::midiRead);
-      SetExternalMidiInCloseCallback(&CsoundVST::midiDeviceClose);
+        Message("Compiling for VST performance.\n");
+        SetHostImplementedAudioIO(1, 0);
+        SetHostImplementedMIDIIO(1);
+        SetExternalMidiInOpenCallback(&CsoundVST::midiDeviceOpen);
+        SetExternalMidiReadCallback(&CsoundVST::midiRead);
+        SetExternalMidiInCloseCallback(&CsoundVST::midiDeviceClose);
         if(compile()) {
-          Message("Csound compilation failed.\n");
-          reset();
-          stop();
+            Message("Csound compilation failed.\n");
+            reset();
+            stop();
         }
         int initialDelayFrames = GetKsmps();
         setInitialDelay(initialDelayFrames);
     } else {
-      Message("Classic performance.\n");
-      perform();
+        Message("Classic performance.\n");
+        perform();
     }
-  return 0;
+    return 0;
 }
 
 bool CsoundVST::getIsMultiThreaded() const
 {
-  return isMultiThreaded;
+    return isMultiThreaded;
 }
 
 void CsoundVST::setIsMultiThreaded(bool isMultiThreaded)
 {
-  this->isMultiThreaded = isMultiThreaded;
+    this->isMultiThreaded = isMultiThreaded;
 }
 
 uintptr_t performanceThreadRoutine_(void *data)
 {
-  return ((CsoundVST *)data)->performanceThreadRoutine();
+    return ((CsoundVST *)data)->performanceThreadRoutine();
 }
 
 static int threadYieldCallback(CSOUND *csound)
 {
-  CsoundVST *csoundVst_ = (CsoundVST *) csoundGetHostData(csound);
-  if (csoundVst_) {
-    csoundVst_->fltkwait();
-  }
-  return 1;
+    CsoundVST *csoundVst_ = (CsoundVST *) csoundGetHostData(csound);
+    if (csoundVst_) {
+        csoundVst_->fltkwait();
+    }
+    return 1;
 }
 
 static int nonThreadYieldCallback(CSOUND *)
 {
-  return 1;
+    return 1;
 }
 
 int CsoundVST::performance()
 {
-  int result = true;
+    int result = true;
     if(getIsVst()) {
-      Message("VST performance.\n");
-      SetYieldCallback(nonThreadYieldCallback);
-      performanceThreadRoutine();
+        Message("VST performance.\n");
+        SetYieldCallback(nonThreadYieldCallback);
+        performanceThreadRoutine();
     } else if(getIsMultiThreaded()) {
-      Message("Multi-threaded performance.\n");
-      SetYieldCallback(threadYieldCallback);
-      void *result_ = csoundCreateThread(performanceThreadRoutine_, this);
-      if(result_) {
-        result = true;
-      } else {
-        result = false;
-      }
-      Message("Created Csound performance thread.\n");
+        Message("Multi-threaded performance.\n");
+        SetYieldCallback(threadYieldCallback);
+        void *result_ = csoundCreateThread(performanceThreadRoutine_, this);
+        if(result_) {
+            result = true;
+        } else {
+            result = false;
+        }
+        Message("Created Csound performance thread.\n");
     } else {
-      Message("Single-threaded performance.\n");
-      SetYieldCallback(nonThreadYieldCallback);
-      performanceThreadRoutine();
+        Message("Single-threaded performance.\n");
+        SetYieldCallback(nonThreadYieldCallback);
+        performanceThreadRoutine();
     }
-  return result;
+    return result;
 }
 
 void CsoundVST::open()
 {
-  Message("BEGAN CsoundVST::open()...\n");
-  SetHostData(this);
-  std::string filename_ = getFilename();
+    Message("BEGAN CsoundVST::open()...\n");
+    SetHostData(this);
+    std::string filename_ = getFilename();
     if(filename_.length() > 0) {
-      setFilename(filename_);
+        setFilename(filename_);
     }
-  // setFLTKThreadLocking(false);
-  Message("ENDED CsoundVST::open().\n");
+    // setFLTKThreadLocking(false);
+    Message("ENDED CsoundVST::open().\n");
 }
 
 void CsoundVST::reset()
 {
-  csoundFrameI = 0;
-  csoundLastFrame = 0;
-  channelI = 0;
-  channelN = 0;
-  hostFrameI = 0;
-  vstSr = 0;
-  vstCurrentSampleBlockStart = 0;
-  vstCurrentSampleBlockEnd = 0;
-  vstCurrentSamplePosition = 0;
-  vstPriorSamplePosition = 0;
-  midiEventQueue.clear();
+    csoundFrameI = 0;
+    csoundLastFrame = 0;
+    channelI = 0;
+    channelN = 0;
+    hostFrameI = 0;
+    vstSr = 0;
+    vstCurrentSampleBlockStart = 0;
+    vstCurrentSampleBlockEnd = 0;
+    vstCurrentSamplePosition = 0;
+    vstPriorSamplePosition = 0;
+    midiEventQueue.clear();
 }
 
 void CsoundVST::setProgram(VstInt32 program)
 {
     if(program < kNumPrograms && program >= 0) {
-      curProgram = program;
-      setText(bank[curProgram].text);
+        curProgram = program;
+        setText(bank[curProgram].text);
     }
 }
 
 void CsoundVST::suspend()
 {
-  stop();
+    stop();
 }
 
 void CsoundVST::resume()
 {
-  CsoundVstFltk *ed = (CsoundVstFltk *)getEditor();
-  if (ed) {
-    if (ed->isOpen()) {
-      ed->updateModel();
+    CsoundVstFltk *ed = (CsoundVstFltk *)getEditor();
+    if (ed) {
+        if (ed->isOpen()) {
+            ed->updateModel();
+        }
     }
-  }
-  performance();
+    performance();
 }
 
 
@@ -453,85 +453,85 @@ VstInt32 CsoundVST::processEvents(VstEvents *vstEvents)
     if(getIsGo()) {
         for(int i = 0; i < vstEvents->numEvents; i++) {
             if(vstEvents->events[i]->type == kVstMidiType) {
-              VstMidiEvent *vstMidiEvent = (VstMidiEvent *)vstEvents->events[i];
-              midiEventQueue.push_back(*vstMidiEvent);
+                VstMidiEvent *vstMidiEvent = (VstMidiEvent *)vstEvents->events[i];
+                midiEventQueue.push_back(*vstMidiEvent);
             }
         }
-      return 1;
+        return 1;
     } else {
-      return 0;
+        return 0;
     }
 }
 
 int CsoundVST::midiRead(CSOUND *csound, void *userData,
                         unsigned char *midiData, int nbytes)
 {
-  CsoundVST *csoundVST = (CsoundVST *)userData;
-  int cnt = 0;
-  while (!csoundVST->midiEventQueue.empty() && cnt <= (nbytes - 3)) {
-    const VstMidiEvent &event = csoundVST->midiEventQueue.front();
-    midiData[cnt + 0] = (unsigned char) event.midiData[0];
-    midiData[cnt + 1] = (unsigned char) event.midiData[1];
-    midiData[cnt + 2] = (unsigned char) event.midiData[2];
-    csoundVST->midiEventQueue.pop_front();
-    //csoundVST->Message("CsoundVST::midiRead(%x, %x, %x)\n",
-    //(int) midiData[cnt + 0],
-    //(int) midiData[cnt + 1],
-    //(int) midiData[cnt + 2]);
-    switch ((int) midiData[cnt] & 0xF0) {
-    case 0x80:    /* note off */
-    case 0x90:    /* note on */
-    case 0xA0:    /* polyphonic pressure */
-    case 0xB0:    /* control change */
-    case 0xE0:    /* pitch bend */
-      cnt += 3;
-      break;
-    case 0xC0:    /* program change */
-    case 0xD0:    /* channel pressure */
-      cnt += 2;
-      break;
-    case 0xF0:
-      switch ((int) midiData[cnt]) {
-      case 0xF8:    /* timing clock */
-      case 0xFA:    /* start */
-      case 0xFB:    /* continue */
-      case 0xFC:    /* stop */
-      case 0xFF:    /* reset */
-        cnt++;
-      }
-      break;      /* ignore any other message */
+    CsoundVST *csoundVST = (CsoundVST *)userData;
+    int cnt = 0;
+    while (!csoundVST->midiEventQueue.empty() && cnt <= (nbytes - 3)) {
+        const VstMidiEvent &event = csoundVST->midiEventQueue.front();
+        midiData[cnt + 0] = (unsigned char) event.midiData[0];
+        midiData[cnt + 1] = (unsigned char) event.midiData[1];
+        midiData[cnt + 2] = (unsigned char) event.midiData[2];
+        csoundVST->midiEventQueue.pop_front();
+        //csoundVST->Message("CsoundVST::midiRead(%x, %x, %x)\n",
+        //(int) midiData[cnt + 0],
+        //(int) midiData[cnt + 1],
+        //(int) midiData[cnt + 2]);
+        switch ((int) midiData[cnt] & 0xF0) {
+        case 0x80:    /* note off */
+        case 0x90:    /* note on */
+        case 0xA0:    /* polyphonic pressure */
+        case 0xB0:    /* control change */
+        case 0xE0:    /* pitch bend */
+            cnt += 3;
+            break;
+        case 0xC0:    /* program change */
+        case 0xD0:    /* channel pressure */
+            cnt += 2;
+            break;
+        case 0xF0:
+            switch ((int) midiData[cnt]) {
+            case 0xF8:    /* timing clock */
+            case 0xFA:    /* start */
+            case 0xFB:    /* continue */
+            case 0xFC:    /* stop */
+            case 0xFF:    /* reset */
+                cnt++;
+            }
+            break;      /* ignore any other message */
+        }
     }
-  }
-  return cnt;
+    return cnt;
 }
 
 void CsoundVST::process(float **hostInput, float **hostOutput, VstInt32 hostFrameN)
 {
     if(getIsGo()) {
-      synchronizeScore();
-      MYFLT *csoundInput = GetSpin();
-      MYFLT *csoundOutput = GetSpout();
-      size_t csoundLastFrame = GetKsmps() - 1;
-      size_t channelN = GetNchnls();
-      size_t channelI;
+        synchronizeScore();
+        MYFLT *csoundInput = GetSpin();
+        MYFLT *csoundOutput = GetSpout();
+        size_t csoundLastFrame = GetKsmps() - 1;
+        size_t channelN = GetNchnls();
+        size_t channelI;
         for(VstInt32 hostFrameI = 0; hostFrameI < hostFrameN; hostFrameI++) {
             for(channelI = 0; channelI < channelN; channelI++) {
-              csoundInput[(csoundFrameI * channelN) + channelI] = hostInput[channelI][hostFrameI];
+                csoundInput[(csoundFrameI * channelN) + channelI] = hostInput[channelI][hostFrameI];
             }
             for(channelI = 0; channelI < channelN; channelI++) {
-              hostOutput[channelI][hostFrameI] += csoundOutput[(csoundFrameI * channelN) + channelI] * outputScale;
-              csoundOutput[(csoundFrameI * channelN) + channelI] = 0.0;
+                hostOutput[channelI][hostFrameI] += csoundOutput[(csoundFrameI * channelN) + channelI] * outputScale;
+                csoundOutput[(csoundFrameI * channelN) + channelI] = 0.0;
             }
-          csoundFrameI++;
+            csoundFrameI++;
             if(csoundFrameI > csoundLastFrame) {
-              csoundFrameI = 0;
-              performKsmps();
+                csoundFrameI = 0;
+                performKsmps();
             }
         }
     } else {
         for (VstInt32 hostFrameI = 0; hostFrameI < hostFrameN; hostFrameI++) {
             for (channelI = 0; channelI < kNumOutputs; channelI++) {
-              hostOutput[channelI][hostFrameI] += hostInput[channelI][hostFrameI];
+                hostOutput[channelI][hostFrameI] += hostInput[channelI][hostFrameI];
             }
         }
     }
@@ -540,30 +540,30 @@ void CsoundVST::process(float **hostInput, float **hostOutput, VstInt32 hostFram
 void CsoundVST::processReplacing(float **hostInput, float **hostOutput, VstInt32 hostFrameN)
 {
     if(getIsGo()) {
-      synchronizeScore();
-      MYFLT *csoundInput = GetSpin();
-      MYFLT *csoundOutput = GetSpout();
-      size_t csoundLastFrame = GetKsmps() - 1;
-      size_t channelN = GetNchnls();
-      size_t channelI;
+        synchronizeScore();
+        MYFLT *csoundInput = GetSpin();
+        MYFLT *csoundOutput = GetSpout();
+        size_t csoundLastFrame = GetKsmps() - 1;
+        size_t channelN = GetNchnls();
+        size_t channelI;
         for(VstInt32 hostFrameI = 0; hostFrameI < hostFrameN; hostFrameI++) {
             for(channelI = 0; channelI < channelN; channelI++) {
-              csoundInput[(csoundFrameI * channelN) + channelI] = hostInput[channelI][hostFrameI];
+                csoundInput[(csoundFrameI * channelN) + channelI] = hostInput[channelI][hostFrameI];
             }
             for(channelI = 0; channelI < channelN; channelI++) {
-              hostOutput[channelI][hostFrameI] = csoundOutput[(csoundFrameI * channelN) + channelI] *  outputScale;
-              csoundOutput[(csoundFrameI * channelN) + channelI] = 0.0;
+                hostOutput[channelI][hostFrameI] = csoundOutput[(csoundFrameI * channelN) + channelI] *  outputScale;
+                csoundOutput[(csoundFrameI * channelN) + channelI] = 0.0;
             }
-          csoundFrameI++;
+            csoundFrameI++;
             if(csoundFrameI > csoundLastFrame) {
-              csoundFrameI = 0;
-              performKsmps();
+                csoundFrameI = 0;
+                performKsmps();
             }
         }
     } else {
         for (VstInt32 hostFrameI = 0; hostFrameI < hostFrameN; hostFrameI++) {
             for (channelI = 0; channelI < kNumOutputs; channelI++) {
-              hostOutput[channelI][hostFrameI] = hostInput[channelI][hostFrameI];
+                hostOutput[channelI][hostFrameI] = hostInput[channelI][hostFrameI];
             }
         }
     }
@@ -571,23 +571,19 @@ void CsoundVST::processReplacing(float **hostInput, float **hostOutput, VstInt32
 
 void CsoundVST::synchronizeScore()
 {
-  vstPriorSamplePosition = vstCurrentSamplePosition;
-  VstTimeInfo *vstTimeInfo = getTimeInfo(kVstTransportPlaying);
+    vstPriorSamplePosition = vstCurrentSamplePosition;
+    VstTimeInfo *vstTimeInfo = getTimeInfo(kVstTransportPlaying);
     if ((vstTimeInfo->flags & kVstTransportPlaying) == kVstTransportPlaying) {
-      vstSr = double(vstTimeInfo->sampleRate);
-      vstCurrentSamplePosition = (int) vstTimeInfo->samplePos;
-      vstCurrentSampleBlockStart = vstTimeInfo->samplePos / vstSr;
-      if((vstCurrentSamplePosition && !vstPriorSamplePosition) ||
+        vstSr = double(vstTimeInfo->sampleRate);
+        vstCurrentSamplePosition = (int) vstTimeInfo->samplePos;
+        vstCurrentSampleBlockStart = vstTimeInfo->samplePos / vstSr;
+        if((vstCurrentSamplePosition && !vstPriorSamplePosition) ||
                 (vstCurrentSamplePosition < vstPriorSamplePosition)) {
-            if(getIsGo()) {
-              SetScorePending(1);
-              RewindScore();
-              SetScoreOffsetSeconds(vstCurrentSampleBlockStart);
-            }
-        }
-    } else {
-        if(getIsGo()) {
-          SetScorePending(0);
+            //if(getIsGo()) {
+                // This is a workaround to enable alwayson to stay on in the VST context.
+                SetScoreOffsetSeconds(vstCurrentSampleBlockStart);
+                csoundCompileOrc(csound, getOrchestra().c_str());
+            //}
         }
     }
 }
@@ -595,117 +591,117 @@ void CsoundVST::synchronizeScore()
 bool CsoundVST::getInputProperties(VstInt32 index, VstPinProperties* properties)
 {
     if(index < kNumInputs) {
-      sprintf(properties->label, "My %d In", index + 1);
-      properties->flags = kVstPinIsStereo | kVstPinIsActive;
-      return true;
+        sprintf(properties->label, "My %d In", index + 1);
+        properties->flags = kVstPinIsStereo | kVstPinIsActive;
+        return true;
     }
-  return false;
+    return false;
 }
 
 bool CsoundVST::getOutputProperties(VstInt32 index, VstPinProperties* properties)
 {
     if(index < kNumOutputs) {
-      sprintf(properties->label, "My %d Out", index + 1);
-      properties->flags = kVstPinIsStereo | kVstPinIsActive;
-      return true;
+        sprintf(properties->label, "My %d Out", index + 1);
+        properties->flags = kVstPinIsStereo | kVstPinIsActive;
+        return true;
     }
-  return false;
+    return false;
 }
 
 bool CsoundVST::getProgramNameIndexed(VstInt32 category, VstInt32 index, char* text)
 {
     if(index < kNumPrograms) {
         strcpy(text, bank[index].name.c_str());
-      return true;
+        return true;
     }
-  return false;
+    return false;
 }
 
 bool CsoundVST::getEffectName(char* name)
 {
-  strcpy(name, "CsoundVST");
-  return true;
+    strcpy(name, "CsoundVST");
+    return true;
 }
 
 bool CsoundVST::getVendorString(char* text)
 {
-  strcpy(text, "Irreducible Productions");
-  return true;
+    strcpy(text, "Irreducible Productions");
+    return true;
 }
 
 bool CsoundVST::getProductString(char* text)
 {
-  strcpy(text, "CsoundVST");
-  return true;
+    strcpy(text, "CsoundVST");
+    return true;
 }
 
 VstInt32 CsoundVST::canDo(char* text)
 {
     if(strcmp(text, "receiveVstTimeInfo") == 0) {
-      return 1;
+        return 1;
     }
     if(strcmp(text, "receiveVstEvents") == 0) {
-      return 1;
+        return 1;
     }
     if(strcmp(text, "receiveVstMidiEvent") == 0) {
-      return 1;
+        return 1;
     }
-  return 0;
+    return 0;
 }
 
 bool CsoundVST::keysRequired()
 {
-  return 1;
+    return 1;
 }
 
 VstInt32 CsoundVST::getProgram()
 {
-  //bank[curProgram].text = getText();
-  return curProgram;
+    //bank[curProgram].text = getText();
+    return curProgram;
 }
 
 bool CsoundVST::copyProgram(VstInt32 destination)
 {
     if(destination < kNumPrograms) {
-      bank[destination] = bank[curProgram];
-      return true;
+        bank[destination] = bank[curProgram];
+        return true;
     }
-  return false;
+    return false;
 }
 
 VstInt32 CsoundVST::getChunk(void** data, bool isPreset)
 {
-  ((CsoundVstFltk *)getEditor())->updateModel();
-  VstInt32 returnValue = 0;
-  static std::string bankBuffer;
-  bank[curProgram].text = getText();
+    ((CsoundVstFltk *)getEditor())->updateModel();
+    VstInt32 returnValue = 0;
+    static std::string bankBuffer;
+    bank[curProgram].text = getText();
     if(isPreset) {
         bankBuffer = bank[curProgram].text;
         *data = (void *)bankBuffer.c_str();
         returnValue = bankBuffer.size();
     } else {
-      std::ostringstream stream;
-      int n = bank.size();
-      stream << n << "\n";
+        std::ostringstream stream;
+        int n = bank.size();
+        stream << n << "\n";
         for(std::vector<Preset>::iterator it = bank.begin(); it != bank.end(); ++it) {
-          Preset &preset = (*it);
-          stream << preset.name.c_str() << "\n";
-          stream << preset.text.size() << "\n";
+            Preset &preset = (*it);
+            stream << preset.name.c_str() << "\n";
+            stream << preset.text.size() << "\n";
             for(std::string::iterator jt = preset.text.begin(); jt != preset.text.end(); ++jt) {
-              stream.put(*jt);
+                stream.put(*jt);
             }
-          stream << "\n";
+            stream << "\n";
         }
-      bankBuffer = stream.str();
-      *data = (void *)bankBuffer.c_str();
-      returnValue = bankBuffer.size();
+        bankBuffer = stream.str();
+        *data = (void *)bankBuffer.c_str();
+        returnValue = bankBuffer.size();
     }
-  return returnValue;
+    return returnValue;
 }
 
 VstInt32 CsoundVST::setChunk(void* data, VstInt32 byteSize, bool isPreset)
 {
-  VstInt32 returnValue = 0;
+    VstInt32 returnValue = 0;
     if(isPreset) {
         Preset preset;
         preset.text.resize(byteSize);
@@ -713,97 +709,97 @@ VstInt32 CsoundVST::setChunk(void* data, VstInt32 byteSize, bool isPreset)
             preset.text[j] = ((const char *)data)[j];
         }
         bank[curProgram] = preset;
-      returnValue = byteSize;
+        returnValue = byteSize;
     } else {
-      std::string inputBuffer = (const char *)data;
-      std::istringstream stream(inputBuffer);
-      std::string buffer;
-      stream >> buffer;
-      stream >> std::ws;
-      int n = atoi(buffer.c_str());
-      bank.resize(n);
+        std::string inputBuffer = (const char *)data;
+        std::istringstream stream(inputBuffer);
+        std::string buffer;
+        stream >> buffer;
+        stream >> std::ws;
+        int n = atoi(buffer.c_str());
+        bank.resize(n);
         for(int i = 0; i < n; i++) {
-          Preset preset;
-          stream >> preset.name;
-          stream >> std::ws;
-          stream >> buffer;
-          stream >> std::ws;
-          int length = atoi(buffer.c_str());
-          preset.text.resize(length);
-          char c;
+            Preset preset;
+            stream >> preset.name;
+            stream >> std::ws;
+            stream >> buffer;
+            stream >> std::ws;
+            int length = atoi(buffer.c_str());
+            preset.text.resize(length);
+            char c;
             for(int j = 0; j < length; j++) {
-              stream.get(c);
-              preset.text[j] = c;
+                stream.get(c);
+                preset.text[j] = c;
             }
-          bank[i] = preset;
+            bank[i] = preset;
         }
-      returnValue = byteSize;
+        returnValue = byteSize;
     }
-  setProgram(curProgram);
+    setProgram(curProgram);
     ((CsoundVstFltk *)getEditor())->update();
-  return returnValue;
+    return returnValue;
 }
 
 std::string CsoundVST::getText()
 {
-  std::string buffer = getCSD();
-  return buffer;
+    std::string buffer = getCSD();
+    return buffer;
 }
 
 void CsoundVST::setText(const std::string text)
 {
-  setCSD(text);
+    setCSD(text);
 }
 
 void CsoundVST::openFile(std::string filename_)
 {
-  WaitCursor wait;
-  load(filename_);
-  bank[getProgram()].text = getText();
-  ((CsoundVstFltk *)getEditor())->update();
-  setFilename(filename_);
+    WaitCursor wait;
+    load(filename_);
+    bank[getProgram()].text = getText();
+    ((CsoundVstFltk *)getEditor())->update();
+    setFilename(filename_);
 }
 
 void CsoundVST::fltklock()
 {
-  if (fltkWaitThreadId != csoundGetCurrentThreadId()) {
-    Fl::lock();
-  }
+    if (fltkWaitThreadId != csoundGetCurrentThreadId()) {
+        Fl::lock();
+    }
 }
 
 void CsoundVST::fltkunlock()
 {
-  if (fltkWaitThreadId != csoundGetCurrentThreadId()) {
-    Fl::awake();
-    Fl::unlock();
-  } else {
-    Fl::awake();
-  }
+    if (fltkWaitThreadId != csoundGetCurrentThreadId()) {
+        Fl::awake();
+        Fl::unlock();
+    } else {
+        Fl::awake();
+    }
 }
 
 void CsoundVST::fltkflush()
 {
-  fltklock();
-  Fl::flush();
-  fltkunlock();
+    fltklock();
+    Fl::flush();
+    fltkunlock();
 }
 
 void CsoundVST::fltkwait()
 {
-  if (fltkWaitThreadId == csoundGetCurrentThreadId() || getIsVst()) {
-    Fl::wait(0.0);
-  }
+    if (fltkWaitThreadId == csoundGetCurrentThreadId() || getIsVst()) {
+        Fl::wait(0.0);
+    }
 }
 
 int CsoundVST::fltkrun()
 {
-  int status = -100;
-  if (!getIsVst()) {
-    status = Fl::run();
-  } else {
-    Message("Sorry, can't run FLTK if running as a VST plugin.\n");
-  }
-  return status;
+    int status = -100;
+    if (!getIsVst()) {
+        status = Fl::run();
+    } else {
+        Message("Sorry, can't run FLTK if running as a VST plugin.\n");
+    }
+    return status;
 }
 
 VstIntPtr CsoundVST::dispatcher(VstInt32 opcode, VstInt32 index, VstIntPtr value, void* ptr, float opt)
@@ -833,20 +829,20 @@ extern "C"
         }
         return effect->getAeffect();
     }
-  SILENCE_PUBLIC CsoundVST* CreateCsoundVST()
-  {
-    CsoundVST *csoundVST = new CsoundVST;
-    std::fprintf(stderr, "CreateCsoundVST: created 0x%p\n", csoundVST);
-    return csoundVST;
-  }
-  SILENCE_PUBLIC void RunCsoundVST(const char *filename)
-  {
-    CsoundVST *csoundVST = new CsoundVST;
-    AEffEditor *editor = csoundVST->getEditor();
-    editor->open(0);
-    if (filename) {
-      csoundVST->openFile(filename);
+    SILENCE_PUBLIC CsoundVST* CreateCsoundVST()
+    {
+        CsoundVST *csoundVST = new CsoundVST;
+        std::fprintf(stderr, "CreateCsoundVST: created 0x%p\n", csoundVST);
+        return csoundVST;
+    }
+    SILENCE_PUBLIC void RunCsoundVST(const char *filename)
+    {
+        CsoundVST *csoundVST = new CsoundVST;
+        AEffEditor *editor = csoundVST->getEditor();
+        editor->open(0);
+        if (filename) {
+            csoundVST->openFile(filename);
+        }
+        csoundVST->fltkrun();
     }
-    csoundVST->fltkrun();
-  }
 }
