@@ -1,21 +1,21 @@
 /*
     csound~ : A MaxMSP external interface for the Csound API.
-    
+
     Created by Davis Pyon on 2/4/06.
     Copyright 2006-2010 Davis Pyon. All rights reserved.
-    
+
     LICENSE AGREEMENT
-    
+
     This software is free software; you can redistribute it and/or
     modify it under the terms of the GNU Lesser General Public
     License as published by the Free Software Foundation; either
     version 2.1 of the License, or (at your option) any later version.
-    
+
     This software is distributed in the hope that it will be useful,
     but WITHOUT ANY WARRANTY; without even the implied warranty of
     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
     Lesser General Public License for more details.
-    
+
     You should have received a copy of the GNU Lesser General Public
     License along with this software; if not, write to the Free Software
     Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
@@ -26,6 +26,7 @@
 #ifdef _USE_BOOST_SERIALIZATION
 	#include "Parser.h" // Include here instead of in sequencer.h. That way, other files that include
 						// sequencer.h won't take so damn long to compile.
+    #include <boost/property_tree/xml_parser.hpp>
 	using boost::property_tree::ptree;
 #endif
 
@@ -52,7 +53,7 @@ void ControlEvent::save(ptree &pt) const
 }
 #endif
 
-CsoundEvent::CsoundEvent(int time, const char *evt) : 
+CsoundEvent::CsoundEvent(int time, const char *evt) :
 	Event(EVENT_TYPE_CSOUND, time), m_event(evt)
 {}
 
@@ -70,7 +71,7 @@ void CsoundEvent::save(ptree &pt) const
 }
 #endif
 
-MidiEvent::MidiEvent(int time, const byte *buf, int bytes) : 
+MidiEvent::MidiEvent(int time, const byte *buf, int bytes) :
 	Event(EVENT_TYPE_MIDI, time), m_size(bytes)
 {
 	assert(m_size<=MAX_MIDI_MESSAGE_SIZE);
@@ -78,14 +79,14 @@ MidiEvent::MidiEvent(int time, const byte *buf, int bytes) :
 }
 
 #ifdef _USE_BOOST_SERIALIZATION
-MidiEvent::MidiEvent(ptree &pt) : 
+MidiEvent::MidiEvent(ptree &pt) :
 	Event(EVENT_TYPE_MIDI, pt.get<int>("time")), m_size(pt.get<int>("size"))
 {
 	string byte_str;
 	std::vector<int> v(0); // parse_integers appends values, so vector must be empty.
 	byte_str = pt.get<string>("bytes");
 	Parser::parse_integers(byte_str.begin(), byte_str.end(), v);
-	for(int i=0; i<m_size; i++) 
+	for(int i=0; i<m_size; i++)
 		m_buffer[i] = v[i];
 }
 
@@ -134,11 +135,11 @@ Sequencer::Sequencer(t_object *o, CSOUND *c, ChannelGroup *g, MidiBuffer *m) :
 	m_midiInputBuffer(m),
 	m_lock((char*)"Sequencer"),
 	m_time(0), m_timerRes(1), m_nticks(0), m_fticks(0), m_nSamples(0), m_sr(DEFAULT_SAMPLE_RATE),
-	m_playing(false), 
+	m_playing(false),
 	m_recording(false),
 	m_max_clock(NULL),
 	m_read_write_thread_exists(false)
-{			
+{
 	m_max_clock = clock_new(this, (method)Sequencer_TimerCallback);
 	SetBPM(DEFAULT_BPM);
 	for(int i=0; i<16; i++)
@@ -148,7 +149,7 @@ Sequencer::Sequencer(t_object *o, CSOUND *c, ChannelGroup *g, MidiBuffer *m) :
 }
 
 Sequencer::~Sequencer()
-{	
+{
 	clock_unset(m_max_clock);
 	freeobject((t_object *) m_max_clock);
 	StopRecording();
@@ -184,22 +185,22 @@ int Sequencer::AdvanceTicks()
 	return m_nticks;
 }
 
-/* Have to define C function inside namespace if it's a friend 
+/* Have to define C function inside namespace if it's a friend
    to a C++ class that's inside a namespace. */
 namespace dvx
 {
 	void Sequencer_TimerCallback(Sequencer *s)
-	{	
+	{
 		if(s->m_playing) s->ProcessEvents(); // If playing, process some events.
 		s->m_time += s->AdvanceTicks();      // Advance the tick count and update the time.
-	
+
 		if(s->m_time >= MAX_TIME)
 		{
 			object_error(s->m_obj, "Maximum sequencer time reached. Stopping playing/recording.");
 			if(s->m_playing) s->StopPlaying();
 			if(s->m_recording) s->StopRecording();
 		}
-	
+
 		if(s->m_recording || s->m_playing) clock_fdelay(s->m_max_clock, s->m_timerRes);
 	}
 
@@ -224,7 +225,7 @@ namespace dvx
 } // namespace dvx
 
 void Sequencer::SampleBasedTimerCallback()
-{	
+{
 	if(m_playing) ProcessEvents();
 	m_time += AdvanceTicks();
 	if(m_time >= MAX_TIME)
@@ -232,11 +233,11 @@ void Sequencer::SampleBasedTimerCallback()
 		object_error(m_obj, "Stopping sequencer. Maximum time reached.");
 		if(m_playing) StopPlaying();
 		if(m_recording) StopRecording();
-	} 
+	}
 }
 
 void Sequencer::AdvanceSampleCount(int n)
-{		
+{
 	m_nSamples += n * 1000;
 	while(m_nSamples >= m_sr)
 	{
@@ -262,16 +263,16 @@ void Sequencer::StartRecording()
 
 	if(!m_recording)
 	{
-		m_events.clear(); // Delete all events.	
+		m_events.clear(); // Delete all events.
 		m_recording = true;
 		m_time = m_nticks = m_fticks = 0;
 		SetBPM(DEFAULT_BPM);
-	
+
 		// Add one Control event for each ChannelObject in the table.
 		{
 			ScopedLock k(c->m_lock);
 			boost::ptr_set<ChannelObject>::iterator it;
-			
+
 			for(it = c->m_channels.begin(); it != c->m_channels.end(); it++)
 			{
 				co = &*it;
@@ -279,7 +280,7 @@ void Sequencer::StartRecording()
 				else if(co->IsStringChannel()) AddStringEvent(co->m_name, co->m_str_value.c_str(), true);
 			}
 		}
-		
+
 		// Add one MIDI ctrl event for every entry in the m_ctrlMatrix < 128.
 		for(ch=0; ch<16; ch++)
 			for(ctrl=0; ctrl<128; ctrl++)
@@ -292,11 +293,11 @@ void Sequencer::StartRecording()
 					AddMIDIEvent(buf, 3, true);
 				}
 			}
-		
+
 		// Set the time to 1 so that we can distinguish between
 		// recorded events and initializing events.
-		m_time = 1;		
-		
+		m_time = 1;
+
 		// Set the clock so that Sequencer_TimerCallback() is called in m_timerRes ms.
 		clock_fdelay(m_max_clock, m_timerRes);
 	}
@@ -310,21 +311,21 @@ void Sequencer::StopRecording()
 	int firstEventTime = 1;
 	byte activeNoteMatrix[16][128];
 	byte status = 0, chan, pitch, vel, b[3];
-	
+
 	m_recording = false;
 	memset(activeNoteMatrix, 0, MIDI_MATRIX_SIZE);
-	
+
 	/* Find the first event with time >= 1 and subtract object's time - 1 from that event and all
 	   subsequent events.  In other words, move all recorded events back in time so that when the
 	   user hits play, playback of recorded events will begin immediately. Events with time == 0
 	   are initializing events; that's why we're looking for first event with time >= 1.
-	
+
 	   While moving events in time, keep track of MIDI note-on's and note-off's. After going
 	   through all events, take care of hanging MIDI notes. */
 
 	ScopedLock k(m_lock);
 	boost::ptr_multiset<Event>::iterator it;
-		
+
 	for(it = m_events.begin(); it != m_events.end(); it++)
 	{
 		e = &*it;
@@ -337,9 +338,9 @@ void Sequencer::StopRecording()
 			}
 			// multiset is still consistent because we're subtracting all event times
 			// by the same amount, so we don't have to remove/insert elements individually.
-			e->m_time -= firstEventTime - 1; 
+			e->m_time -= firstEventTime - 1;
 		}
-			
+
 		if(e->type() == EVENT_TYPE_MIDI)
 		{
 			me = static_cast<MidiEvent*>(e);
@@ -361,7 +362,7 @@ void Sequencer::StopRecording()
 			}
 		}
 	}
-		
+
 	// If any entries in active_note_count[][] are > 0, add a note-off for that chan+pitch.
 	for(int i=0; i<16; i++)
 	{
@@ -379,7 +380,7 @@ void Sequencer::StopRecording()
 }
 
 void Sequencer::StartPlaying()
-{	
+{
 	if(m_read_write_thread_exists)
 	{
 		object_warn(m_obj, "Can't start playing. Please wait until reading/writing has finished...");
@@ -388,7 +389,7 @@ void Sequencer::StartPlaying()
 	if(m_playing) StopPlaying();
 	if(m_recording) StopRecording();
 	ScopedLock k(m_lock);
-	
+
 	m_playing = true;
 	m_cur_event = m_events.begin();
 	m_time = m_nticks = m_fticks = 0;
@@ -401,7 +402,7 @@ void Sequencer::StopPlaying()
 	int i, j;
 	byte b[3];
 	ScopedLock k(m_lock);
-	
+
 	m_cur_event = m_events.begin();
 	m_playing = false;
 	m_time = m_nticks = m_fticks = 0;
@@ -424,7 +425,7 @@ void Sequencer::StopPlaying()
 bool Sequencer::AddCsoundEvent(char *buf, bool lock)
 {
 	int len = strlen(buf);
-	
+
 	if(len >= MAX_EVENT_MESSAGE_SIZE)
 	{
 		object_error(m_obj, "Event string size %d too large.  Max size is %d.", len, MAX_EVENT_MESSAGE_SIZE - 1);
@@ -492,7 +493,7 @@ void Sequencer::ProcessEvents()
 		m_playing = false;
 		return;
 	}
-		
+
 	while(m_cur_event != m_events.end() && m_cur_event->m_time <= m_time)
 	{
 		switch(m_cur_event->type())
@@ -519,7 +520,7 @@ void Sequencer::ProcessEvents()
 			{
 				MidiEvent &e = static_cast<MidiEvent&>(*m_cur_event);
 				m_midiInputBuffer->EnqueueBuffer(e.m_buffer, e.m_size);
-					
+
 				// Keep track of note-on/off's.
 				status = e.m_buffer[0] & 0xf0;
 				switch(status)
@@ -540,7 +541,7 @@ void Sequencer::ProcessEvents()
 						m_activeNoteMatrix[chan][pitch] -= 1;
 					break;
 				}
-			}	
+			}
 			break;
 		default: break;
 		}
@@ -578,15 +579,14 @@ void Sequencer::Write(const string & file)
 
 		ptr_multiset<Event>::iterator it;
 		for(it = m_events.begin(); it != m_events.end(); it++) it->save(pt);
-		
+
 		if(FILE_JSON == file_type)
 		{
 			write_json(file, top_pt, std::locale());
 		}
 		else if(FILE_XML == file_type)
 		{
-			boost::property_tree::xml_writer_settings<char> w(' ', 4); // Set indentation character and amount.
-			write_xml(file, top_pt, std::locale(), w);
+			write_xml(file, top_pt, std::locale(), boost::property_tree::xml_parser::xml_writer_make_settings(' ', 4u));
 		}
 		object_post(m_obj, "Finished writing %s.", file.c_str());
 	}
@@ -619,11 +619,11 @@ void Sequencer::Read(const string & file)
 
 	#ifdef _USE_BOOST_SERIALIZATION
 	try
-	{	
+	{
 		int type = EVENT_TYPE_NONE;
 		ptree top_pt;
 		ptree::iterator it;
-		
+
 		if(FILE_JSON == file_type)
 			read_json(file, top_pt);
 		else if(FILE_XML == file_type)
@@ -667,18 +667,18 @@ void Sequencer::ReadBinary(const string & file)
 	bool reverse = false;
 	int magic_number = FILE_MAGIC_NUMBER;
 	int magic_number_reverse = magic_number;
-	
+
 	reverseBytes((byte*)&magic_number_reverse, sizeof(int));
-	
+
 	if(m_playing) StopPlaying();
 	if(m_recording) StopRecording();
-	
+
 	ScopedLock k(m_lock);
-	
+
 	m_events.clear();
-	
+
 	fp = fopen(file.c_str(), "rb");
-	
+
 	if(fp == NULL)
 	{
 		object_error(m_obj, "fopen() failed for %s", file.c_str());
@@ -688,16 +688,16 @@ void Sequencer::ReadBinary(const string & file)
 	fseek(fp, 0, SEEK_END);
 	fileSize = ftell(fp);
 	fseek(fp, 0, SEEK_SET);
-	
+
 	buffer = (byte*) MemoryNew(fileSize);
-	
+
 	if(buffer == NULL)
 	{
 		object_error(m_obj, "MemoryNew() failed to create buffer for reading from %s", file.c_str());
 		fclose(fp);
 		return;
 	}
-	
+
 	result = fread(buffer, 1, fileSize, fp);
 
 	if(result != fileSize)
@@ -707,12 +707,12 @@ void Sequencer::ReadBinary(const string & file)
 		object_error(m_obj, "fread() failed for %s", file.c_str());
 		return;
 	}
-	
+
 	fclose(fp);
 	bytePtr = buffer;
 	magic = *(int*)bytePtr;
 	bytePtr += sizeof(int);
-	
+
 	if(magic != magic_number && magic != magic_number_reverse)
 	{
 		object_error(m_obj, "%s is not a csound~ recorded sequence.", file.c_str());
@@ -723,23 +723,23 @@ void Sequencer::ReadBinary(const string & file)
 		numEvents = *(int*)bytePtr;
 		reverseNumber((byte*)&numEvents, sizeof(int), reverse);
 		bytePtr += sizeof(int);
-		
+
 		for(i=0; i<numEvents; i++)
 		{
 			type = *(int*)bytePtr;
 			reverseNumber((byte*)&type, sizeof(int), reverse);
 			bytePtr += sizeof(int);
-			
+
 			time = *(int*)bytePtr;
 			reverseNumber((byte*)&time, sizeof(int), reverse);
 			bytePtr += sizeof(int);
-			
+
 			len = *(int*)bytePtr; // data1 size
 			reverseNumber((byte*)&len, sizeof(int), reverse);
 			bytePtr += sizeof(int);
-			
+
 			m_time = time;		// must set time before adding event
-			
+
 			switch(type)
 			{
 			case EVENT_TYPE_CSOUND:
@@ -770,10 +770,10 @@ void Sequencer::ReadBinary(const string & file)
 				break;
 			}
 		}
-		
+
 		object_post(m_obj, "\"%s\" successfully read into csound~.", file.c_str());
 	}
-	
+
 	MemoryFree(buffer);
 }
 
@@ -786,54 +786,54 @@ void Sequencer::WriteBinary(const string & file)
 	float fval;
 	void * vptr = NULL;
 	static int magic = FILE_MAGIC_NUMBER;
-	
+
 	if(m_playing) StopPlaying();
 	if(m_recording) StopRecording();
-	
+
 	ScopedLock k(m_lock);
-	
+
 	fp = fopen(file.c_str(), "wb");
-	
+
 	if(fp == NULL)
 	{
 		object_post(m_obj, "fopen() failed for %s", file.c_str());
 		return;
 	}
-	
+
 	buffer = (byte *) MemoryNew(bufferSize);
-	
+
 	if(buffer == NULL)
 	{
 		object_post(m_obj, "MemoryNew() failed to create buffer for writing to %s", file.c_str());
 		return;
 	}
-	
+
 	// First is the magic number.
 	realloc_result = BufferWrite(&buffer, &magic, sizeof(int), &byteCount, &bufferSize);
-	
+
 	// Then comes the # of events.
 	if(!realloc_result)
 	{
 		numEvents = m_events.size();
 		realloc_result = BufferWrite(&buffer, &numEvents, sizeof(int), &byteCount, &bufferSize);
 	}
-	
+
 	// Now we add the events.
 	boost::ptr_multiset<Event>::iterator it;
 	for(it = m_events.begin(); it != m_events.end(); it++)
 	{
 		// Save type.
-		if(!realloc_result) 
+		if(!realloc_result)
 			realloc_result = BufferWrite(&buffer, &it->m_type, sizeof(int), &byteCount, &bufferSize);
-		
+
 		// Save time.
-		if(!realloc_result) 
+		if(!realloc_result)
 			realloc_result = BufferWrite(&buffer, &it->m_time, sizeof(int), &byteCount, &bufferSize);
 
 		// Get data1 size.
 		switch(it->m_type)
 		{
-		case EVENT_TYPE_CSOUND: 
+		case EVENT_TYPE_CSOUND:
 		case EVENT_TYPE_CONTROL:
 		case EVENT_TYPE_STRING:
 			len = static_cast<StringEvent&>(*it).m_name.size() + 1;
@@ -846,11 +846,11 @@ void Sequencer::WriteBinary(const string & file)
 		}
 
 		// Save data1 size.
-		if(!realloc_result) 
+		if(!realloc_result)
 			realloc_result = BufferWrite(&buffer, &len, sizeof(int), &byteCount, &bufferSize);
-		
-		// Save data1.		
-		if(!realloc_result) 
+
+		// Save data1.
+		if(!realloc_result)
 			realloc_result = BufferWrite(&buffer, vptr, len, &byteCount, &bufferSize);
 
 		// Get data2 size.
@@ -872,23 +872,23 @@ void Sequencer::WriteBinary(const string & file)
 		}
 
 		// Save data2 size.
-		if(!realloc_result) 
+		if(!realloc_result)
 			realloc_result = BufferWrite(&buffer, &len, sizeof(int), &byteCount, &bufferSize);
-		
+
 		// Save data2.
 		if(!realloc_result && len > 0)
 			realloc_result = BufferWrite(&buffer, vptr, len, &byteCount, &bufferSize);
-		
+
 		if(realloc_result) break;
 	}
-	
+
 	if(!realloc_result)
 		result = fwrite(buffer, 1, byteCount, fp);
-	
+
 	fclose(fp);
-	
+
 	if(realloc_result == 1 || result != byteCount) object_post(m_obj, "fwrite() failed to write to %s.", file.c_str());
 	else post("%s successfully saved.", file.c_str());
-	
+
 	MemoryFree(buffer);
-}
\ No newline at end of file
+}
