@@ -39,8 +39,30 @@
 #include "csound.h"
 #include "cscore.h"
 #include "csound_data_structures.h"
+#include "csound_standard_types.h"
 #include "pools.h"
 
+#ifndef CSOUND_CSDL_H
+/* VL not sure if we need to check for SSE */
+#ifdef __SSE__
+#ifndef _MM_DENORMALS_ZERO_ON
+#include <xmmintrin.h>
+#define _MM_DENORMALS_ZERO_MASK   0x0040
+#define _MM_DENORMALS_ZERO_ON     0x0040
+#define _MM_DENORMALS_ZERO_OFF    0x0000
+#define _MM_SET_DENORMALS_ZERO_MODE(mode)                                   \
+            _mm_setcsr((_mm_getcsr() & ~_MM_DENORMALS_ZERO_MASK) | (mode))
+#define _MM_GET_DENORMALS_ZERO_MODE()                                       \
+            (_mm_getcsr() & _MM_DENORMALS_ZERO_MASK)
+#endif
+#else
+#define _MM_DENORMALS_ZERO_MASK   0
+#define _MM_DENORMALS_ZERO_ON     0
+#define _MM_DENORMALS_ZERO_OFF    0
+#define _MM_SET_DENORMALS_ZERO_MODE(mode)
+#endif
+#endif
+
 #ifdef __cplusplus
 extern "C" {
 #endif /*  __cplusplus */
@@ -82,15 +104,8 @@ typedef struct {
 //#define OUTOCOUNT   ORTXT.outoffs->count
 #define INOCOUNT    ORTXT.inArgCount
 #define OUTOCOUNT   ORTXT.outArgCount
-#define XINCODE     ORTXT.xincod
-#  define XINARG1   (p->XINCODE & 1)
-#  define XINARG2   (p->XINCODE & 2)
-#  define XINARG3   (p->XINCODE & 4)
-#  define XINARG4   (p->XINCODE & 8)
-#  define XINARG5   (p->XINCODE &16)
-#define XOUTCODE    ORTXT.xoutcod
-//#define XSTRCODE    ORTXT.xincod_str
-//#define XOUTSTRCODE ORTXT.xoutcod_str
+#define IS_ASIG_ARG(x) (csoundGetTypeForArg(x) == &CS_VAR_TYPE_A)
+#define IS_STR_ARG(x) (csoundGetTypeForArg(x) == &CS_VAR_TYPE_S)
 
 #define CURTIME (((double)csound->icurTime)/((double)csound->esr))
 #define CURTIME_inc (((double)csound->ksmps)/((double)csound->esr))
@@ -208,7 +223,7 @@ typedef struct {
     int     midiKey, midiKeyCps, midiKeyOct, midiKeyPch;
     int     midiVelocity, midiVelocityAmp;
     int     noDefaultPaths;  /* syy - Oct 25, 2006: for disabling relative paths
-                              from files */
+                                from files */
     int     numThreads;
     int     syntaxCheckOnly;
     int     useCsdLineCounts;
@@ -217,6 +232,7 @@ typedef struct {
     MYFLT   e0dbfs_override;
     int     daemon;
     double  quality;        /* for ogg encoding */
+    int     ksmps_override;
   } OPARMS;
 
   typedef struct arglst {
@@ -225,10 +241,10 @@ typedef struct {
   } ARGLST;
 
   typedef struct arg {
-          int type;
-          void* argPtr;
-          int index;
-          struct arg* next;
+    int type;
+    void* argPtr;
+    int index;
+    struct arg* next;
   } ARG;
 //  typedef struct argoffs {
 //    int     count;
@@ -264,21 +280,17 @@ typedef struct {
    * Storage for parsed orchestra code, for each opcode in an INSTRTXT.
    */
   typedef struct text {
-    int     linenum;        /* Line num in orch file (currently buggy!)  */
-    OENTRY* oentry;
-    char    *opcod;         /* Pointer to opcode name in global pool */
-    ARGLST  *inlist;        /* Input args (pointer to item in name list) */
-    ARGLST  *outlist;
-    ARG     *inArgs;        /* Input args (index into list of values) */
-    unsigned int inArgCount;
-    ARG     *outArgs;
-    unsigned int outArgCount;
-    int     xincod;         /* Rate switch for multi-rate opcode functions */
-    int     xoutcod;        /* output rate switch (IV - Sep 1 2002) */
-    int     xincod_str;     /* Type switch for string arguments */
-    int     xoutcod_str;
-    char    intype;         /* Type of first input argument (g,k,a,w etc) */
-    char    pftype;         /* Type of output argument (k,a etc) */
+    int             linenum;        /* Line num in orch file (currently buggy!)  */
+    OENTRY          *oentry;
+    char            *opcod;         /* Pointer to opcode name in global pool */
+    ARGLST          *inlist;        /* Input args (pointer to item in name list) */
+    ARGLST          *outlist;
+    ARG             *inArgs;        /* Input args (index into list of values) */
+    unsigned int    inArgCount;
+    ARG             *outArgs;
+    unsigned        int outArgCount;
+    char            intype;         /* Type of first input argument (g,k,a,w etc) */
+    char            pftype;         /* Type of output argument (k,a etc) */
   } TEXT;
 
 
@@ -314,6 +326,7 @@ typedef struct {
     char    *insname;               /* instrument name */
     int     instcnt;                /* Count number of instances ever */
     int     isNew;                  /* is this a new definition */
+    int     nocheckpcnt;            /* Control checks on pcnt */
   } INSTRTXT;
 
   typedef struct namedInstr {
@@ -430,7 +443,7 @@ typedef struct {
     int     scnt;
     char    *strarg;
     /* instance pointer */
-    void  *pinstance;
+    void  *pinstance;  /* TODO - Remove this field in Csound 7, not being used */
     /** Event type */
     char    opcod;
     /** Number of p-fields */
@@ -523,10 +536,10 @@ typedef struct {
     MYFLT  *lclbas;  /* base for variable memory pool */
     char   *strarg;       /* string argument */
     /* Copy of required p-field values for quick access */
-    MYFLT   p0;
-    MYFLT   p1;
-    MYFLT   p2;
-    MYFLT   p3;
+    CS_VAR_MEM  p0;
+    CS_VAR_MEM  p1;
+    CS_VAR_MEM  p2;
+    CS_VAR_MEM  p3;
   } INSDS;
 
 #define CS_KSMPS     (p->h.insdshead->ksmps)
@@ -625,6 +638,10 @@ typedef struct {
     int32    nchanls;
     /** table number */
     int32    fno;
+    /** args  */
+    MYFLT args[PMAX - 4];
+    /** arg count */
+    int argcnt;
     /** GEN01 parameters */
     GEN01ARGS gen01args;
     /** table data (flen + 1 MYFLT values) */
@@ -976,13 +993,10 @@ typedef struct NAME__ {
     /**@}*/
     /** @name Arguments to opcodes */
     /**@{ */
+    CS_TYPE *(*GetTypeForArg)(void *p);
     int (*GetInputArgCnt)(void *p);
-    unsigned long (*GetInputArgAMask)(void *p);
-    unsigned long (*GetInputArgSMask)(void *p);
     char *(*GetInputArgName)(void *p, int n);
     int (*GetOutputArgCnt)(void *p);
-    unsigned long (*GetOutputArgAMask)(void *p);
-    unsigned long (*GetOutputArgSMask)(void *p);
     char *(*GetOutputArgName)(void *p, int n);
     char *(*GetString)(CSOUND *, MYFLT);
     int32 (*strarg2insno)(CSOUND *, void *p, int is_string);
@@ -1260,7 +1274,11 @@ typedef struct NAME__ {
     int (*OpenLibrary)(void **library, const char *libraryPath);
     int (*CloseLibrary)(void *library);
     void *(*GetLibrarySymbol)(void *library, const char *procedureName);
+#ifndef __MACH__
+    char *(*LocalizeString)(const char *) __attribute__ ((format_arg (1)));
+#else
     char *(*LocalizeString)(const char *);
+#endif
     char *(*strtok_r)(char*, char*, char**);
     double (*strtod)(char*, char**);
     int (*sprintf)(char *str, const char *format, ...);
@@ -1457,7 +1475,6 @@ typedef struct NAME__ {
     /* statics from twarp.c should be TSEG* */
     void          *tseg, *tpsave, *tplim;
     /* Statics from express.c */
-    int           acount, kcount, icount, Bcount, bcount, tcount;
     MYFLT         *gbloffbas;       /* was static in oload.c */
     pthread_t    file_io_thread;
     int          file_io_start;
@@ -1605,6 +1622,7 @@ typedef struct NAME__ {
     char          *SF_csd_licence;
     char          *SF_id_title;
     char          *SF_id_copyright;
+    int           SF_id_scopyright;
     char          *SF_id_software;
     char          *SF_id_artist;
     char          *SF_id_comment;
@@ -1677,7 +1695,10 @@ typedef struct NAME__ {
     int           modules_loaded;
     MYFLT         _system_sr;
     void*         csdebug_data; /* debugger data */
-    int (*kperf)(CSOUND *); /* kperf function pointer, to switch between debug and nodebug function */
+    int (*kperf)(CSOUND *); /* kperf function pointer, to switch between debug
+                               and nodebug function */
+    int           score_parser;
+    CS_HASH_TABLE* symbtab;
     /*struct CSOUND_ **self;*/
     /**@}*/
 #endif  /* __BUILDING_LIBCSOUND */
