@@ -1,7 +1,7 @@
 #!/usr/bin/python
 
-# Csound5 Test Suite
-# By Steven Yi<stevenyi at gmail dot com>
+# Csound Test Suite
+# By Steven Yi <stevenyi at gmail dot com>
 
 import os
 import sys
@@ -115,7 +115,9 @@ def runTest():
 	["test_arrays_string.csd", "test string-array"],
 	["test_arrays_string2.csd", "test simple string-array assignment"],
 	["test_asig_as_array.csd", "test using a-sig with array get/set syntax"],
-	
+	["test_arrays_negative_dimension_fail.csd", 
+             "test expected failure with negative dimension size and array", 1],
+
 	["test_empty_conditional_branches.csd", "tests that empty branches do not cause compiler issues"],
 	["test_empty_instr.csd", "tests that empty instruments do not cause compiler issues"],
 	["test_empty_udo.csd", "tests that empty UDOs do not cause compiler issues"],
@@ -133,6 +135,7 @@ def runTest():
 	["test_udo_a_array.csd", "test udo with a-array"],
 	["test_udo_2d_array.csd", "test udo with 2d-array"],
         ["test_udo_string_array_join.csd", "test udo with S[] arg returning S"],
+        ["test_array_function_call.csd", "test synthesizing an array arg from a function-call"],
     ]
 
     arrayTests = [["arrays/arrays_i_local.csd", "local i[]"],
@@ -145,7 +148,15 @@ def runTest():
         ["arrays/arrays_S_global.csd", "global S[]"],
     ]
 
+
+    udoTests = [["udo/fail_no_xin.csd", "fail due to no xin", 1],
+        ["udo/fail_no_xout.csd", "fail due to no xout", 1],
+        ["udo/fail_invalid_xin.csd", "fail due to invalid xin", 1],
+        ["udo/fail_invalid_xout.csd", "fail due to invalid xout", 1],
+    ]
+
     tests += arrayTests
+    tests += udoTests
 
     output = ""
     tempfile = "/tmp/csound_test_output.txt"
