@@ -51,7 +51,7 @@ static int het_export(CSOUND *csound, int argc, char **argv)
       het_export_usage(csound);
       return 1;
     }
-    inf = csound->ldmemfile2(csound, argv[1], CSFTYPE_HETRO);
+    inf = csound->ldmemfile2withCB(csound, argv[1], CSFTYPE_HETRO,NULL);
     if (inf == NULL) {
       csound->Message(csound, Str("Cannot open input file %s\n"), argv[1]);
       return 1;
@@ -65,6 +65,7 @@ static int het_export(CSOUND *csound, int argc, char **argv)
     endata = (int16 *) inf->endp;
     cc = 0;
 
+    fprintf(outf, "HETRO ");
     for (; adp<endata; adp++) {
       if (*adp == END) fputc('\n',outf), cc = 0;
       else fprintf(outf, "%s%hd", (cc ? ",":""), *adp), cc = 1;
