@@ -37,9 +37,11 @@
 #endif
 #include "lpc.h"
 
+#define Str(x) x
+
 void lpc_export_usage(void)
 {
-    printf("usage: lpc_export lpc_file cstext-file\n");
+    printf(Str("usage: lpc_export lpc_file cstext-file\n"));
 }
 
 int main(int argc, char **argv)
@@ -57,18 +59,18 @@ int main(int argc, char **argv)
     }
     inf = fopen(argv[1], "rb");
     if (inf == NULL) {
-      printf("Cannot open input file %s\n", argv[1]);
+      printf(Str("Cannot open input file %s\n"), argv[1]);
       return 1;
     }
     outf = fopen(argv[2], "w");
     if (outf == NULL) {
-      printf("Cannot open output file %s\n", argv[2]);
+      printf(Str("Cannot open output file %s\n"), argv[2]);
       fclose(inf);
       return 1;
     }
     if (fread(&hdr, sizeof(LPHEADER)-4, 1, inf) != 1 ||
         (hdr.lpmagic != LP_MAGIC && hdr.lpmagic != LP_MAGIC2)) {
-      printf("Failed to read LPC header\n");
+      printf(Str("Failed to read LPC header\n"));
       fclose(inf);
       fclose(outf);
       return 1;
@@ -76,22 +78,28 @@ int main(int argc, char **argv)
     fprintf(outf, "%d,%d,%d,%d,%f,%f,%f",
             hdr.headersize, hdr.lpmagic, hdr.npoles, hdr.nvals,
             hdr.framrate, hdr.srate, hdr.duration);
-    str = (char *)malloc((size_t)(hdr.headersize-sizeof(LPHEADER)+4));
-    if( str == NULL) exit(1);
-    if (UNLIKELY(fread(&hdr, sizeof(char),
-                       hdr.headersize-sizeof(LPHEADER)+4, inf)!=
-                 hdr.headersize-sizeof(LPHEADER)+4)){
-      fprintf(stderr, "Read failure\n");
+    if (hdr.headersize>1024) {
+      fprintf(stderr, Str("corrupt header\n"));
       exit(1);
     }
+    str = (char *)malloc((size_t)(hdr.headersize-sizeof(LPHEADER)+4));
+    if( str == NULL) exit(1);
+    if (UNLIKELY(fread(&str, sizeof(char),
+                       hdr.headersize-sizeof(LPHEADER)+4, inf)!=
+                 hdr.headersize-sizeof(LPHEADER)+4)){
+      fprintf(stderr, Str("Read failure\n"));
+      exit(1);
+    }
+    if (UNLIKELY(hdr.headersize>100)) hdr.headersize = 101;
     for (i=0; i<hdr.headersize-sizeof(LPHEADER)+4; i++)
       putc(str[i],outf);
-    putc('\n', outf);
+    if (UNLIKELY(hdr.headersize > 100))
+      putc('\n', outf);
     if (hdr.npoles+hdr.nvals > 0 && hdr.npoles > 0) {
       coef = (MYFLT *)malloc((hdr.npoles+hdr.nvals)*sizeof(MYFLT));
       for (i = 0; i<floor(hdr.framrate*hdr.duration); i++) {
-        if (UNLIKELY(fread(&coef[0], sizeof(MYFLT), hdr.npoles,inf) != hdr.npoles)) {
-          fprintf(stderr, "Read failure\n");
+        if (UNLIKELY(fread(coef, sizeof(MYFLT), hdr.npoles,inf) != hdr.npoles)) {
+          fprintf(stderr, Str("Read failure\n"));
           exit(1);
         }
         for (j=0; j<hdr.npoles; j++)
