@@ -47,7 +47,7 @@ static CS_NOINLINE CS_PRINTF2 void pvlook_print(PVLOOK *p, const char *fmt, ...)
 
     s = &(buf[0]);
     va_start(args, fmt);
-    len = (int) vsprintf(s, fmt, args);
+    len = (int) vsnprintf(s, 1024, fmt, args);
     va_end(args);
  /* fprintf(p->outfd, "%s", s); */
     p->csound->MessageS(p->csound, CSOUNDMSG_ORCH, s);
